$APIVersionInterfaceBuilder class abstract mixin

Implementers

Properties

epoch ↔ int?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
major ↔ int?
getter/setter pair
minor ↔ int?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
replace($APIVersionInterface other) → void
toString() → String
A string representation of this object.
inherited
update(void updates($APIVersionInterfaceBuilder)) → void

Operators

operator ==(Object other) → bool
The equality operator.
inherited