$CategoryInformationInterface class sealed

The very basic information of a category. Please note: A category name of * indicates the number of recipes with no category associated.

Implementers
Annotations
  • @BuiltValue.new(instantiable: false)

Properties

hashCode → int
The hash code for this object.
no setterinherited
name → String
The name of the category.
no setter
recipeCount → int
The number of recipes in the category.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(void updates($CategoryInformationInterfaceBuilder)) → $CategoryInformationInterface
Rebuilds the instance.
toBuilder() → $CategoryInformationInterfaceBuilder
Converts the instance to a builder $CategoryInformationInterfaceBuilder.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited