$NutritionInterfaceBuilder class abstract mixin

Implementers

Properties

calories ↔ String?
getter/setter pair
carbohydrateContent ↔ String?
getter/setter pair
cholesterolContent ↔ String?
getter/setter pair
fatContent ↔ String?
getter/setter pair
fiberContent ↔ String?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
proteinContent ↔ String?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
saturatedFatContent ↔ String?
getter/setter pair
servingSize ↔ String?
getter/setter pair
sodiumContent ↔ String?
getter/setter pair
sugarContent ↔ String?
getter/setter pair
transFatContent ↔ String?
getter/setter pair
type ↔ String?
getter/setter pair
unsaturatedFatContent ↔ String?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
replace($NutritionInterface other) → void
toString() → String
A string representation of this object.
inherited
update(void updates($NutritionInterfaceBuilder)) → void

Operators

operator ==(Object other) → bool
The equality operator.
inherited