$RecipeStubInformationInterface class sealed

The very basic information of a recipe.

Implementers
Annotations
  • @BuiltValue.new(instantiable: false)

Properties

dateCreated → String
The date the recipe was created in the app.
no setter
dateModified → String?
The date the recipe was modified lastly in the app.
no setter
hashCode → int
The hash code for this object.
no setterinherited
imagePlaceholderUrl → String
The URL of the placeholder of the recipe image.
no setter
imageUrl → String
The URL of the recipe image.
no setter
keywords → String
A comma-separated list of recipe keywords, can be empty string.
no setter
name → String
The name of the recipe.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(void updates($RecipeStubInformationInterfaceBuilder)) → $RecipeStubInformationInterface
Rebuilds the instance.
toBuilder() → $RecipeStubInformationInterfaceBuilder
Converts the instance to a builder $RecipeStubInformationInterfaceBuilder.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited