CategoryInformation class abstract

The very basic information of a category. Please note: A category name of * indicates the number of recipes with no category associated.

Implemented types

Constructors

CategoryInformation([void b(CategoryInformationBuilder)?])
Creates a new CategoryInformation object using the builder pattern.
factory
CategoryInformation.fromJson(Map<String, dynamic> json)
Creates a new object from the given json data.
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
name → String
The name of the category.
no setterinherited
recipeCount → int
The number of recipes in the category.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(CategoryInformationBuilder)) → CategoryInformation
Rebuilds the instance.
inherited
toBuilder() → CategoryInformationBuilder
Converts the instance to a builder B.
inherited
toJson() → Map<String, dynamic>
Parses this object into a json like map.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

serializer → Serializer<CategoryInformation>
Serializer for CategoryInformation.
no setter