Nutrition class abstract

Implemented types

Constructors

Nutrition([void b(NutritionBuilder)?])
Creates a new Nutrition object using the builder pattern.
factory
Nutrition.fromJson(Map<String, dynamic> json)
Creates a new object from the given json data.
factory

Properties

calories → String?
The number of calories for the given amount.
no setterinherited
carbohydrateContent → String?
The number of grams of carbohydrates.
no setterinherited
cholesterolContent → String?
The number of milligrams of cholesterol.
no setterinherited
fatContent → String?
The number of grams of fat.
no setterinherited
fiberContent → String?
The number of grams of fiber.
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
proteinContent → String?
The number of grams of protein.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
saturatedFatContent → String?
The number of grams of saturated fat.
no setterinherited
servingSize → String?
The serving size, in terms of the number of volume or mass.
no setterinherited
sodiumContent → String?
The number of milligrams of sodium.
no setterinherited
sugarContent → String?
The number of grams of sugar.
no setterinherited
transFatContent → String?
The number of grams of trans fat.
no setterinherited
type → String
Schema.org object description.
no setterinherited
unsaturatedFatContent → String?
The number of grams of unsaturated fat.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(NutritionBuilder)) → Nutrition
Rebuilds the instance.
inherited
toBuilder() → NutritionBuilder
Converts the instance to a builder B.
inherited
toJson() → Map<String, dynamic>
Parses this object into a json like map.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

serializer → Serializer<Nutrition>
Serializer for Nutrition.
no setter