RecipeStubInformation class abstract

The very basic information of a recipe.

Implemented types

Constructors

RecipeStubInformation([void b(RecipeStubInformationBuilder)?])
Creates a new RecipeStubInformation object using the builder pattern.
factory
RecipeStubInformation.fromJson(Map<String, dynamic> json)
Creates a new object from the given json data.
factory

Properties

dateCreated → String
The date the recipe was created in the app.
no setterinherited
dateModified → String?
The date the recipe was modified lastly in the app.
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
imagePlaceholderUrl → String
The URL of the placeholder of the recipe image.
no setterinherited
imageUrl → String
The URL of the recipe image.
no setterinherited
keywords → String
A comma-separated list of recipe keywords, can be empty string.
no setterinherited
name → String
The name of the recipe.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(RecipeStubInformationBuilder)) → RecipeStubInformation
Rebuilds the instance.
inherited
toBuilder() → RecipeStubInformationBuilder
Converts the instance to a builder B.
inherited
toJson() → Map<String, dynamic>
Parses this object into a json like map.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

serializer → Serializer<RecipeStubInformation>
Serializer for RecipeStubInformation.
no setter