$getRaw method
Autocomplete a query.
This method and the response it returns is experimental. The API might change without a major version bump.
Returns a Future containing a DynamiteRawResponse with the raw HttpClientResponse and serialization helpers.
Throws a DynamiteApiException if the API call does not return an expected status code.
Parameters:
searchText to search for.itemTypeType of the items to search for.itemIdID of the items to search for.sortercan be piped, top prio first, e.g.: "commenters|share-recipients".shareTypesTypes of shares to search for. Defaults to[].limitMaximum number of results to return. Defaults to10.oCSAPIRequestRequired to be true for the API request to pass. Defaults totrue.
Status codes:
- 200: Autocomplete results returned
See:
- $get for an operation that returns a
DynamiteResponsewith a stable API.
Implementation
@_i4.experimental
_i1.DynamiteRawResponse<AutoCompleteGetResponseApplicationJson, void> $getRaw({
required String search,
String? itemType,
String? itemId,
String? sorter,
BuiltList<int>? shareTypes,
int? limit,
bool? oCSAPIRequest,
}) {
final _parameters = <String, dynamic>{};
final _headers = <String, String>{'Accept': 'application/json'};
// coverage:ignore-start
final authentication = _rootClient.authentications?.firstWhereOrNull(
(auth) => switch (auth) {
_i1.DynamiteHttpBearerAuthentication() || _i1.DynamiteHttpBasicAuthentication() => true,
_ => false,
},
);
if (authentication != null) {
_headers.addAll(
authentication.headers,
);
} else {
throw Exception('Missing authentication for bearer_auth or basic_auth');
}
// coverage:ignore-end
final $search = _$jsonSerializers.serialize(search, specifiedType: const FullType(String));
_parameters['search'] = $search;
final $itemType = _$jsonSerializers.serialize(itemType, specifiedType: const FullType(String));
_parameters['itemType'] = $itemType;
final $itemId = _$jsonSerializers.serialize(itemId, specifiedType: const FullType(String));
_parameters['itemId'] = $itemId;
final $sorter = _$jsonSerializers.serialize(sorter, specifiedType: const FullType(String));
_parameters['sorter'] = $sorter;
var $shareTypes =
_$jsonSerializers.serialize(shareTypes, specifiedType: const FullType(BuiltList, [FullType(int)]));
$shareTypes ??= [];
_parameters['shareTypes%5B%5D'] = $shareTypes;
var $limit = _$jsonSerializers.serialize(limit, specifiedType: const FullType(int));
$limit ??= 10;
_parameters['limit'] = $limit;
var $oCSAPIRequest = _$jsonSerializers.serialize(oCSAPIRequest, specifiedType: const FullType(bool));
$oCSAPIRequest ??= true;
_headers['OCS-APIRequest'] = const _i2.HeaderEncoder().convert($oCSAPIRequest);
final _path = _i3.UriTemplate(
'/ocs/v2.php/core/autocomplete/get{?search*,itemType*,itemId*,sorter*,shareTypes%5B%5D*,limit*}',
).expand(_parameters);
return _i1.DynamiteRawResponse<AutoCompleteGetResponseApplicationJson, void>(
response: _rootClient.executeRequest(
'get',
_path,
headers: _headers,
validStatuses: const {200},
),
bodyType: const FullType(AutoCompleteGetResponseApplicationJson),
headersType: null,
serializers: _$jsonSerializers,
);
}