$AutocompleteResultInterfaceBuilder class abstract mixin

Implementers

Properties

hashCode → int
The hash code for this object.
no setterinherited
icon ↔ String?
getter/setter pair
id ↔ String?
getter/setter pair
label ↔ String?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
shareWithDisplayNameUnique ↔ String?
getter/setter pair
source ↔ String?
getter/setter pair
status ↔ AutocompleteResult_Status?
getter/setter pair
subline ↔ String?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
replace($AutocompleteResultInterface other) → void
toString() → String
A string representation of this object.
inherited
update(void updates($AutocompleteResultInterfaceBuilder)) → void

Operators

operator ==(Object other) → bool
The equality operator.
inherited