$Client class

Available extensions

Constructors

$Client(Uri baseURL, {Client? httpClient, List<DynamiteAuthentication>? authentications})
Creates a new DynamiteClient for untagged requests.
$Client.fromClient(DynamiteClient client)
Creates a new $Client from another client.

Properties

appPassword → $AppPasswordClient
latefinal
authentications → List<DynamiteAuthentication>?
The available authentications for this client.
finalinherited
autoComplete → $AutoCompleteClient
latefinal
avatar → $AvatarClient
Class AvatarController.
latefinal
baseURL → Uri
The base server url used to build the request uri.
finalinherited
clientFlowLoginV2 → $ClientFlowLoginV2Client
latefinal
collaborationResources → $CollaborationResourcesClient
latefinal
csrfToken → $CsrfTokenClient
latefinal
guestAvatar → $GuestAvatarClient
This controller handles guest avatar requests.
latefinal
hashCode → int
The hash code for this object.
no setterinherited
hoverCard → $HoverCardClient
latefinal
httpClient → Client
The base http client.
finalinherited
login → $LoginClient
latefinal
latefinal
ocm → $OcmClient
Controller about the endpoint /ocm-provider/.
latefinal
ocs → $OcsClient
latefinal
preview → $PreviewClient
latefinal
profileApi → $ProfileApiClient
latefinal
reference → $ReferenceClient
latefinal
referenceApi → $ReferenceApiClient
latefinal
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
taskProcessingApi → $TaskProcessingApiClient
latefinal
teamsApi → $TeamsApiClient
latefinal
textProcessingApi → $TextProcessingApiClient
latefinal
textToImageApi → $TextToImageApiClient
latefinal
translationApi → $TranslationApiClient
latefinal
twoFactorApi → $TwoFactorApiClient
latefinal
unifiedSearch → $UnifiedSearchClient
latefinal
whatsNew → $WhatsNewClient
latefinal
wipe → $WipeClient
latefinal

Methods

$getStatus_Request() → Request
Returns a DynamiteRequest backing the getStatus operation. Throws a DynamiteApiException if the API call does not return an expected status code.
$getStatus_Serializer() → DynamiteSerializer<Status, void>
Builds a serializer to parse the response of $getStatus_Request.
getStatus() → Future<DynamiteResponse<Status, void>>
Returns a Future containing a DynamiteResponse with the status code, deserialized body and headers. Throws a DynamiteApiException if the API call does not return an expected status code.
getVersionCheck(OcsGetCapabilitiesResponseApplicationJson_Ocs_Data capabilities) → VersionCheck

Available on $Client, provided by the CoreVersionCheck extension

Check if the core/Server version is supported by this client
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited