init method

Init a login flow.

Returns a Future containing a DynamiteResponse with the status code, deserialized body and headers. Throws a DynamiteApiException if the API call does not return an expected status code.

Status codes:

  • 200: Login flow init returned

See:

Implementation

Future<DynamiteResponse<LoginFlowV2, void>> init() async {
  final rawResponse = initRaw();

  return rawResponse.future;
}