initRaw method
Init a login flow.
This method and the response it returns is experimental. The API might change without a major version bump.
Returns a Future containing a DynamiteRawResponse with the raw HttpClientResponse and serialization helpers. Throws a DynamiteApiException if the API call does not return an expected status code.
Status codes:
- 200: Login flow init returned
See:
- init for an operation that returns a DynamiteResponse with a stable API.
Implementation
@experimental
DynamiteRawResponse<LoginFlowV2, void> initRaw() {
final _headers = <String, String>{
'Accept': 'application/json',
};
// coverage:ignore-start
final authentication = _rootClient.authentications.firstWhereOrNull(
(auth) => switch (auth) {
DynamiteHttpBearerAuthentication() || DynamiteHttpBasicAuthentication() => true,
_ => false,
},
);
if (authentication != null) {
_headers.addAll(
authentication.headers,
);
}
// coverage:ignore-end
const _path = '/index.php/login/v2';
return DynamiteRawResponse<LoginFlowV2, void>(
response: _rootClient.executeRequest(
'post',
_path,
_headers,
null,
const {200},
),
bodyType: const FullType(LoginFlowV2),
headersType: null,
serializers: jsonSerializers,
);
}