poll method

Future<DynamiteResponse<LoginFlowV2Credentials, void>> poll({
  1. required String token,
})

Poll the login flow credentials.

Returns a Future containing a DynamiteResponse with the status code, deserialized body and headers. Throws a DynamiteApiException if the API call does not return an expected status code.

Parameters:

  • token Token of the flow.

Status codes:

  • 200: Login flow credentials returned
  • 404: Login flow not found or completed

See:

  • pollRaw for an experimental operation that returns a DynamiteRawResponse that can be serialized.

Implementation

Future<_i1.DynamiteResponse<LoginFlowV2Credentials, void>> poll({required String token}) async {
  final rawResponse = pollRaw(
    token: token,
  );

  return rawResponse.future;
}