renameCollectionRaw method
- @experimental
Rename a collection.
This method and the response it returns is experimental. The API might change without a major version bump.
Returns a Future containing a DynamiteRawResponse with the raw HttpClientResponse and serialization helpers.
Throws a DynamiteApiException if the API call does not return an expected status code.
Parameters:
collectionNameNew name.collectionIdID of the collection.oCSAPIRequestRequired to be true for the API request to pass. Defaults totrue.
Status codes:
- 200: Collection returned
- 404: Collection not found
- 500
See:
- renameCollection for an operation that returns a
DynamiteResponsewith a stable API.
Implementation
@_i4.experimental
_i1.DynamiteRawResponse<CollaborationResourcesRenameCollectionResponseApplicationJson, void> renameCollectionRaw({
required String collectionName,
required int collectionId,
bool? oCSAPIRequest,
}) {
final _parameters = <String, dynamic>{};
final _headers = <String, String>{'Accept': 'application/json'};
// coverage:ignore-start
final authentication = _rootClient.authentications?.firstWhereOrNull(
(auth) => switch (auth) {
_i1.DynamiteHttpBearerAuthentication() || _i1.DynamiteHttpBasicAuthentication() => true,
_ => false,
},
);
if (authentication != null) {
_headers.addAll(
authentication.headers,
);
} else {
throw Exception('Missing authentication for bearer_auth or basic_auth');
}
// coverage:ignore-end
final $collectionName = _$jsonSerializers.serialize(collectionName, specifiedType: const FullType(String));
_parameters['collectionName'] = $collectionName;
final $collectionId = _$jsonSerializers.serialize(collectionId, specifiedType: const FullType(int));
_parameters['collectionId'] = $collectionId;
var $oCSAPIRequest = _$jsonSerializers.serialize(oCSAPIRequest, specifiedType: const FullType(bool));
$oCSAPIRequest ??= true;
_headers['OCS-APIRequest'] = const _i2.HeaderEncoder().convert($oCSAPIRequest);
final _path = _i3.UriTemplate('/ocs/v2.php/collaboration/resources/collections/{collectionId}{?collectionName*}')
.expand(_parameters);
return _i1.DynamiteRawResponse<CollaborationResourcesRenameCollectionResponseApplicationJson, void>(
response: _rootClient.executeRequest(
'put',
_path,
headers: _headers,
validStatuses: const {200},
),
bodyType: const FullType(CollaborationResourcesRenameCollectionResponseApplicationJson),
headersType: null,
serializers: _$jsonSerializers,
);
}