searchCollections method

Future<DynamiteResponse<CollaborationResourcesSearchCollectionsResponseApplicationJson, void>> searchCollections({
  1. required String filter,
  2. bool? oCSAPIRequest,
})

Search for collections.

Returns a Future containing a DynamiteResponse with the status code, deserialized body and headers. Throws a DynamiteApiException if the API call does not return an expected status code.

Parameters:

  • filter Filter collections.
  • oCSAPIRequest Required to be true for the API request to pass. Defaults to true.

Status codes:

  • 200: Collections returned
  • 404: Collection not found

See:

Implementation

Future<_i1.DynamiteResponse<CollaborationResourcesSearchCollectionsResponseApplicationJson, void>> searchCollections({
  required String filter,
  bool? oCSAPIRequest,
}) async {
  final _request = $searchCollections_Request(filter: filter, oCSAPIRequest: oCSAPIRequest);
  final _streamedResponse = await _rootClient.httpClient.send(_request);
  final _response = await _i3.Response.fromStream(_streamedResponse);

  final _serializer = $searchCollections_Serializer();
  return _i1.ResponseConverter<CollaborationResourcesSearchCollectionsResponseApplicationJson, void>(
    _serializer,
  ).convert(_response);
}