$CollaborationResourcesRemoveResourceResponseApplicationJsonInterface class sealed

Implementers
Annotations
  • @BuiltValue.new(instantiable: false)

Properties

hashCode → int
The hash code for this object.
no setterinherited
ocs → CollaborationResourcesRemoveResourceResponseApplicationJson_Ocs
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(void updates($CollaborationResourcesRemoveResourceResponseApplicationJsonInterfaceBuilder)) → $CollaborationResourcesRemoveResourceResponseApplicationJsonInterface
Rebuilds the instance.
toBuilder() → $CollaborationResourcesRemoveResourceResponseApplicationJsonInterfaceBuilder
Converts the instance to a builder $CollaborationResourcesRemoveResourceResponseApplicationJsonInterfaceBuilder.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited