$FilesSharingCapabilities_FilesSharingInterface class sealed

Implementers
Annotations
  • @BuiltValue.new(instantiable: false)

Properties

apiEnabled → bool
no setter
defaultPermissions → int?
no setter
federation → FilesSharingCapabilities_FilesSharing_Federation
no setter
group → FilesSharingCapabilities_FilesSharing_Group?
no setter
groupSharing → bool?
no setter
hashCode → int
The hash code for this object.
no setterinherited
public → FilesSharingCapabilities_FilesSharing_Public
no setter
resharing → bool
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sharee → FilesSharingCapabilities_FilesSharing_Sharee
no setter
user → FilesSharingCapabilities_FilesSharing_User
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(void updates($FilesSharingCapabilities_FilesSharingInterfaceBuilder)) → $FilesSharingCapabilities_FilesSharingInterface
Rebuilds the instance.
toBuilder() → $FilesSharingCapabilities_FilesSharingInterfaceBuilder
Converts the instance to a builder $FilesSharingCapabilities_FilesSharingInterfaceBuilder.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited