$FilesSharingCapabilities_FilesSharingInterfaceBuilder class abstract mixin

Implementers

Properties

apiEnabled ↔ bool?
getter/setter pair
defaultPermissions ↔ int?
getter/setter pair
federation ↔ FilesSharingCapabilities_FilesSharing_FederationBuilder
getter/setter pair
group ↔ FilesSharingCapabilities_FilesSharing_GroupBuilder
getter/setter pair
groupSharing ↔ bool?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
public ↔ FilesSharingCapabilities_FilesSharing_PublicBuilder
getter/setter pair
resharing ↔ bool?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sharee ↔ FilesSharingCapabilities_FilesSharing_ShareeBuilder
getter/setter pair
user ↔ FilesSharingCapabilities_FilesSharing_UserBuilder
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
replace($FilesSharingCapabilities_FilesSharingInterface other) → void
toString() → String
A string representation of this object.
inherited
update(void updates($FilesSharingCapabilities_FilesSharingInterfaceBuilder)) → void

Operators

operator ==(Object other) → bool
The equality operator.
inherited