$NavigationEntryInterface class sealed

Implementers
Annotations
  • @BuiltValue.new(instantiable: false)

Properties

$default → bool?
no setter
active → bool
no setter
app → String?
no setter
classes → String
no setter
hashCode → int
The hash code for this object.
no setterinherited
href → String
no setter
icon → String
no setter
id → String
no setter
name → String
no setter
order → int?
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → String
no setter
unread → int
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(void updates($NavigationEntryInterfaceBuilder)) → $NavigationEntryInterface
Rebuilds the instance.
toBuilder() → $NavigationEntryInterfaceBuilder
Converts the instance to a builder $NavigationEntryInterfaceBuilder.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited