getMimeIconUrl method
Future<DynamiteResponse<void, PreviewPreviewGetMimeIconUrlHeaders> >
getMimeIconUrl({
- String? mime,
Get a preview by mime.
Returns a Future containing a DynamiteResponse with the status code, deserialized body and headers.
Throws a DynamiteApiException if the API call does not return an expected status code.
Parameters:
mimeMime type. Defaults to"application/octet-stream".
Status codes:
- 303: The mime icon url
See:
- $getMimeIconUrl_Request for the request send by this method.
- $getMimeIconUrl_Serializer for a converter to parse the
Responsefrom an executed request.
Implementation
Future<_i1.DynamiteResponse<void, PreviewPreviewGetMimeIconUrlHeaders>> getMimeIconUrl({String? mime}) async {
final _request = $getMimeIconUrl_Request(mime: mime);
final _streamedResponse = await _rootClient.httpClient.send(_request);
final _response = await _i3.Response.fromStream(_streamedResponse);
final _serializer = $getMimeIconUrl_Serializer();
return _i1.ResponseConverter<void, PreviewPreviewGetMimeIconUrlHeaders>(_serializer).convert(_response);
}