$ProfileActionInterface class sealed

Implementers
Annotations
  • @BuiltValue.new(instantiable: false)

Properties

hashCode int
The hash code for this object.
no setterinherited
icon String
no setter
id String
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
target String?
no setter
title String
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(void updates($ProfileActionInterfaceBuilder)) $ProfileActionInterface
Rebuilds the instance.
toBuilder() $ProfileActionInterfaceBuilder
Converts the instance to a builder $ProfileActionInterfaceBuilder.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited