$ProfileApiClient class

Constructors

$ProfileApiClient($Client _rootClient)
Creates a new DynamiteClient for profile_api requests.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

$getProfileFields_Request({required String targetUserId, bool? oCSAPIRequest}) → Request
Get profile fields for another user.
$getProfileFields_Serializer() → DynamiteSerializer<ProfileApiGetProfileFieldsResponseApplicationJson, void>
Builds a serializer to parse the response of $getProfileFields_Request.
$setVisibility_Request({required String targetUserId, required ProfileApiSetVisibilityRequestApplicationJson $body, bool? oCSAPIRequest}) → Request
Update the visibility of a parameter.
$setVisibility_Serializer() → DynamiteSerializer<ProfileApiSetVisibilityResponseApplicationJson, void>
Builds a serializer to parse the response of $setVisibility_Request.
getProfileFields({required String targetUserId, bool? oCSAPIRequest}) Future<DynamiteResponse<ProfileApiGetProfileFieldsResponseApplicationJson, void>>
Get profile fields for another user.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setVisibility({required String targetUserId, required ProfileApiSetVisibilityRequestApplicationJson $body, bool? oCSAPIRequest}) Future<DynamiteResponse<ProfileApiSetVisibilityResponseApplicationJson, void>>
Update the visibility of a parameter.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited