rebuild abstract method
Rebuilds the instance.
The result is the same as this instance but with updates applied.
updates is a function that takes a builder $ProfileApiGetProfileFieldsResponseApplicationJson_OcsInterfaceBuilder.
Implementation
$ProfileApiGetProfileFieldsResponseApplicationJson_OcsInterface rebuild(
void Function($ProfileApiGetProfileFieldsResponseApplicationJson_OcsInterfaceBuilder) updates,
);