$ProfileDataInterface class sealed

Implemented types
Implementers
Annotations
  • @BuiltValue.new(instantiable: false)

Properties

actions → BuiltList<ProfileAction>
no setterinherited
address String?
no setterinherited
biography String?
no setterinherited
displayname String?
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
headline String?
no setterinherited
isUserAvatarVisible bool?
no setterinherited
organisation String?
no setterinherited
pronouns String?
no setterinherited
role String?
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
timezone String
no setter
timezoneOffset int
no setter
userId String
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(void updates($ProfileDataInterfaceBuilder)) $ProfileDataInterface
Rebuilds the instance.
override
toBuilder() $ProfileDataInterfaceBuilder
Converts the instance to a builder $ProfileDataInterfaceBuilder.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited