rebuild abstract method

  1. @override
$ProfileDataInterface rebuild(
  1. void updates(
    1. $ProfileDataInterfaceBuilder
    )
)
override

Rebuilds the instance.

The result is the same as this instance but with updates applied. updates is a function that takes a builder $ProfileDataInterfaceBuilder.

Implementation

@override
$ProfileDataInterface rebuild(void Function($ProfileDataInterfaceBuilder) updates);