$ProfileFieldsInterface class sealed

Implementers
Annotations
  • @BuiltValue.new(instantiable: false)

Properties

actions → BuiltList<ProfileAction>
no setter
address → String?
no setter
biography → String?
no setter
displayname → String?
no setter
hashCode → int
The hash code for this object.
no setterinherited
headline → String?
no setter
isUserAvatarVisible → bool?
no setter
organisation → String?
no setter
pronouns → String?
no setter
role → String?
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
userId → String
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(void updates($ProfileFieldsInterfaceBuilder)) → $ProfileFieldsInterface
Rebuilds the instance.
toBuilder() → $ProfileFieldsInterfaceBuilder
Converts the instance to a builder $ProfileFieldsInterfaceBuilder.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited