extract method
Future<DynamiteResponse<ReferenceApiExtractResponseApplicationJson, void> >
extract({
- required String text,
- ReferenceApiExtractResolve? resolve,
- int? limit,
- bool? oCSAPIRequest,
Extract references from a text.
Returns a Future containing a DynamiteResponse with the status code, deserialized body and headers.
Throws a DynamiteApiException if the API call does not return an expected status code.
Parameters:
textText to extract from.resolveResolve the references. Defaults to0.limitMaximum amount of references to extract. Defaults to1.oCSAPIRequestRequired to be true for the API request to pass. Defaults totrue.
Status codes:
- 200: References returned
See:
- extractRaw for an experimental operation that returns a
DynamiteRawResponsethat can be serialized.
Implementation
Future<_i1.DynamiteResponse<ReferenceApiExtractResponseApplicationJson, void>> extract({
required String text,
ReferenceApiExtractResolve? resolve,
int? limit,
bool? oCSAPIRequest,
}) async {
final rawResponse = extractRaw(
text: text,
resolve: resolve,
limit: limit,
oCSAPIRequest: oCSAPIRequest,
);
return rawResponse.future;
}