extractRaw method
Extract references from a text.
This method and the response it returns is experimental. The API might change without a major version bump.
Returns a Future containing a DynamiteRawResponse with the raw HttpClientResponse and serialization helpers. Throws a DynamiteApiException if the API call does not return an expected status code.
Parameters:
textText to extract from.resolveResolve the references. Defaults to0.limitMaximum amount of references to extract. Defaults to1.oCSAPIRequestRequired to be true for the API request to pass. Defaults totrue.
Status codes:
- 200: References returned
See:
- extract for an operation that returns a DynamiteResponse with a stable API.
Implementation
@experimental
DynamiteRawResponse<ReferenceApiExtractResponseApplicationJson, void> extractRaw({
required String text,
int? resolve,
int? limit,
bool? oCSAPIRequest,
}) {
final _parameters = <String, dynamic>{};
final _headers = <String, String>{
'Accept': 'application/json',
};
// coverage:ignore-start
final authentication = _rootClient.authentications.firstWhereOrNull(
(auth) => switch (auth) {
DynamiteHttpBearerAuthentication() || DynamiteHttpBasicAuthentication() => true,
_ => false,
},
);
if (authentication != null) {
_headers.addAll(
authentication.headers,
);
} else {
throw Exception('Missing authentication for bearer_auth or basic_auth');
}
// coverage:ignore-end
final $text = jsonSerializers.serialize(text, specifiedType: const FullType(String));
_parameters['text'] = $text;
var $resolve = jsonSerializers.serialize(resolve, specifiedType: const FullType(int));
$resolve ??= 0;
_parameters['resolve'] = $resolve;
var $limit = jsonSerializers.serialize(limit, specifiedType: const FullType(int));
$limit ??= 1;
_parameters['limit'] = $limit;
var $oCSAPIRequest = jsonSerializers.serialize(oCSAPIRequest, specifiedType: const FullType(bool));
$oCSAPIRequest ??= true;
_headers['OCS-APIRequest'] = const dynamite_utils.HeaderEncoder().convert($oCSAPIRequest);
final _path = UriTemplate('/ocs/v2.php/references/extract{?text*,resolve*,limit*}').expand(_parameters);
return DynamiteRawResponse<ReferenceApiExtractResponseApplicationJson, void>(
response: _rootClient.executeRequest(
'post',
_path,
_headers,
null,
const {200},
),
bodyType: const FullType(ReferenceApiExtractResponseApplicationJson),
headersType: null,
serializers: jsonSerializers,
);
}