$RichObjectParameterInterface class sealed

Implementers
Annotations
  • @BuiltValue.new(instantiable: false)

Properties

assignable → String?
If the user can assign the systemtag.
no setter
blurhash → String?
The blurhash of the image.
no setter
boardname → String?
The display name of board which contains the card.
no setter
callType → String?
The type of the call: one2one, group or public.
no setter
conversation → String?
The token of the conversation.
no setter
description → String?
The open graph description from the website.
no setter
etag → String?
The ETag of the file/folder.
no setter
hashCode → int
The hash code for this object.
no setterinherited
height → String?
The height in pixels if the file is an image.
no setter
hideDownload → String?
Whether the download option should be hidden. If not set to yes the option can be shown.
no setter
iconUrl → String?
The icon url to use as avatar.
no setter
id → String
no setter
latitude → String?
The latitude of the location MUST be the same as in the id.
no setter
The full URL to the file.
no setter
longitude → String?
The longitude of the location MUST be the same as in the id.
no setter
messageId → String?
The id of a message that was referred to.
no setter
mimetype → String?
The mimetype of the file/folder to allow clients to show a placeholder.
no setter
mtime → String?
The mtime of the file/folder as unix timestamp.
no setter
name → String
no setter
path → String?
The full path of the file for the user, should not start with a slash.
no setter
permissions → String?
The permissions on the file/folder.
no setter
previewAvailable → String?
Whether or not a preview is available. If no the mimetype icon should be used.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
server → String?
The URL of the instance the user lives on.
no setter
size → String?
The file size in bytes.
no setter
stackname → String?
The display name of the stack which contains the card in the board.
no setter
thumb → String?
The full URL of the open graph thumbnail.
no setter
type → RichObjectParameter_Type
no setter
visibility → String?
If the user can see the systemtag.
no setter
website → String?
The name of the described website.
no setter
width → String?
The width in pixels if the file is an image.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(void updates($RichObjectParameterInterfaceBuilder)) → $RichObjectParameterInterface
Rebuilds the instance.
toBuilder() → $RichObjectParameterInterfaceBuilder
Converts the instance to a builder $RichObjectParameterInterfaceBuilder.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited