hideDownload property
Whether the download option should be hidden. If not set to yes the option can be shown.
Implementation
@BuiltValueField(wireName: 'hide-download')
String? get hideDownload;
Whether the download option should be hidden. If not set to yes the option can be shown.
@BuiltValueField(wireName: 'hide-download')
String? get hideDownload;