$SharebymailCapabilities_FilesSharingInterface class sealed

Implementers
Annotations
  • @BuiltValue.new(instantiable: false)

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sharebymail SharebymailCapabilities_FilesSharing_Sharebymail
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(void updates($SharebymailCapabilities_FilesSharingInterfaceBuilder)) $SharebymailCapabilities_FilesSharingInterface
Rebuilds the instance.
toBuilder() $SharebymailCapabilities_FilesSharingInterfaceBuilder
Converts the instance to a builder $SharebymailCapabilities_FilesSharingInterfaceBuilder.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited