- Implementers
Constructors
Properties
- canCreate ↔ bool?
-
getter/setter pair
- descriptionLength ↔ int?
-
getter/setter pair
- forcePasswords ↔ bool?
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- listStyle ↔ SpreedCapabilities_Config_Conversations_ListStyle?
-
getter/setter pair
- retentionEvent ↔ int?
-
getter/setter pair
- retentionInstantMeetings ↔ int?
-
getter/setter pair
- retentionPhone ↔ int?
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
replace(
$SpreedCapabilities_Config_ConversationsInterface other) → void -
toString(
) → String -
A string representation of this object.
inherited
-
update(
void updates($SpreedCapabilities_Config_ConversationsInterfaceBuilder)) → void
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited