$StatusInterface class sealed

Implementers
Annotations
  • @BuiltValue.new(instantiable: false)

Properties

edition → String
no setter
extendedSupport → bool
no setter
hashCode → int
The hash code for this object.
no setterinherited
installed → bool
no setter
maintenance → bool
no setter
needsDbUpgrade → bool
no setter
productname → String
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
version → String
no setter
versionstring → String
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(void updates($StatusInterfaceBuilder)) → $StatusInterface
Rebuilds the instance.
toBuilder() → $StatusInterfaceBuilder
Converts the instance to a builder $StatusInterfaceBuilder.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited