$getNextScheduledTask_Request method
- @experimental
Returns the next scheduled task for the taskTypeId.
This endpoint requires admin access.
Returns a DynamiteRequest backing the getNextScheduledTask operation.
Throws a DynamiteApiException if the API call does not return an expected status code.
Parameters:
providerIdsThe ids of the providers.taskTypeIdsThe ids of the task types.oCSAPIRequestRequired to be true for the API request to pass. Defaults totrue.
Status codes:
- 200: Task returned
- 204: No task found
- 500
See:
- getNextScheduledTask for a method executing this request and parsing the response.
- $getNextScheduledTask_Serializer for a converter to parse the
Responsefrom an executed this request.
Implementation
@_i2.experimental
_i3.Request $getNextScheduledTask_Request({
required BuiltList<String> providerIds,
required BuiltList<String> taskTypeIds,
bool? oCSAPIRequest,
}) {
final _parameters = <String, Object?>{};
final __providerIds = _$jsonSerializers.serialize(
providerIds,
specifiedType: const FullType(BuiltList, [FullType(String)]),
);
_parameters['providerIds%5B%5D'] = __providerIds;
final __taskTypeIds = _$jsonSerializers.serialize(
taskTypeIds,
specifiedType: const FullType(BuiltList, [FullType(String)]),
);
_parameters['taskTypeIds%5B%5D'] = __taskTypeIds;
final _path = _i6.UriTemplate(
'/ocs/v2.php/taskprocessing/tasks_provider/next{?providerIds%5B%5D*,taskTypeIds%5B%5D*}',
).expand(_parameters);
final _uri = Uri.parse('${_rootClient.baseURL}$_path');
final _request = _i3.Request('get', _uri);
_request.headers['Accept'] = 'application/json';
// coverage:ignore-start
final authentication = _i4.IterableExtension(_rootClient.authentications)?.firstWhereOrNull(
(auth) => switch (auth) {
_i1.DynamiteHttpBearerAuthentication() || _i1.DynamiteHttpBasicAuthentication() => true,
_ => false,
},
);
if (authentication != null) {
_request.headers.addAll(authentication.headers);
} else {
throw Exception('Missing authentication for bearer_auth or basic_auth');
}
// coverage:ignore-end
var __oCSAPIRequest = _$jsonSerializers.serialize(oCSAPIRequest, specifiedType: const FullType(bool));
__oCSAPIRequest ??= true;
_request.headers['OCS-APIRequest'] = const _i5.HeaderEncoder().convert(__oCSAPIRequest);
return _request;
}