$TaskProcessingApiDeleteTaskResponseApplicationJsonInterface class sealed

Implementers
Annotations
  • @BuiltValue.new(instantiable: false)

Properties

hashCode → int
The hash code for this object.
no setterinherited
ocs → TaskProcessingApiDeleteTaskResponseApplicationJson_Ocs
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(void updates($TaskProcessingApiDeleteTaskResponseApplicationJsonInterfaceBuilder)) → $TaskProcessingApiDeleteTaskResponseApplicationJsonInterface
Rebuilds the instance.
toBuilder() → $TaskProcessingApiDeleteTaskResponseApplicationJsonInterfaceBuilder
Converts the instance to a builder $TaskProcessingApiDeleteTaskResponseApplicationJsonInterfaceBuilder.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited