$TaskProcessingApiScheduleRequestApplicationJsonInterface class sealed

Implementers
Annotations
  • @BuiltValue.new(instantiable: false)

Properties

appId → String
ID of the app that will execute the task.
no setter
customId → String
An arbitrary identifier for the task.
no setter
hashCode → int
The hash code for this object.
no setterinherited
input → BuiltMap<String, JsonObject>
Task's input parameters.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → String
Type of the task.
no setter
webhookMethod → String?
Method used for the webhook request (HTTP:GET, HTTP:POST, HTTP:PUT, HTTP:DELETE or AppAPI:APP_ID:GET, AppAPI:APP_ID:POST...).
no setter
webhookUri → String?
URI to be requested when the task finishes.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(void updates($TaskProcessingApiScheduleRequestApplicationJsonInterfaceBuilder)) → $TaskProcessingApiScheduleRequestApplicationJsonInterface
Rebuilds the instance.
toBuilder() → $TaskProcessingApiScheduleRequestApplicationJsonInterfaceBuilder
Converts the instance to a builder $TaskProcessingApiScheduleRequestApplicationJsonInterfaceBuilder.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited