$TaskProcessingTaskInterface class sealed

Implementers
Annotations
  • @BuiltValue.new(instantiable: false)

Properties

appId → String
no setter
completionExpectedAt → int?
no setter
customId → String?
no setter
endedAt → int?
no setter
hashCode → int
The hash code for this object.
no setterinherited
id → int
no setter
input → BuiltMap<String, TaskProcessingIO>
no setter
lastUpdated → int
no setter
output → BuiltMap<String, TaskProcessingIO>?
no setter
progress → double?
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scheduledAt → int?
no setter
startedAt → int?
no setter
status → TaskProcessingTask_Status
no setter
type → String
no setter
userId → String?
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(void updates($TaskProcessingTaskInterfaceBuilder)) → $TaskProcessingTaskInterface
Rebuilds the instance.
toBuilder() → $TaskProcessingTaskInterfaceBuilder
Converts the instance to a builder $TaskProcessingTaskInterfaceBuilder.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited