$TeamResourceInterface class sealed

Implementers
Annotations
  • @BuiltValue.new(instantiable: false)

Properties

hashCode → int
The hash code for this object.
no setterinherited
iconEmoji → String?
no setter
iconSvg → String?
no setter
iconURL → String?
no setter
id → int
no setter
label → String
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
url → String
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(void updates($TeamResourceInterfaceBuilder)) → $TeamResourceInterface
Rebuilds the instance.
toBuilder() → $TeamResourceInterfaceBuilder
Converts the instance to a builder $TeamResourceInterfaceBuilder.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited