rebuild abstract method

Rebuilds the instance.

The result is the same as this instance but with updates applied. updates is a function that takes a builder $TermsOfServicePublicCapabilities_TermsOfServiceInterfaceBuilder.

Implementation

$TermsOfServicePublicCapabilities_TermsOfServiceInterface rebuild(
  void Function($TermsOfServicePublicCapabilities_TermsOfServiceInterfaceBuilder) updates,
);