schedule method
This endpoint allows scheduling a language model task.
Returns a Future containing a DynamiteResponse with the status code, deserialized body and headers.
Throws a DynamiteApiException if the API call does not return an expected status code.
Parameters:
inputInput text.typeType of the task.appIdID of the app that will execute the task.identifierAn arbitrary identifier for the task. Defaults to''.oCSAPIRequestRequired to be true for the API request to pass. Defaults totrue.
Status codes:
- 200: Task scheduled successfully
- 500
- 400: Scheduling task is not possible
- 412: Scheduling task is not possible
See:
- scheduleRaw for an experimental operation that returns a
DynamiteRawResponsethat can be serialized.
Implementation
Future<_i1.DynamiteResponse<TextProcessingApiScheduleResponseApplicationJson, void>> schedule({
required String input,
required String type,
required String appId,
String? identifier,
bool? oCSAPIRequest,
}) async {
final rawResponse = scheduleRaw(
input: input,
type: type,
appId: appId,
identifier: identifier,
oCSAPIRequest: oCSAPIRequest,
);
return rawResponse.future;
}