scheduleRaw method
- @experimental
This endpoint allows scheduling a language model task.
This method and the response it returns is experimental. The API might change without a major version bump.
Returns a Future containing a DynamiteRawResponse with the raw HttpClientResponse and serialization helpers.
Throws a DynamiteApiException if the API call does not return an expected status code.
Parameters:
inputInput text.typeType of the task.appIdID of the app that will execute the task.identifierAn arbitrary identifier for the task. Defaults to''.oCSAPIRequestRequired to be true for the API request to pass. Defaults totrue.
Status codes:
- 200: Task scheduled successfully
- 500
- 400: Scheduling task is not possible
- 412: Scheduling task is not possible
See:
- schedule for an operation that returns a
DynamiteResponsewith a stable API.
Implementation
@_i4.experimental
_i1.DynamiteRawResponse<TextProcessingApiScheduleResponseApplicationJson, void> scheduleRaw({
required String input,
required String type,
required String appId,
String? identifier,
bool? oCSAPIRequest,
}) {
final _parameters = <String, dynamic>{};
final _headers = <String, String>{'Accept': 'application/json'};
// coverage:ignore-start
final authentication = _rootClient.authentications?.firstWhereOrNull(
(auth) => switch (auth) {
_i1.DynamiteHttpBearerAuthentication() || _i1.DynamiteHttpBasicAuthentication() => true,
_ => false,
},
);
if (authentication != null) {
_headers.addAll(
authentication.headers,
);
}
// coverage:ignore-end
final $input = _$jsonSerializers.serialize(input, specifiedType: const FullType(String));
_parameters['input'] = $input;
final $type = _$jsonSerializers.serialize(type, specifiedType: const FullType(String));
_parameters['type'] = $type;
final $appId = _$jsonSerializers.serialize(appId, specifiedType: const FullType(String));
_parameters['appId'] = $appId;
var $identifier = _$jsonSerializers.serialize(identifier, specifiedType: const FullType(String));
$identifier ??= '';
_parameters['identifier'] = $identifier;
var $oCSAPIRequest = _$jsonSerializers.serialize(oCSAPIRequest, specifiedType: const FullType(bool));
$oCSAPIRequest ??= true;
_headers['OCS-APIRequest'] = const _i2.HeaderEncoder().convert($oCSAPIRequest);
final _path =
_i3.UriTemplate('/ocs/v2.php/textprocessing/schedule{?input*,type*,appId*,identifier*}').expand(_parameters);
return _i1.DynamiteRawResponse<TextProcessingApiScheduleResponseApplicationJson, void>(
response: _rootClient.executeRequest(
'post',
_path,
headers: _headers,
validStatuses: const {200},
),
bodyType: const FullType(TextProcessingApiScheduleResponseApplicationJson),
headersType: null,
serializers: _$jsonSerializers,
);
}