$TextProcessingApiScheduleRequestApplicationJsonInterface class sealed

Implementers
Annotations
  • @BuiltValue.new(instantiable: false)

Properties

appId → String
ID of the app that will execute the task.
no setter
hashCode → int
The hash code for this object.
no setterinherited
identifier → String
An arbitrary identifier for the task.
no setter
input → String
Input text.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → String
Type of the task.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(void updates($TextProcessingApiScheduleRequestApplicationJsonInterfaceBuilder)) → $TextProcessingApiScheduleRequestApplicationJsonInterface
Rebuilds the instance.
toBuilder() → $TextProcessingApiScheduleRequestApplicationJsonInterfaceBuilder
Converts the instance to a builder $TextProcessingApiScheduleRequestApplicationJsonInterfaceBuilder.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited