getImage method
This endpoint allows downloading the resulting image of a task.
Returns a Future containing a DynamiteResponse with the status code, deserialized body and headers.
Throws a DynamiteApiException if the API call does not return an expected status code.
Parameters:
idThe id of the task.indexThe index of the image to retrieve.oCSAPIRequestRequired to be true for the API request to pass. Defaults totrue.
Status codes:
- 200: Image returned
- 404: Task or image not found
- 500
See:
- getImageRaw for an experimental operation that returns a
DynamiteRawResponsethat can be serialized.
Implementation
Future<_i1.DynamiteResponse<Uint8List, void>> getImage({
required int id,
required int index,
bool? oCSAPIRequest,
}) async {
final rawResponse = getImageRaw(
id: id,
index: index,
oCSAPIRequest: oCSAPIRequest,
);
return rawResponse.future;
}