getTask method
This endpoint allows checking the status and results of a task. Tasks are removed 1 week after receiving their last update.
Returns a Future containing a DynamiteResponse with the status code, deserialized body and headers.
Throws a DynamiteApiException if the API call does not return an expected status code.
Parameters:
idThe id of the task.oCSAPIRequestRequired to be true for the API request to pass. Defaults totrue.
Status codes:
- 200: Task returned
- 404: Task not found
- 500
See:
- getTaskRaw for an experimental operation that returns a
DynamiteRawResponsethat can be serialized.
Implementation
Future<_i1.DynamiteResponse<TextToImageApiGetTaskResponseApplicationJson, void>> getTask({
required int id,
bool? oCSAPIRequest,
}) async {
final rawResponse = getTaskRaw(
id: id,
oCSAPIRequest: oCSAPIRequest,
);
return rawResponse.future;
}