$TextToImageTaskInterface class sealed

Implementers
Annotations
  • @BuiltValue.new(instantiable: false)

Properties

appId → String
no setter
completionExpectedAt → int?
no setter
hashCode → int
The hash code for this object.
no setterinherited
id → int?
no setter
identifier → String?
no setter
input → String
no setter
numberOfImages → int
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
status → TextToImageTask_Status
no setter
userId → String?
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(void updates($TextToImageTaskInterfaceBuilder)) → $TextToImageTaskInterface
Rebuilds the instance.
toBuilder() → $TextToImageTaskInterfaceBuilder
Converts the instance to a builder $TextToImageTaskInterfaceBuilder.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited