$TwoFactorApiClient class

Constructors

$TwoFactorApiClient($Client _rootClient)
Creates a new DynamiteClient for two_factor_api requests.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

$disable_Request({required TwoFactorApiDisableRequestApplicationJson $body, bool? oCSAPIRequest}) → Request
Disable two factor authentication providers for specific user.
$disable_Serializer() → DynamiteSerializer<TwoFactorApiDisableResponseApplicationJson, void>
Builds a serializer to parse the response of $disable_Request.
$enable_Request({required TwoFactorApiEnableRequestApplicationJson $body, bool? oCSAPIRequest}) → Request
Enable two factor authentication providers for specific user.
$enable_Serializer() → DynamiteSerializer<TwoFactorApiEnableResponseApplicationJson, void>
Builds a serializer to parse the response of $enable_Request.
$state_Request({required String user, bool? oCSAPIRequest}) → Request
Get two factor authentication provider states.
$state_Serializer() → DynamiteSerializer<TwoFactorApiStateResponseApplicationJson, void>
Builds a serializer to parse the response of $state_Request.
disable({required TwoFactorApiDisableRequestApplicationJson $body, bool? oCSAPIRequest}) Future<DynamiteResponse<TwoFactorApiDisableResponseApplicationJson, void>>
Disable two factor authentication providers for specific user.
enable({required TwoFactorApiEnableRequestApplicationJson $body, bool? oCSAPIRequest}) Future<DynamiteResponse<TwoFactorApiEnableResponseApplicationJson, void>>
Enable two factor authentication providers for specific user.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
state({required String user, bool? oCSAPIRequest}) Future<DynamiteResponse<TwoFactorApiStateResponseApplicationJson, void>>
Get two factor authentication provider states.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited