$disable_Request method
- @experimental
- required TwoFactorApiDisableRequestApplicationJson $body,
- bool? oCSAPIRequest,
Disable two factor authentication providers for specific user.
This endpoint requires admin access.
Returns a DynamiteRequest backing the disable operation.
Throws a DynamiteApiException if the API call does not return an expected status code.
Parameters:
oCSAPIRequestRequired to be true for the API request to pass. Defaults totrue.
Status codes:
- 200: provider states
- 404: user not found
See:
- disable for a method executing this request and parsing the response.
- $disable_Serializer for a converter to parse the
Responsefrom an executed this request.
Implementation
@_i2.experimental
_i3.Request $disable_Request({required TwoFactorApiDisableRequestApplicationJson $body, bool? oCSAPIRequest}) {
const _path = '/ocs/v2.php/twofactor/disable';
final _uri = Uri.parse('${_rootClient.baseURL}$_path');
final _request = _i3.Request('post', _uri);
_request.headers['Accept'] = 'application/json';
// coverage:ignore-start
final authentication = _i4.IterableExtension(_rootClient.authentications)?.firstWhereOrNull(
(auth) => switch (auth) {
_i1.DynamiteHttpBearerAuthentication() || _i1.DynamiteHttpBasicAuthentication() => true,
_ => false,
},
);
if (authentication != null) {
_request.headers.addAll(authentication.headers);
} else {
throw Exception('Missing authentication for bearer_auth or basic_auth');
}
// coverage:ignore-end
var __oCSAPIRequest = _$jsonSerializers.serialize(oCSAPIRequest, specifiedType: const FullType(bool));
__oCSAPIRequest ??= true;
_request.headers['OCS-APIRequest'] = const _i5.HeaderEncoder().convert(__oCSAPIRequest);
_request.headers['Content-Type'] = 'application/json';
_request.body = json.encode(
_$jsonSerializers.serialize($body, specifiedType: const FullType(TwoFactorApiDisableRequestApplicationJson)),
);
return _request;
}