$state_Request method
Get two factor authentication provider states.
This endpoint requires admin access.
Returns a DynamiteRequest backing the state operation.
Throws a DynamiteApiException if the API call does not return an expected status code.
Parameters:
usersystem user id.oCSAPIRequestRequired to be true for the API request to pass. Defaults totrue.
Status codes:
- 200: provider states
- 404: user not found
See:
- state for a method executing this request and parsing the response.
- $state_Serializer for a converter to parse the
Responsefrom an executed this request.
Implementation
@_i2.experimental
_i3.Request $state_Request({required String user, bool? oCSAPIRequest}) {
final _parameters = <String, Object?>{};
final __user = _$jsonSerializers.serialize(user, specifiedType: const FullType(String));
_parameters['user'] = __user;
final _path = _i6.UriTemplate('/ocs/v2.php/twofactor/state{?user*}').expand(_parameters);
final _uri = Uri.parse('${_rootClient.baseURL}$_path');
final _request = _i3.Request('get', _uri);
_request.headers['Accept'] = 'application/json';
// coverage:ignore-start
final authentication = _i4.IterableExtension(_rootClient.authentications)?.firstWhereOrNull(
(auth) => switch (auth) {
_i1.DynamiteHttpBearerAuthentication() || _i1.DynamiteHttpBasicAuthentication() => true,
_ => false,
},
);
if (authentication != null) {
_request.headers.addAll(authentication.headers);
} else {
throw Exception('Missing authentication for bearer_auth or basic_auth');
}
// coverage:ignore-end
var __oCSAPIRequest = _$jsonSerializers.serialize(oCSAPIRequest, specifiedType: const FullType(bool));
__oCSAPIRequest ??= true;
_request.headers['OCS-APIRequest'] = const _i5.HeaderEncoder().convert(__oCSAPIRequest);
return _request;
}