disable method
Future<DynamiteResponse<TwoFactorApiDisableResponseApplicationJson, void> >
disable({
- required TwoFactorApiDisableRequestApplicationJson $body,
- bool? oCSAPIRequest,
Disable two factor authentication providers for specific user.
This endpoint requires admin access.
Returns a Future containing a DynamiteResponse with the status code, deserialized body and headers.
Throws a DynamiteApiException if the API call does not return an expected status code.
Parameters:
oCSAPIRequestRequired to be true for the API request to pass. Defaults totrue.
Status codes:
- 200: provider states
- 404: user not found
See:
- $disable_Request for the request send by this method.
- $disable_Serializer for a converter to parse the
Responsefrom an executed request.
Implementation
Future<_i1.DynamiteResponse<TwoFactorApiDisableResponseApplicationJson, void>> disable({
required TwoFactorApiDisableRequestApplicationJson $body,
bool? oCSAPIRequest,
}) async {
final _request = $disable_Request(oCSAPIRequest: oCSAPIRequest, $body: $body);
final _streamedResponse = await _rootClient.httpClient.send(_request);
final _response = await _i3.Response.fromStream(_streamedResponse);
final _serializer = $disable_Serializer();
return _i1.ResponseConverter<TwoFactorApiDisableResponseApplicationJson, void>(_serializer).convert(_response);
}