enable method

Enable two factor authentication providers for specific user.

This endpoint requires admin access.

Returns a Future containing a DynamiteResponse with the status code, deserialized body and headers. Throws a DynamiteApiException if the API call does not return an expected status code.

Parameters:

  • oCSAPIRequest Required to be true for the API request to pass. Defaults to true.

Status codes:

  • 200: provider states
  • 404: user not found

See:

Implementation

Future<_i1.DynamiteResponse<TwoFactorApiEnableResponseApplicationJson, void>> enable({
  required TwoFactorApiEnableRequestApplicationJson $body,
  bool? oCSAPIRequest,
}) async {
  final _request = $enable_Request(oCSAPIRequest: oCSAPIRequest, $body: $body);
  final _streamedResponse = await _rootClient.httpClient.send(_request);
  final _response = await _i3.Response.fromStream(_streamedResponse);

  final _serializer = $enable_Serializer();
  return _i1.ResponseConverter<TwoFactorApiEnableResponseApplicationJson, void>(_serializer).convert(_response);
}