state method
Get two factor authentication provider states.
This endpoint requires admin access.
Returns a Future containing a DynamiteResponse with the status code, deserialized body and headers.
Throws a DynamiteApiException if the API call does not return an expected status code.
Parameters:
usersystem user id.oCSAPIRequestRequired to be true for the API request to pass. Defaults totrue.
Status codes:
- 200: provider states
- 404: user not found
See:
- $state_Request for the request send by this method.
- $state_Serializer for a converter to parse the
Responsefrom an executed request.
Implementation
Future<_i1.DynamiteResponse<TwoFactorApiStateResponseApplicationJson, void>> state({
required String user,
bool? oCSAPIRequest,
}) async {
final _request = $state_Request(user: user, oCSAPIRequest: oCSAPIRequest);
final _streamedResponse = await _rootClient.httpClient.send(_request);
final _response = await _i3.Response.fromStream(_streamedResponse);
final _serializer = $state_Serializer();
return _i1.ResponseConverter<TwoFactorApiStateResponseApplicationJson, void>(_serializer).convert(_response);
}