rebuild abstract method
Rebuilds the instance.
The result is the same as this instance but with updates applied.
updates is a function that takes a builder $TwoFactorApiEnableResponseApplicationJson_OcsInterfaceBuilder.
Implementation
$TwoFactorApiEnableResponseApplicationJson_OcsInterface rebuild(
void Function($TwoFactorApiEnableResponseApplicationJson_OcsInterfaceBuilder) updates,
);