getProviders method
Get the providers for unified search.
Returns a Future containing a DynamiteResponse with the status code, deserialized body and headers.
Throws a DynamiteApiException if the API call does not return an expected status code.
Parameters:
fromthe url the user is currently at. Defaults to''.oCSAPIRequestRequired to be true for the API request to pass. Defaults totrue.
Status codes:
- 200: Providers returned
See:
- getProvidersRaw for an experimental operation that returns a
DynamiteRawResponsethat can be serialized.
Implementation
Future<_i1.DynamiteResponse<UnifiedSearchGetProvidersResponseApplicationJson, void>> getProviders({
String? from,
bool? oCSAPIRequest,
}) async {
final rawResponse = getProvidersRaw(
from: from,
oCSAPIRequest: oCSAPIRequest,
);
return rawResponse.future;
}