$UnifiedSearchProviderInterface class sealed

Implementers
Annotations
  • @BuiltValue.new(instantiable: false)

Properties

appId → String
no setter
filters → BuiltMap<String, String>
no setter
hashCode → int
The hash code for this object.
no setterinherited
icon → String
no setter
id → String
no setter
inAppSearch → bool
no setter
name → String
no setter
order → int
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
triggers → BuiltList<String>
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(void updates($UnifiedSearchProviderInterfaceBuilder)) → $UnifiedSearchProviderInterface
Rebuilds the instance.
toBuilder() → $UnifiedSearchProviderInterfaceBuilder
Converts the instance to a builder $UnifiedSearchProviderInterfaceBuilder.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited