$UserStatusCapabilitiesInterface class sealed

Implementers
Annotations
  • @BuiltValue.new(instantiable: false)

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
userStatus → UserStatusCapabilities_UserStatus
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(void updates($UserStatusCapabilitiesInterfaceBuilder)) → $UserStatusCapabilitiesInterface
Rebuilds the instance.
toBuilder() → $UserStatusCapabilitiesInterfaceBuilder
Converts the instance to a builder $UserStatusCapabilitiesInterfaceBuilder.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited