$WhatsNewGetResponseApplicationJson_Ocs_DataInterface class sealed

Implementers
Annotations
  • @BuiltValue.new(instantiable: false)

Properties

changelogURL → String
no setter
hashCode → int
The hash code for this object.
no setterinherited
product → String
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
version → String
no setter
whatsNew → WhatsNewGetResponseApplicationJson_Ocs_Data_WhatsNew?
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(void updates($WhatsNewGetResponseApplicationJson_Ocs_DataInterfaceBuilder)) → $WhatsNewGetResponseApplicationJson_Ocs_DataInterface
Rebuilds the instance.
toBuilder() → $WhatsNewGetResponseApplicationJson_Ocs_DataInterfaceBuilder
Converts the instance to a builder $WhatsNewGetResponseApplicationJson_Ocs_DataInterfaceBuilder.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited