wipeDone method
Finish the wipe.
Returns a Future containing a DynamiteResponse with the status code, deserialized body and headers.
Throws a DynamiteApiException if the API call does not return an expected status code.
Parameters:
tokenApp password.
Status codes:
- 200: Wipe finished successfully
- 404: Device should not be wiped
See:
- wipeDoneRaw for an experimental operation that returns a
DynamiteRawResponsethat can be serialized.
Implementation
Future<_i1.DynamiteResponse<JsonObject, void>> wipeDone({required String token}) async {
final rawResponse = wipeDoneRaw(
token: token,
);
return rawResponse.future;
}