AutocompleteResult class abstract

Implemented types

Constructors

AutocompleteResult([void b(AutocompleteResultBuilder)?])
Creates a new AutocompleteResult object using the builder pattern.
factory
AutocompleteResult.fromJson(Map<String, dynamic> json)
Creates a new object from the given json data.
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
icon → String
no setterinherited
id → String
no setterinherited
label → String
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
shareWithDisplayNameUnique → String
no setterinherited
source → String
no setterinherited
status → AutocompleteResult_Status
no setterinherited
subline → String
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(AutocompleteResultBuilder)) → AutocompleteResult
Rebuilds the instance.
inherited
toBuilder() → AutocompleteResultBuilder
Converts the instance to a builder B.
inherited
toJson() → Map<String, dynamic>
Parses this object into a json like map.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

serializer → Serializer<AutocompleteResult>
Serializer for AutocompleteResult.
no setter