AutocompleteResult_Status0 class abstract

Implemented types

Constructors

AutocompleteResult_Status0([void b(AutocompleteResult_Status0Builder)?])
Creates a new AutocompleteResult_Status0 object using the builder pattern.
factory
AutocompleteResult_Status0.fromJson(Map<String, dynamic> json)
Creates a new object from the given json data.
factory

Properties

clearAt → int?
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
icon → String?
no setterinherited
message → String?
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
status → String
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(AutocompleteResult_Status0Builder)) → AutocompleteResult_Status0
Rebuilds the instance.
inherited
toBuilder() → AutocompleteResult_Status0Builder
Converts the instance to a builder B.
inherited
toJson() → Map<String, dynamic>
Parses this object into a json like map.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

serializer → Serializer<AutocompleteResult_Status0>
Serializer for AutocompleteResult_Status0.
no setter