CoreCapabilities_CoreBuilder class

Implemented types

Properties

hashCode → int
The hash code for this object.
no setterinherited
modRewriteWorking ↔ bool?
covariantgetter/setter pairoverride
pollinterval ↔ int?
covariantgetter/setter pairoverride
referenceApi ↔ bool?
covariantgetter/setter pairoverride
referenceRegex ↔ String?
covariantgetter/setter pairoverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
webdavRoot ↔ String?
covariantgetter/setter pairoverride

Methods

build() → CoreCapabilities_Core
Builds.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
replace(covariant CoreCapabilities_Core other) → void
Replaces the value in the builder with a new one.
override
toString() → String
A string representation of this object.
inherited
update(void updates(CoreCapabilities_CoreBuilder)?) → void
Applies updates.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited