DavCapabilities_Dav class abstract

Implemented types

Constructors

DavCapabilities_Dav([void b(DavCapabilities_DavBuilder)?])
Creates a new DavCapabilities_Dav object using the builder pattern.
factory
DavCapabilities_Dav.fromJson(Map<String, dynamic> json)
Creates a new object from the given json data.
factory

Properties

absenceReplacement bool?
no setterinherited
absenceSupported bool?
no setterinherited
bulkupload String?
no setterinherited
chunking String
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(DavCapabilities_DavBuilder)) DavCapabilities_Dav
Rebuilds the instance.
inherited
toBuilder() DavCapabilities_DavBuilder
Converts the instance to a builder B.
inherited
toJson() Map<String, dynamic>
Parses this object into a json like map.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

serializer → Serializer<DavCapabilities_Dav>
Serializer for DavCapabilities_Dav.
no setter