FilesCapabilities_Files_FileConversions class abstract

Implemented types

Constructors

FilesCapabilities_Files_FileConversions([void b(FilesCapabilities_Files_FileConversionsBuilder)?])
Creates a new FilesCapabilities_Files_FileConversions object using the builder pattern.
factory
FilesCapabilities_Files_FileConversions.fromJson(Map<String, dynamic> json)
Creates a new object from the given json data.
factory

Properties

$extension → String
no setterinherited
displayName → String
no setterinherited
from → String
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
to → String
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(FilesCapabilities_Files_FileConversionsBuilder)) → FilesCapabilities_Files_FileConversions
Rebuilds the instance.
inherited
toBuilder() → FilesCapabilities_Files_FileConversionsBuilder
Converts the instance to a builder B.
inherited
toJson() → Map<String, dynamic>
Parses this object into a json like map.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

serializer → Serializer<FilesCapabilities_Files_FileConversions>
Serializer for FilesCapabilities_Files_FileConversions.
no setter