LoginFlowV2_Poll class abstract

Implemented types

Constructors

LoginFlowV2_Poll([void b(LoginFlowV2_PollBuilder)?])
factory
LoginFlowV2_Poll.fromJson(Map<String, dynamic> json)
factory

Properties

endpoint String
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
token String
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(LoginFlowV2_PollBuilder)) LoginFlowV2_Poll
Rebuilds the instance.
inherited
toBuilder() LoginFlowV2_PollBuilder
Converts the instance to a builder B.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

serializer → Serializer<LoginFlowV2_Poll>
no setter