NavigationEntry class abstract

Implemented types

Constructors

Creates a new NavigationEntry object using the builder pattern.
factory
Creates a new object from the given json data.
factory

Properties

$default → bool?
no setterinherited
active → bool
no setterinherited
app → String?
no setterinherited
classes → String
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
href → String
no setterinherited
icon → String
no setterinherited
id → String
no setterinherited
name → String
no setterinherited
order → int?
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → String
no setterinherited
unread → int
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(NavigationEntryBuilder)) → NavigationEntry
Rebuilds the instance.
inherited
toBuilder() → NavigationEntryBuilder
Converts the instance to a builder B.
inherited
toJson() → Map<String, dynamic>
Parses this object into a json like map.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

serializer → Serializer<NavigationEntry>
Serializer for NavigationEntry.
no setter