OcmOcmDiscoveryHeaders class abstract

Implemented types

Constructors

OcmOcmDiscoveryHeaders([void b(OcmOcmDiscoveryHeadersBuilder)?])
Creates a new OcmOcmDiscoveryHeaders object using the builder pattern.
factory
OcmOcmDiscoveryHeaders.fromJson(Map<String, dynamic> json)
Creates a new object from the given json data.
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
xNextcloudOcmProviders → Header<OcmOcmDiscoveryHeaders_XNextcloudOcmProviders?>?
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(OcmOcmDiscoveryHeadersBuilder)) → OcmOcmDiscoveryHeaders
Rebuilds the instance.
inherited
toBuilder() → OcmOcmDiscoveryHeadersBuilder
Converts the instance to a builder B.
inherited
toJson() → Map<String, dynamic>
Parses this object into a json like map.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

serializer → Serializer<OcmOcmDiscoveryHeaders>
Serializer for OcmOcmDiscoveryHeaders.
no setter