OpenGraphObject class abstract

Implemented types

Constructors

OpenGraphObject([void b(OpenGraphObjectBuilder)?])
Creates a new OpenGraphObject object using the builder pattern.
factory
OpenGraphObject.fromJson(Map<String, dynamic> json)
Creates a new object from the given json data.
factory

Properties

description → String?
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
id → String
no setterinherited
no setterinherited
name → String
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
thumb → String?
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(OpenGraphObjectBuilder)) → OpenGraphObject
Rebuilds the instance.
inherited
toBuilder() → OpenGraphObjectBuilder
Converts the instance to a builder B.
inherited
toJson() → Map<String, dynamic>
Parses this object into a json like map.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

serializer → Serializer<OpenGraphObject>
Serializer for OpenGraphObject.
no setter