PasswordPolicyCapabilities_PasswordPolicy_PoliciesBuilder class

Implemented types

Properties

enforceHaveIBeenPwned ↔ bool?
covariantgetter/setter pairoverride
enforceNonCommonPassword ↔ bool?
covariantgetter/setter pairoverride
enforceNumericCharacters ↔ bool?
covariantgetter/setter pairoverride
enforceSpecialCharacters ↔ bool?
covariantgetter/setter pairoverride
enforceUpperLowerCase ↔ bool?
covariantgetter/setter pairoverride
hashCode → int
The hash code for this object.
no setterinherited
minLength ↔ int?
covariantgetter/setter pairoverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

build() → PasswordPolicyCapabilities_PasswordPolicy_Policies
Builds.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
replace(covariant PasswordPolicyCapabilities_PasswordPolicy_Policies other) → void
Replaces the value in the builder with a new one.
override
toString() → String
A string representation of this object.
inherited
update(void updates(PasswordPolicyCapabilities_PasswordPolicy_PoliciesBuilder)?) → void
Applies updates.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited