replace method

  1. @override
void replace(
  1. covariant PasswordPolicyCapabilities_PasswordPolicy_Policies other
)
override

Replaces the value in the builder with a new one.

The implementation of this method will be generated for you by the built_value generator.

Implementation

@override
void replace(covariant PasswordPolicyCapabilities_PasswordPolicy_Policies other) {
  _$v = other as _$PasswordPolicyCapabilities_PasswordPolicy_Policies;
}