ProfileAction class abstract

Implemented types

Constructors

ProfileAction([void b(ProfileActionBuilder)?])
Creates a new ProfileAction object using the builder pattern.
factory
ProfileAction.fromJson(Map<String, dynamic> json)
Creates a new object from the given json data.
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
icon String
no setterinherited
id String
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
target String?
no setterinherited
title String
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(ProfileActionBuilder)) ProfileAction
Rebuilds the instance.
inherited
toBuilder() ProfileActionBuilder
Converts the instance to a builder B.
inherited
toJson() Map<String, dynamic>
Parses this object into a json like map.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

serializer → Serializer<ProfileAction>
Serializer for ProfileAction.
no setter