ReferenceApiResolvePublicRequestApplicationJson class abstract

Implemented types

Constructors

ReferenceApiResolvePublicRequestApplicationJson([void b(ReferenceApiResolvePublicRequestApplicationJsonBuilder)?])
Creates a new ReferenceApiResolvePublicRequestApplicationJson object using the builder pattern.
factory
ReferenceApiResolvePublicRequestApplicationJson.fromJson(Map<String, dynamic> json)
Creates a new object from the given json data.
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
limit → int
Maximum amount of references to resolve, limited to 15.
no setterinherited
references → BuiltList<String>
References to resolve.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sharingToken → String
Token of the public share.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(ReferenceApiResolvePublicRequestApplicationJsonBuilder)) → ReferenceApiResolvePublicRequestApplicationJson
Rebuilds the instance.
inherited
toBuilder() → ReferenceApiResolvePublicRequestApplicationJsonBuilder
Converts the instance to a builder B.
inherited
toJson() → Map<String, dynamic>
Parses this object into a json like map.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

serializer → Serializer<ReferenceApiResolvePublicRequestApplicationJson>
Serializer for ReferenceApiResolvePublicRequestApplicationJson.
no setter