Resource class abstract

Implemented types

Constructors

Resource([void b(ResourceBuilder)?])
Creates a new Resource object using the builder pattern.
factory
Resource.fromJson(Map<String, dynamic> json)
Creates a new object from the given json data.
factory

Properties

accessible → bool
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
openGraphObject → OpenGraphObject
no setterinherited
richObject → BuiltMap<String, JsonObject?>
no setterinherited
richObjectType → String
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(ResourceBuilder)) → Resource
Rebuilds the instance.
inherited
toBuilder() → ResourceBuilder
Converts the instance to a builder B.
inherited
toJson() → Map<String, dynamic>
Parses this object into a json like map.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

serializer → Serializer<Resource>
Serializer for Resource.
no setter