RichObjectParameter class abstract

Implemented types

Constructors

RichObjectParameter([void b(RichObjectParameterBuilder)?])
Creates a new RichObjectParameter object using the builder pattern.
factory
RichObjectParameter.fromJson(Map<String, dynamic> json)
Creates a new object from the given json data.
factory

Properties

assignable → String?
If the user can assign the systemtag.
no setterinherited
blurhash → String?
The blurhash of the image.
no setterinherited
boardname → String?
The display name of board which contains the card.
no setterinherited
callType → String?
The type of the call: one2one, group or public.
no setterinherited
conversation → String?
The token of the conversation.
no setterinherited
description → String?
The open graph description from the website.
no setterinherited
etag → String?
The ETag of the file/folder.
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
height → String?
The height in pixels if the file is an image.
no setterinherited
hideDownload → String?
Whether the download option should be hidden. If not set to yes the option can be shown.
no setterinherited
iconUrl → String?
The icon url to use as avatar.
no setterinherited
id → String
no setterinherited
latitude → String?
The latitude of the location MUST be the same as in the id.
no setterinherited
The full URL to the file.
no setterinherited
longitude → String?
The longitude of the location MUST be the same as in the id.
no setterinherited
messageId → String?
The id of a message that was referred to.
no setterinherited
mimetype → String?
The mimetype of the file/folder to allow clients to show a placeholder.
no setterinherited
mtime → String?
The mtime of the file/folder as unix timestamp.
no setterinherited
name → String
no setterinherited
path → String?
The full path of the file for the user, should not start with a slash.
no setterinherited
permissions → String?
The permissions on the file/folder.
no setterinherited
previewAvailable → String?
Whether or not a preview is available. If no the mimetype icon should be used.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
server → String?
The URL of the instance the user lives on.
no setterinherited
size → String?
The file size in bytes.
no setterinherited
stackname → String?
The display name of the stack which contains the card in the board.
no setterinherited
thumb → String?
The full URL of the open graph thumbnail.
no setterinherited
type → RichObjectParameter_Type
no setterinherited
visibility → String?
If the user can see the systemtag.
no setterinherited
website → String?
The name of the described website.
no setterinherited
width → String?
The width in pixels if the file is an image.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(RichObjectParameterBuilder)) → RichObjectParameter
Rebuilds the instance.
inherited
toBuilder() → RichObjectParameterBuilder
Converts the instance to a builder B.
inherited
toJson() → Map<String, dynamic>
Parses this object into a json like map.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

serializer → Serializer<RichObjectParameter>
Serializer for RichObjectParameter.
no setter