ShareType enum

Inheritance
Available extensions

Values

user → const ShareType
group → const ShareType
usergroup → const ShareType
email → const ShareType
contact → const ShareType
remote → const ShareType
circle → const ShareType
guest → const ShareType
remoteGroup → const ShareType
room → const ShareType
userroom → const ShareType
deck → const ShareType
deckUser → const ShareType
_unused → const ShareType
scienceMesh → const ShareType

Properties

binary → int

Available on Enum, provided by the EnumBinary extension

Gets the binary representation of the index.
no setter
hashCode → int
The hash code for this object.
no setterinherited
index → int
A numeric identifier for the enumerated value.
no setterinherited
name → String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

values → const List<ShareType>
A constant List of the values in this enum, in order of their declaration.