SharebymailCapabilities_FilesSharing class abstract

Implemented types

Constructors

SharebymailCapabilities_FilesSharing([void b(SharebymailCapabilities_FilesSharingBuilder)?])
Creates a new SharebymailCapabilities_FilesSharing object using the builder pattern.
factory
SharebymailCapabilities_FilesSharing.fromJson(Map<String, dynamic> json)
Creates a new object from the given json data.
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sharebymail SharebymailCapabilities_FilesSharing_Sharebymail
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(SharebymailCapabilities_FilesSharingBuilder)) SharebymailCapabilities_FilesSharing
Rebuilds the instance.
inherited
toBuilder() SharebymailCapabilities_FilesSharingBuilder
Converts the instance to a builder B.
inherited
toJson() Map<String, dynamic>
Parses this object into a json like map.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

serializer → Serializer<SharebymailCapabilities_FilesSharing>
Serializer for SharebymailCapabilities_FilesSharing.
no setter