SpreedCapabilities_Config_Conversations class abstract

Implemented types

Constructors

SpreedCapabilities_Config_Conversations([void b(SpreedCapabilities_Config_ConversationsBuilder)?])
Creates a new SpreedCapabilities_Config_Conversations object using the builder pattern.
factory
SpreedCapabilities_Config_Conversations.fromJson(Map<String, dynamic> json)
Creates a new object from the given json data.
factory

Properties

canCreate bool
no setterinherited
descriptionLength int?
no setterinherited
forcePasswords bool?
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
listStyle SpreedCapabilities_Config_Conversations_ListStyle?
no setterinherited
retentionEvent int?
no setterinherited
retentionInstantMeetings int?
no setterinherited
retentionPhone int?
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(SpreedCapabilities_Config_ConversationsBuilder)) SpreedCapabilities_Config_Conversations
Rebuilds the instance.
inherited
toBuilder() SpreedCapabilities_Config_ConversationsBuilder
Converts the instance to a builder B.
inherited
toJson() Map<String, dynamic>
Parses this object into a json like map.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

serializer → Serializer<SpreedCapabilities_Config_Conversations>
Serializer for SpreedCapabilities_Config_Conversations.
no setter