Status class abstract

Implemented types
Available extensions

Constructors

Status([void b(StatusBuilder)?])
Creates a new Status object using the builder pattern.
factory
Status.fromJson(Map<String, dynamic> json)
Creates a new object from the given json data.
factory

Properties

edition → String
no setterinherited
extendedSupport → bool
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
installed → bool
no setterinherited
maintenance → bool
no setterinherited
needsDbUpgrade → bool
no setterinherited
productname → String
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
version → String
no setterinherited
versionCheck → VersionCheck

Available on Status, provided by the CoreStatusVersionCheck extension

Check if the core/Server version is supported
no setter
versionstring → String
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(StatusBuilder)) → Status
Rebuilds the instance.
inherited
toBuilder() → StatusBuilder
Converts the instance to a builder B.
inherited
toJson() → Map<String, dynamic>
Parses this object into a json like map.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

serializer → Serializer<Status>
Serializer for Status.
no setter