TaskProcessingApiGetNextScheduledTaskResponseApplicationJson_Ocs_Data_Provider class abstract

Implemented types

Constructors

TaskProcessingApiGetNextScheduledTaskResponseApplicationJson_Ocs_Data_Provider([void b(TaskProcessingApiGetNextScheduledTaskResponseApplicationJson_Ocs_Data_ProviderBuilder)?])
Creates a new TaskProcessingApiGetNextScheduledTaskResponseApplicationJson_Ocs_Data_Provider object using the builder pattern.
factory
TaskProcessingApiGetNextScheduledTaskResponseApplicationJson_Ocs_Data_Provider.fromJson(Map<String, dynamic> json)
Creates a new object from the given json data.
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
name → String
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(TaskProcessingApiGetNextScheduledTaskResponseApplicationJson_Ocs_Data_ProviderBuilder)) → TaskProcessingApiGetNextScheduledTaskResponseApplicationJson_Ocs_Data_Provider
Rebuilds the instance.
inherited
toBuilder() → TaskProcessingApiGetNextScheduledTaskResponseApplicationJson_Ocs_Data_ProviderBuilder
Converts the instance to a builder B.
inherited
toJson() → Map<String, dynamic>
Parses this object into a json like map.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

serializer → Serializer<TaskProcessingApiGetNextScheduledTaskResponseApplicationJson_Ocs_Data_Provider>
Serializer for TaskProcessingApiGetNextScheduledTaskResponseApplicationJson_Ocs_Data_Provider.
no setter