TaskProcessingApiScheduleRequestApplicationJson class abstract

Implemented types

Constructors

TaskProcessingApiScheduleRequestApplicationJson([void b(TaskProcessingApiScheduleRequestApplicationJsonBuilder)?])
Creates a new TaskProcessingApiScheduleRequestApplicationJson object using the builder pattern.
factory
TaskProcessingApiScheduleRequestApplicationJson.fromJson(Map<String, dynamic> json)
Creates a new object from the given json data.
factory

Properties

appId → String
ID of the app that will execute the task.
no setterinherited
customId → String
An arbitrary identifier for the task.
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
input → BuiltMap<String, JsonObject>
Task's input parameters.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → String
Type of the task.
no setterinherited
webhookMethod → String?
Method used for the webhook request (HTTP:GET, HTTP:POST, HTTP:PUT, HTTP:DELETE or AppAPI:APP_ID:GET, AppAPI:APP_ID:POST...).
no setterinherited
webhookUri → String?
URI to be requested when the task finishes.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(TaskProcessingApiScheduleRequestApplicationJsonBuilder)) → TaskProcessingApiScheduleRequestApplicationJson
Rebuilds the instance.
inherited
toBuilder() → TaskProcessingApiScheduleRequestApplicationJsonBuilder
Converts the instance to a builder B.
inherited
toJson() → Map<String, dynamic>
Parses this object into a json like map.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

serializer → Serializer<TaskProcessingApiScheduleRequestApplicationJson>
Serializer for TaskProcessingApiScheduleRequestApplicationJson.
no setter