TaskProcessingApiScheduleRequestApplicationJsonBuilder class

Implemented types

Properties

appId ↔ String?
covariantgetter/setter pairoverride
customId ↔ String?
covariantgetter/setter pairoverride
hashCode → int
The hash code for this object.
no setterinherited
input ↔ MapBuilder<String, JsonObject>
covariantgetter/setter pairoverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type ↔ String?
covariantgetter/setter pairoverride
webhookMethod ↔ String?
covariantgetter/setter pairoverride
webhookUri ↔ String?
covariantgetter/setter pairoverride

Methods

build() → TaskProcessingApiScheduleRequestApplicationJson
Builds.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
replace(covariant TaskProcessingApiScheduleRequestApplicationJson other) → void
Replaces the value in the builder with a new one.
override
toString() → String
A string representation of this object.
inherited
update(void updates(TaskProcessingApiScheduleRequestApplicationJsonBuilder)?) → void
Applies updates.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited