TaskProcessingApiSetResultRequestApplicationJson class abstract

Implemented types

Constructors

TaskProcessingApiSetResultRequestApplicationJson([void b(TaskProcessingApiSetResultRequestApplicationJsonBuilder)?])
Creates a new TaskProcessingApiSetResultRequestApplicationJson object using the builder pattern.
factory
TaskProcessingApiSetResultRequestApplicationJson.fromJson(Map<String, dynamic> json)
Creates a new object from the given json data.
factory

Properties

errorMessage → String?
An error message if the task failed.
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
output → BuiltMap<String, JsonObject>?
The resulting task output, files are represented by their IDs.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(TaskProcessingApiSetResultRequestApplicationJsonBuilder)) → TaskProcessingApiSetResultRequestApplicationJson
Rebuilds the instance.
inherited
toBuilder() → TaskProcessingApiSetResultRequestApplicationJsonBuilder
Converts the instance to a builder B.
inherited
toJson() → Map<String, dynamic>
Parses this object into a json like map.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

serializer → Serializer<TaskProcessingApiSetResultRequestApplicationJson>
Serializer for TaskProcessingApiSetResultRequestApplicationJson.
no setter