TaskProcessingTask class abstract

Implemented types

Constructors

TaskProcessingTask([void b(TaskProcessingTaskBuilder)?])
Creates a new TaskProcessingTask object using the builder pattern.
factory
TaskProcessingTask.fromJson(Map<String, dynamic> json)
Creates a new object from the given json data.
factory

Properties

appId → String
no setterinherited
completionExpectedAt → int?
no setterinherited
customId → String?
no setterinherited
endedAt → int?
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
id → int
no setterinherited
input → BuiltMap<String, TaskProcessingIO>
no setterinherited
lastUpdated → int
no setterinherited
output → BuiltMap<String, TaskProcessingIO>?
no setterinherited
progress → double?
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scheduledAt → int?
no setterinherited
startedAt → int?
no setterinherited
status → TaskProcessingTask_Status
no setterinherited
type → String
no setterinherited
userId → String?
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(TaskProcessingTaskBuilder)) → TaskProcessingTask
Rebuilds the instance.
inherited
toBuilder() → TaskProcessingTaskBuilder
Converts the instance to a builder B.
inherited
toJson() → Map<String, dynamic>
Parses this object into a json like map.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

serializer → Serializer<TaskProcessingTask>
Serializer for TaskProcessingTask.
no setter