TeamResourceBuilder class

Implemented types

Constructors

TeamResourceBuilder()

Properties

hashCode → int
The hash code for this object.
no setterinherited
iconEmoji ↔ String?
covariantgetter/setter pairoverride
iconSvg ↔ String?
covariantgetter/setter pairoverride
iconURL ↔ String?
covariantgetter/setter pairoverride
id ↔ int?
covariantgetter/setter pairoverride
label ↔ String?
covariantgetter/setter pairoverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
url ↔ String?
covariantgetter/setter pairoverride

Methods

build() → TeamResource
Builds.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
replace(covariant TeamResource other) → void
Replaces the value in the builder with a new one.
override
toString() → String
A string representation of this object.
inherited
update(void updates(TeamResourceBuilder)?) → void
Applies updates.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited