TextProcessingApiGetTaskResponseApplicationJson_Ocs class abstract

Implemented types

Constructors

TextProcessingApiGetTaskResponseApplicationJson_Ocs([void b(TextProcessingApiGetTaskResponseApplicationJson_OcsBuilder)?])
Creates a new TextProcessingApiGetTaskResponseApplicationJson_Ocs object using the builder pattern.
factory
TextProcessingApiGetTaskResponseApplicationJson_Ocs.fromJson(Map<String, dynamic> json)
Creates a new object from the given json data.
factory

Properties

data → TextProcessingApiGetTaskResponseApplicationJson_Ocs_Data
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
meta → OCSMeta
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(TextProcessingApiGetTaskResponseApplicationJson_OcsBuilder)) → TextProcessingApiGetTaskResponseApplicationJson_Ocs
Rebuilds the instance.
inherited
toBuilder() → TextProcessingApiGetTaskResponseApplicationJson_OcsBuilder
Converts the instance to a builder B.
inherited
toJson() → Map<String, dynamic>
Parses this object into a json like map.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

serializer → Serializer<TextProcessingApiGetTaskResponseApplicationJson_Ocs>
Serializer for TextProcessingApiGetTaskResponseApplicationJson_Ocs.
no setter