TextProcessingApiScheduleRequestApplicationJson class abstract

Implemented types

Constructors

TextProcessingApiScheduleRequestApplicationJson([void b(TextProcessingApiScheduleRequestApplicationJsonBuilder)?])
Creates a new TextProcessingApiScheduleRequestApplicationJson object using the builder pattern.
factory
TextProcessingApiScheduleRequestApplicationJson.fromJson(Map<String, dynamic> json)
Creates a new object from the given json data.
factory

Properties

appId → String
ID of the app that will execute the task.
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
identifier → String
An arbitrary identifier for the task.
no setterinherited
input → String
Input text.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → String
Type of the task.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(TextProcessingApiScheduleRequestApplicationJsonBuilder)) → TextProcessingApiScheduleRequestApplicationJson
Rebuilds the instance.
inherited
toBuilder() → TextProcessingApiScheduleRequestApplicationJsonBuilder
Converts the instance to a builder B.
inherited
toJson() → Map<String, dynamic>
Parses this object into a json like map.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

serializer → Serializer<TextProcessingApiScheduleRequestApplicationJson>
Serializer for TextProcessingApiScheduleRequestApplicationJson.
no setter