TextProcessingTask class abstract

Implemented types

Constructors

TextProcessingTask([void b(TextProcessingTaskBuilder)?])
Creates a new TextProcessingTask object using the builder pattern.
factory
TextProcessingTask.fromJson(Map<String, dynamic> json)
Creates a new object from the given json data.
factory

Properties

appId → String
no setterinherited
completionExpectedAt → int?
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
id → int?
no setterinherited
identifier → String
no setterinherited
input → String
no setterinherited
output → String?
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
status → TextProcessingTask_Status
no setterinherited
type → String
no setterinherited
userId → String?
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(TextProcessingTaskBuilder)) → TextProcessingTask
Rebuilds the instance.
inherited
toBuilder() → TextProcessingTaskBuilder
Converts the instance to a builder B.
inherited
toJson() → Map<String, dynamic>
Parses this object into a json like map.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

serializer → Serializer<TextProcessingTask>
Serializer for TextProcessingTask.
no setter