TextToImageTask class abstract

Implemented types

Constructors

TextToImageTask([void b(TextToImageTaskBuilder)?])
Creates a new TextToImageTask object using the builder pattern.
factory
TextToImageTask.fromJson(Map<String, dynamic> json)
Creates a new object from the given json data.
factory

Properties

appId → String
no setterinherited
completionExpectedAt → int?
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
id → int?
no setterinherited
identifier → String?
no setterinherited
input → String
no setterinherited
numberOfImages → int
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
status → TextToImageTask_Status
no setterinherited
userId → String?
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(TextToImageTaskBuilder)) → TextToImageTask
Rebuilds the instance.
inherited
toBuilder() → TextToImageTaskBuilder
Converts the instance to a builder B.
inherited
toJson() → Map<String, dynamic>
Parses this object into a json like map.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

serializer → Serializer<TextToImageTask>
Serializer for TextToImageTask.
no setter