replace method
void
replace()
override
Replaces the value in the builder with a new one.
The implementation of this method will be generated for you by the built_value generator.
Implementation
@override
void replace(covariant TranslationApiLanguagesResponseApplicationJson_Ocs_Data_Languages other) {
_$v = other as _$TranslationApiLanguagesResponseApplicationJson_Ocs_Data_Languages;
}