TwoFactorApiEnableRequestApplicationJson class abstract

Implemented types

Constructors

TwoFactorApiEnableRequestApplicationJson([void b(TwoFactorApiEnableRequestApplicationJsonBuilder)?])
Creates a new TwoFactorApiEnableRequestApplicationJson object using the builder pattern.
factory
TwoFactorApiEnableRequestApplicationJson.fromJson(Map<String, dynamic> json)
Creates a new object from the given json data.
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
providers → BuiltList<String>
collection of TFA provider ids.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
user String
system user identifier.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(TwoFactorApiEnableRequestApplicationJsonBuilder)) TwoFactorApiEnableRequestApplicationJson
Rebuilds the instance.
inherited
toBuilder() TwoFactorApiEnableRequestApplicationJsonBuilder
Converts the instance to a builder B.
inherited
toJson() Map<String, dynamic>
Parses this object into a json like map.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

serializer → Serializer<TwoFactorApiEnableRequestApplicationJson>
Serializer for TwoFactorApiEnableRequestApplicationJson.
no setter