UnifiedSearchProvider class abstract

Implemented types

Constructors

UnifiedSearchProvider([void b(UnifiedSearchProviderBuilder)?])
Creates a new UnifiedSearchProvider object using the builder pattern.
factory
UnifiedSearchProvider.fromJson(Map<String, dynamic> json)
Creates a new object from the given json data.
factory

Properties

appId → String
no setterinherited
filters → BuiltMap<String, String>
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
icon → String
no setterinherited
id → String
no setterinherited
inAppSearch → bool
no setterinherited
name → String
no setterinherited
order → int
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
triggers → BuiltList<String>
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(UnifiedSearchProviderBuilder)) → UnifiedSearchProvider
Rebuilds the instance.
inherited
toBuilder() → UnifiedSearchProviderBuilder
Converts the instance to a builder B.
inherited
toJson() → Map<String, dynamic>
Parses this object into a json like map.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

serializer → Serializer<UnifiedSearchProvider>
Serializer for UnifiedSearchProvider.
no setter