WipeCheckWipeRequestApplicationJson class abstract

Implemented types

Constructors

WipeCheckWipeRequestApplicationJson([void b(WipeCheckWipeRequestApplicationJsonBuilder)?])
Creates a new WipeCheckWipeRequestApplicationJson object using the builder pattern.
factory
WipeCheckWipeRequestApplicationJson.fromJson(Map<String, dynamic> json)
Creates a new object from the given json data.
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
token → String
App password.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(WipeCheckWipeRequestApplicationJsonBuilder)) → WipeCheckWipeRequestApplicationJson
Rebuilds the instance.
inherited
toBuilder() → WipeCheckWipeRequestApplicationJsonBuilder
Converts the instance to a builder B.
inherited
toJson() → Map<String, dynamic>
Parses this object into a json like map.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

serializer → Serializer<WipeCheckWipeRequestApplicationJson>
Serializer for WipeCheckWipeRequestApplicationJson.
no setter