OutOfOfficeDataCommon class abstract

Implemented types

Constructors

OutOfOfficeDataCommon([void b(OutOfOfficeDataCommonBuilder)?])
Creates a new OutOfOfficeDataCommon object using the builder pattern.
factory
OutOfOfficeDataCommon.fromJson(Map<String, dynamic> json)
Creates a new object from the given json data.
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
message → String
no setterinherited
replacementUserDisplayName → String?
no setterinherited
replacementUserId → String?
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
userId → String
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(OutOfOfficeDataCommonBuilder)) → OutOfOfficeDataCommon
Rebuilds the instance.
inherited
toBuilder() → OutOfOfficeDataCommonBuilder
Converts the instance to a builder B.
inherited
toJson() → Map<String, dynamic>
Parses this object into a json like map.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

serializer → Serializer<OutOfOfficeDataCommon>
Serializer for OutOfOfficeDataCommon.
no setter