OutOfOfficeGetOutOfOfficeResponseApplicationJson class abstract

Implemented types

Constructors

OutOfOfficeGetOutOfOfficeResponseApplicationJson([void b(OutOfOfficeGetOutOfOfficeResponseApplicationJsonBuilder)?])
Creates a new OutOfOfficeGetOutOfOfficeResponseApplicationJson object using the builder pattern.
factory
OutOfOfficeGetOutOfOfficeResponseApplicationJson.fromJson(Map<String, dynamic> json)
Creates a new object from the given json data.
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
ocs → OutOfOfficeGetOutOfOfficeResponseApplicationJson_Ocs
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(OutOfOfficeGetOutOfOfficeResponseApplicationJsonBuilder)) → OutOfOfficeGetOutOfOfficeResponseApplicationJson
Rebuilds the instance.
inherited
toBuilder() → OutOfOfficeGetOutOfOfficeResponseApplicationJsonBuilder
Converts the instance to a builder B.
inherited
toJson() → Map<String, dynamic>
Parses this object into a json like map.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

serializer → Serializer<OutOfOfficeGetOutOfOfficeResponseApplicationJson>
Serializer for OutOfOfficeGetOutOfOfficeResponseApplicationJson.
no setter