$ConversionApiClient class

Constructors

$ConversionApiClient($Client _rootClient)
Creates a new DynamiteClient for conversion_api requests.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

$convert_Request({required ConversionApiConvertRequestApplicationJson $body, bool? oCSAPIRequest}) → Request
Converts a file from one MIME type to another.
$convert_Serializer() → DynamiteSerializer<ConversionApiConvertResponseApplicationJson, void>
Builds a serializer to parse the response of $convert_Request.
convert({required ConversionApiConvertRequestApplicationJson $body, bool? oCSAPIRequest}) Future<DynamiteResponse<ConversionApiConvertResponseApplicationJson, void>>
Converts a file from one MIME type to another.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited