convert method

Converts a file from one MIME type to another.

Returns a Future containing a DynamiteResponse with the status code, deserialized body and headers. Throws a DynamiteApiException if the API call does not return an expected status code.

Parameters:

  • oCSAPIRequest Required to be true for the API request to pass. Defaults to true.

Status codes:

  • 201: File was converted and written to the destination or temporary file
  • 404: The file to be converted was not found

See:

Implementation

Future<_i1.DynamiteResponse<ConversionApiConvertResponseApplicationJson, void>> convert({
  required ConversionApiConvertRequestApplicationJson $body,
  bool? oCSAPIRequest,
}) async {
  final _request = $convert_Request(oCSAPIRequest: oCSAPIRequest, $body: $body);
  final _streamedResponse = await _rootClient.httpClient.send(_request);
  final _response = await _i3.Response.fromStream(_streamedResponse);

  final _serializer = $convert_Serializer();
  return _i1.ResponseConverter<ConversionApiConvertResponseApplicationJson, void>(_serializer).convert(_response);
}