$ConversionApiConvertRequestApplicationJsonInterface class sealed

Implementers
Annotations
  • @BuiltValue.new(instantiable: false)

Properties

destination → String?
The target path of the converted file. Written to a temporary file if left empty.
no setter
fileId → int
ID of the file to be converted.
no setter
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
targetMimeType → String
The MIME type to which you want to convert the file.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(void updates($ConversionApiConvertRequestApplicationJsonInterfaceBuilder)) → $ConversionApiConvertRequestApplicationJsonInterface
Rebuilds the instance.
toBuilder() → $ConversionApiConvertRequestApplicationJsonInterfaceBuilder
Converts the instance to a builder $ConversionApiConvertRequestApplicationJsonInterfaceBuilder.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited