targetMimeType property
String
get
targetMimeType
The MIME type to which you want to convert the file.
Implementation
String get targetMimeType;
The MIME type to which you want to convert the file.
String get targetMimeType;