rebuild abstract method
Rebuilds the instance.
The result is the same as this instance but with updates applied.
updates is a function that takes a builder $ConversionApiConvertResponseApplicationJson_Ocs_DataInterfaceBuilder.
Implementation
$ConversionApiConvertResponseApplicationJson_Ocs_DataInterface rebuild(
void Function($ConversionApiConvertResponseApplicationJson_Ocs_DataInterfaceBuilder) updates,
);