$DirectEditingCreateRequestApplicationJsonInterfaceBuilder class abstract mixin

Implementers

Properties

creatorId ↔ String?
getter/setter pair
editorId ↔ String?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
path ↔ String?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
templateId ↔ String?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
replace($DirectEditingCreateRequestApplicationJsonInterface other) → void
toString() → String
A string representation of this object.
inherited
update(void updates($DirectEditingCreateRequestApplicationJsonInterfaceBuilder)) → void

Operators

operator ==(Object other) → bool
The equality operator.
inherited