$listTemplateFields_Request method

  1. @experimental
Request $listTemplateFields_Request({
  1. required int fileId,
  2. bool? oCSAPIRequest,
})

List the fields for the template specified by the given file ID.

Returns a DynamiteRequest backing the listTemplateFields operation. Throws a DynamiteApiException if the API call does not return an expected status code.

Parameters:

  • fileId File ID of the template.
  • oCSAPIRequest Required to be true for the API request to pass. Defaults to true.

Status codes:

  • 200: Fields returned

See:

Implementation

@_i2.experimental
_i3.Request $listTemplateFields_Request({required int fileId, bool? oCSAPIRequest}) {
  final _parameters = <String, Object?>{};
  final __fileId = _$jsonSerializers.serialize(fileId, specifiedType: const FullType(int));
  _parameters['fileId'] = __fileId;

  final _path = _i5.UriTemplate('/ocs/v2.php/apps/files/api/v1/templates/fields/{fileId}').expand(_parameters);
  final _uri = Uri.parse('${_rootClient.baseURL}$_path');
  final _request = _i3.Request('get', _uri);
  _request.headers['Accept'] = 'application/json';
  // coverage:ignore-start
  final authentication = _i6.IterableExtension(_rootClient.authentications)?.firstWhereOrNull(
    (auth) => switch (auth) {
      _i1.DynamiteHttpBearerAuthentication() || _i1.DynamiteHttpBasicAuthentication() => true,
      _ => false,
    },
  );

  if (authentication != null) {
    _request.headers.addAll(authentication.headers);
  } else {
    throw Exception('Missing authentication for bearer_auth or basic_auth');
  }

  // coverage:ignore-end
  var __oCSAPIRequest = _$jsonSerializers.serialize(oCSAPIRequest, specifiedType: const FullType(bool));
  __oCSAPIRequest ??= true;
  _request.headers['OCS-APIRequest'] = const _i4.HeaderEncoder().convert(__oCSAPIRequest);

  return _request;
}