listTemplateFields method

Future<DynamiteResponse<TemplateListTemplateFieldsResponseApplicationJson, void>> listTemplateFields({
  1. required int fileId,
  2. bool? oCSAPIRequest,
})

List the fields for the template specified by the given file ID.

Returns a Future containing a DynamiteResponse with the status code, deserialized body and headers. Throws a DynamiteApiException if the API call does not return an expected status code.

Parameters:

  • fileId File ID of the template.
  • oCSAPIRequest Required to be true for the API request to pass. Defaults to true.

Status codes:

  • 200: Fields returned

See:

Implementation

Future<_i1.DynamiteResponse<TemplateListTemplateFieldsResponseApplicationJson, void>> listTemplateFields({
  required int fileId,
  bool? oCSAPIRequest,
}) async {
  final _request = $listTemplateFields_Request(fileId: fileId, oCSAPIRequest: oCSAPIRequest);
  final _streamedResponse = await _rootClient.httpClient.send(_request);
  final _response = await _i3.Response.fromStream(_streamedResponse);

  final _serializer = $listTemplateFields_Serializer();
  return _i1.ResponseConverter<TemplateListTemplateFieldsResponseApplicationJson, void>(
    _serializer,
  ).convert(_response);
}