$TemplateFieldInterface class sealed

Implementers
Annotations
  • @BuiltValue.new(instantiable: false)

Properties

alias String?
no setter
checked bool?
no setter
content String?
no setter
hashCode int
The hash code for this object.
no setterinherited
id int?
no setter
index String
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tag String?
no setter
type String
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(void updates($TemplateFieldInterfaceBuilder)) $TemplateFieldInterface
Rebuilds the instance.
toBuilder() $TemplateFieldInterfaceBuilder
Converts the instance to a builder $TemplateFieldInterfaceBuilder.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited