$TemplateFileCreatorInterface class sealed

Implementers
Annotations
  • @BuiltValue.new(instantiable: false)

Properties

$extension → String
no setter
actionLabel → String
no setter
app → String
no setter
hashCode → int
The hash code for this object.
no setterinherited
iconClass → String?
no setter
iconSvgInline → String?
no setter
label → String
no setter
mimetypes → BuiltList<String>
no setter
ratio → double?
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(void updates($TemplateFileCreatorInterfaceBuilder)) → $TemplateFileCreatorInterface
Rebuilds the instance.
toBuilder() → $TemplateFileCreatorInterfaceBuilder
Converts the instance to a builder $TemplateFileCreatorInterfaceBuilder.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited