$TemplateFileInterface class sealed

Implementers
Annotations
  • @BuiltValue.new(instantiable: false)

Properties

basename → String
no setter
etag → String
no setter
fileid → int
no setter
filename → String?
no setter
hashCode → int
The hash code for this object.
no setterinherited
hasPreview → bool
no setter
lastmod → int
no setter
mime → String
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
size → int
no setter
type → String
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(void updates($TemplateFileInterfaceBuilder)) → $TemplateFileInterface
Rebuilds the instance.
toBuilder() → $TemplateFileInterfaceBuilder
Converts the instance to a builder $TemplateFileInterfaceBuilder.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited