$TemplateFileInterfaceBuilder class abstract mixin

Implementers

Properties

basename ↔ String?
getter/setter pair
etag ↔ String?
getter/setter pair
fileid ↔ int?
getter/setter pair
filename ↔ String?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
hasPreview ↔ bool?
getter/setter pair
lastmod ↔ int?
getter/setter pair
mime ↔ String?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
size ↔ int?
getter/setter pair
type ↔ String?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
replace($TemplateFileInterface other) → void
toString() → String
A string representation of this object.
inherited
update(void updates($TemplateFileInterfaceBuilder)) → void

Operators

operator ==(Object other) → bool
The equality operator.
inherited