rebuild abstract method

Rebuilds the instance.

The result is the same as this instance but with updates applied. updates is a function that takes a builder $TemplateListTemplateFieldsResponseApplicationJsonInterfaceBuilder.

Implementation

$TemplateListTemplateFieldsResponseApplicationJsonInterface rebuild(
  void Function($TemplateListTemplateFieldsResponseApplicationJsonInterfaceBuilder) updates,
);