rebuild abstract method
Rebuilds the instance.
The result is the same as this instance but with updates applied.
updates is a function that takes a builder $TemplateListTemplateFieldsResponseApplicationJson_OcsInterfaceBuilder.
Implementation
$TemplateListTemplateFieldsResponseApplicationJson_OcsInterface rebuild(
void Function($TemplateListTemplateFieldsResponseApplicationJson_OcsInterfaceBuilder) updates,
);