Capabilities_Files_DirectEditing class abstract

Implemented types

Constructors

Capabilities_Files_DirectEditing([void b(Capabilities_Files_DirectEditingBuilder)?])
Creates a new Capabilities_Files_DirectEditing object using the builder pattern.
factory
Capabilities_Files_DirectEditing.fromJson(Map<String, dynamic> json)
Creates a new object from the given json data.
factory

Properties

etag → String
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
supportsFileId → bool
no setterinherited
url → String
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(Capabilities_Files_DirectEditingBuilder)) → Capabilities_Files_DirectEditing
Rebuilds the instance.
inherited
toBuilder() → Capabilities_Files_DirectEditingBuilder
Converts the instance to a builder B.
inherited
toJson() → Map<String, dynamic>
Parses this object into a json like map.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

serializer → Serializer<Capabilities_Files_DirectEditing>
Serializer for Capabilities_Files_DirectEditing.
no setter