Capabilities_Files_FileConversionsBuilder class

Implemented types

Properties

$extension String?
covariantgetter/setter pairoverride
displayName String?
covariantgetter/setter pairoverride
from String?
covariantgetter/setter pairoverride
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
to String?
covariantgetter/setter pairoverride

Methods

build() Capabilities_Files_FileConversions
Builds.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
replace(covariant Capabilities_Files_FileConversions other) → void
Replaces the value in the builder with a new one.
override
toString() String
A string representation of this object.
inherited
update(void updates(Capabilities_Files_FileConversionsBuilder)?) → void
Applies updates.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited