DirectEditingCreateRequestApplicationJson class abstract

Implemented types

Constructors

DirectEditingCreateRequestApplicationJson([void b(DirectEditingCreateRequestApplicationJsonBuilder)?])
Creates a new DirectEditingCreateRequestApplicationJson object using the builder pattern.
factory
DirectEditingCreateRequestApplicationJson.fromJson(Map<String, dynamic> json)
Creates a new object from the given json data.
factory

Properties

creatorId → String
ID of the creator.
no setterinherited
editorId → String
ID of the editor.
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
path → String
Path of the file.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
templateId → String?
ID of the template.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(DirectEditingCreateRequestApplicationJsonBuilder)) → DirectEditingCreateRequestApplicationJson
Rebuilds the instance.
inherited
toBuilder() → DirectEditingCreateRequestApplicationJsonBuilder
Converts the instance to a builder B.
inherited
toJson() → Map<String, dynamic>
Parses this object into a json like map.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

serializer → Serializer<DirectEditingCreateRequestApplicationJson>
Serializer for DirectEditingCreateRequestApplicationJson.
no setter