DirectEditingInfoResponseApplicationJson_Ocs_Data_EditorsBuilder class

Implemented types

Properties

hashCode → int
The hash code for this object.
no setterinherited
id ↔ String?
covariantgetter/setter pairoverride
mimetypes ↔ ListBuilder<String>
covariantgetter/setter pairoverride
name ↔ String?
covariantgetter/setter pairoverride
optionalMimetypes ↔ ListBuilder<String>
covariantgetter/setter pairoverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
secure ↔ bool?
covariantgetter/setter pairoverride

Methods

build() → DirectEditingInfoResponseApplicationJson_Ocs_Data_Editors
Builds.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
replace(covariant DirectEditingInfoResponseApplicationJson_Ocs_Data_Editors other) → void
Replaces the value in the builder with a new one.
override
toString() → String
A string representation of this object.
inherited
update(void updates(DirectEditingInfoResponseApplicationJson_Ocs_Data_EditorsBuilder)?) → void
Applies updates.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited