Template class abstract
- Implemented types
Constructors
- Template([void b(TemplateBuilder)?])
-
Creates a new Template object using the builder pattern.
factory
-
Template.fromJson(Map<
String, dynamic> json) -
Creates a new object from the given
jsondata.factory
Properties
- basename → String
-
no setterinherited
- etag → String
-
no setterinherited
-
fields
→ BuiltList<
TemplateField> -
no setterinherited
- fileid → int
-
no setterinherited
- filename → String
-
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- hasPreview → bool
-
no setterinherited
- lastmod → int
-
no setterinherited
- mime → String
-
no setterinherited
- previewUrl → String?
-
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- size → num
-
no setterinherited
- templateId → String
-
no setterinherited
- templateType → String
-
no setterinherited
- type → String
-
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
rebuild(
dynamic updates(TemplateBuilder)) → Template -
Rebuilds the instance.
inherited
-
toBuilder(
) → TemplateBuilder -
Converts the instance to a builder
B.inherited -
toJson(
) → Map< String, dynamic> - Parses this object into a json like map.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
-
serializer
→ Serializer<
Template> -
Serializer for Template.
no setter