Template constructor
Template([
- void b()?
Creates a new Template object using the builder pattern.
Implementation
factory Template([void Function(TemplateBuilder)? b]) = _$Template;
Creates a new Template object using the builder pattern.
factory Template([void Function(TemplateBuilder)? b]) = _$Template;