TemplateField class abstract

Implemented types

Constructors

TemplateField([void b(TemplateFieldBuilder)?])
Creates a new TemplateField object using the builder pattern.
factory
TemplateField.fromJson(Map<String, dynamic> json)
Creates a new object from the given json data.
factory

Properties

alias String?
no setterinherited
checked bool?
no setterinherited
content String?
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
id int?
no setterinherited
index String
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tag String?
no setterinherited
type String
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(TemplateFieldBuilder)) TemplateField
Rebuilds the instance.
inherited
toBuilder() TemplateFieldBuilder
Converts the instance to a builder B.
inherited
toJson() Map<String, dynamic>
Parses this object into a json like map.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

serializer → Serializer<TemplateField>
Serializer for TemplateField.
no setter