TemplateFileCreator class abstract

Implemented types

Constructors

TemplateFileCreator([void b(TemplateFileCreatorBuilder)?])
Creates a new TemplateFileCreator object using the builder pattern.
factory
TemplateFileCreator.fromJson(Map<String, dynamic> json)
Creates a new object from the given json data.
factory

Properties

$extension → String
no setterinherited
actionLabel → String
no setterinherited
app → String
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
iconClass → String?
no setterinherited
iconSvgInline → String?
no setterinherited
label → String
no setterinherited
mimetypes → BuiltList<String>
no setterinherited
ratio → double?
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(TemplateFileCreatorBuilder)) → TemplateFileCreator
Rebuilds the instance.
inherited
toBuilder() → TemplateFileCreatorBuilder
Converts the instance to a builder B.
inherited
toJson() → Map<String, dynamic>
Parses this object into a json like map.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

serializer → Serializer<TemplateFileCreator>
Serializer for TemplateFileCreator.
no setter