TemplateFileCreatorWithTemplates class abstract

Implemented types

Constructors

TemplateFileCreatorWithTemplates([void b(TemplateFileCreatorWithTemplatesBuilder)?])
Creates a new TemplateFileCreatorWithTemplates object using the builder pattern.
factory
TemplateFileCreatorWithTemplates.fromJson(Map<String, dynamic> json)
Creates a new object from the given json data.
factory

Properties

$extension → String
no setterinherited
actionLabel → String
no setterinherited
app → String
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
iconClass → String?
no setterinherited
iconSvgInline → String?
no setterinherited
label → String
no setterinherited
mimetypes → BuiltList<String>
no setterinherited
ratio → double?
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
templates → BuiltList<Template>
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(TemplateFileCreatorWithTemplatesBuilder)) → TemplateFileCreatorWithTemplates
Rebuilds the instance.
inherited
toBuilder() → TemplateFileCreatorWithTemplatesBuilder
Converts the instance to a builder B.
inherited
toJson() → Map<String, dynamic>
Parses this object into a json like map.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

serializer → Serializer<TemplateFileCreatorWithTemplates>
Serializer for TemplateFileCreatorWithTemplates.
no setter