$StorageConfigInterface class sealed

Implementers
Annotations
  • @BuiltValue.new(instantiable: false)

Properties

applicableGroups → BuiltList<String>?
no setter
applicableUsers → BuiltList<String>?
no setter
authMechanism → String
no setter
backend → String
no setter
backendOptions → BuiltMap<String, JsonObject>
no setter
hashCode → int
The hash code for this object.
no setterinherited
id → int?
no setter
mountOptions → BuiltMap<String, JsonObject>?
no setter
mountPoint → String
no setter
priority → int?
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
status → int?
no setter
statusMessage → String?
no setter
type → StorageConfig_Type
no setter
userProvided → bool
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(void updates($StorageConfigInterfaceBuilder)) → $StorageConfigInterface
Rebuilds the instance.
toBuilder() → $StorageConfigInterfaceBuilder
Converts the instance to a builder $StorageConfigInterfaceBuilder.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited