$StorageConfigInterfaceBuilder class abstract mixin

Implementers

Properties

applicableGroups ↔ ListBuilder<String>
getter/setter pair
applicableUsers ↔ ListBuilder<String>
getter/setter pair
authMechanism ↔ String?
getter/setter pair
backend ↔ String?
getter/setter pair
backendOptions ↔ MapBuilder<String, JsonObject>
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
id ↔ int?
getter/setter pair
mountOptions ↔ MapBuilder<String, JsonObject>
getter/setter pair
mountPoint ↔ String?
getter/setter pair
priority ↔ int?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
status ↔ int?
getter/setter pair
statusMessage ↔ String?
getter/setter pair
type ↔ StorageConfig_Type?
getter/setter pair
userProvided ↔ bool?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
replace($StorageConfigInterface other) → void
toString() → String
A string representation of this object.
inherited
update(void updates($StorageConfigInterfaceBuilder)) → void

Operators

operator ==(Object other) → bool
The equality operator.
inherited