Mount class abstract

Implemented types

Constructors

Mount([void b(MountBuilder)?])
Creates a new Mount object using the builder pattern.
factory
Mount.fromJson(Map<String, dynamic> json)
Creates a new object from the given json data.
factory

Properties

$class → String
no setterinherited
backend → String
no setterinherited
config → StorageConfig
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
id → int
no setterinherited
name → String
no setterinherited
path → String
no setterinherited
permissions → int
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scope → Mount_Scope
no setterinherited
type → Mount_Type
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(MountBuilder)) → Mount
Rebuilds the instance.
inherited
toBuilder() → MountBuilder
Converts the instance to a builder B.
inherited
toJson() → Map<String, dynamic>
Parses this object into a json like map.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

serializer → Serializer<Mount>
Serializer for Mount.
no setter