StorageConfig class abstract

Implemented types

Constructors

StorageConfig([void b(StorageConfigBuilder)?])
Creates a new StorageConfig object using the builder pattern.
factory
StorageConfig.fromJson(Map<String, dynamic> json)
Creates a new object from the given json data.
factory

Properties

applicableGroups → BuiltList<String>?
no setterinherited
applicableUsers → BuiltList<String>?
no setterinherited
authMechanism → String
no setterinherited
backend → String
no setterinherited
backendOptions → BuiltMap<String, JsonObject>
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
id → int?
no setterinherited
mountOptions → BuiltMap<String, JsonObject>?
no setterinherited
mountPoint → String
no setterinherited
priority → int?
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
status → int?
no setterinherited
statusMessage → String?
no setterinherited
type → StorageConfig_Type
no setterinherited
userProvided → bool
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(StorageConfigBuilder)) → StorageConfig
Rebuilds the instance.
inherited
toBuilder() → StorageConfigBuilder
Converts the instance to a builder B.
inherited
toJson() → Map<String, dynamic>
Parses this object into a json like map.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

serializer → Serializer<StorageConfig>
Serializer for StorageConfig.
no setter