$DeletedShareInterfaceBuilder class abstract mixin

Implementers

Properties

displaynameFileOwner ↔ String?
getter/setter pair
displaynameOwner ↔ String?
getter/setter pair
expiration ↔ String?
getter/setter pair
fileParent ↔ int?
getter/setter pair
fileSource ↔ int?
getter/setter pair
fileTarget ↔ int?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
id ↔ String?
getter/setter pair
itemSource ↔ int?
getter/setter pair
itemType ↔ String?
getter/setter pair
mimetype ↔ String?
getter/setter pair
path ↔ String?
getter/setter pair
permissions ↔ int?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
shareType ↔ int?
getter/setter pair
shareWith ↔ String?
getter/setter pair
shareWithDisplayname ↔ String?
getter/setter pair
getter/setter pair
stime ↔ int?
getter/setter pair
storage ↔ int?
getter/setter pair
uidFileOwner ↔ String?
getter/setter pair
uidOwner ↔ String?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
replace($DeletedShareInterface other) → void
toString() → String
A string representation of this object.
inherited
update(void updates($DeletedShareInterfaceBuilder)) → void

Operators

operator ==(Object other) → bool
The equality operator.
inherited