$getPreview_Request method
- @experimental
- required String token,
- String? file,
- int? x,
- int? y,
- PublicPreviewGetPreviewA? a,
- PublicPreviewGetPreviewMimeFallback? mimeFallback,
Get a preview for a shared file.
Returns a DynamiteRequest backing the getPreview operation.
Throws a DynamiteApiException if the API call does not return an expected status code.
Parameters:
tokenToken of the share.fileFile in the share. Defaults to"".xWidth of the preview. Defaults to32.yHeight of the preview. Defaults to32.aWhether to not crop the preview. Defaults to0.mimeFallbackWhether to fallback to the mime icon if no preview is available. Defaults to0.
Status codes:
- 200: Preview returned
- 400: Getting preview is not possible
- 403: Getting preview is not allowed
- 404: Share or preview not found
- 303: Redirect to the mime icon url if mimeFallback is true
See:
- getPreview for a method executing this request and parsing the response.
- $getPreview_Serializer for a converter to parse the
Responsefrom an executed this request.
Implementation
@_i2.experimental
_i3.Request $getPreview_Request({
required String token,
String? file,
int? x,
int? y,
PublicPreviewGetPreviewA? a,
PublicPreviewGetPreviewMimeFallback? mimeFallback,
}) {
final _parameters = <String, Object?>{};
final __token = _$jsonSerializers.serialize(token, specifiedType: const FullType(String));
_parameters['token'] = __token;
var __file = _$jsonSerializers.serialize(file, specifiedType: const FullType(String));
__file ??= '';
_parameters['file'] = __file;
var __x = _$jsonSerializers.serialize(x, specifiedType: const FullType(int));
__x ??= 32;
_parameters['x'] = __x;
var __y = _$jsonSerializers.serialize(y, specifiedType: const FullType(int));
__y ??= 32;
_parameters['y'] = __y;
var __a = _$jsonSerializers.serialize(a, specifiedType: const FullType(PublicPreviewGetPreviewA));
__a ??= 0;
_parameters['a'] = __a;
var __mimeFallback = _$jsonSerializers.serialize(
mimeFallback,
specifiedType: const FullType(PublicPreviewGetPreviewMimeFallback),
);
__mimeFallback ??= 0;
_parameters['mimeFallback'] = __mimeFallback;
final _path = _i6.UriTemplate(
'/index.php/apps/files_sharing/publicpreview/{token}{?file*,x*,y*,a*,mimeFallback*}',
).expand(_parameters);
final _uri = Uri.parse('${_rootClient.baseURL}$_path');
final _request = _i3.Request('get', _uri);
_request.headers['Accept'] = '*/*';
// coverage:ignore-start
final authentication = _i4.IterableExtension(_rootClient.authentications)?.firstWhereOrNull(
(auth) => switch (auth) {
_i1.DynamiteHttpBearerAuthentication() || _i1.DynamiteHttpBasicAuthentication() => true,
_ => false,
},
);
if (authentication != null) {
_request.headers.addAll(authentication.headers);
}
// coverage:ignore-end
return _request;
}