$ShareapiCreateShareRequestApplicationJsonInterface class sealed

Implementers
Annotations
  • @BuiltValue.new(instantiable: false)

Properties

attributes → String?
Additional attributes for the share.
no setter
expireDate → String?
The expiry date of the share in the user's timezone at 00:00. If $expireDate is not supplied or set to null, the system default will be used.
no setter
hashCode → int
The hash code for this object.
no setterinherited
label → String
Label for the share (only used in link and email).
no setter
note → String
Note for the share.
no setter
password → String
Password for the share.
no setter
path → String?
Path of the share.
no setter
permissions → int?
Permissions for the share.
no setter
publicUpload → ShareapiCreateShareRequestApplicationJson_PublicUpload?
If public uploading is allowed (deprecated).
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sendMail → ShareapiCreateShareRequestApplicationJson_SendMail?
Send a mail to the recipient.
no setter
sendPasswordByTalk → String?
Send the password for the share over Talk.
no setter
shareType → int
Type of the share.
no setter
shareWith → String?
The entity this should be shared with.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(void updates($ShareapiCreateShareRequestApplicationJsonInterfaceBuilder)) → $ShareapiCreateShareRequestApplicationJsonInterface
Rebuilds the instance.
toBuilder() → $ShareapiCreateShareRequestApplicationJsonInterfaceBuilder
Converts the instance to a builder $ShareapiCreateShareRequestApplicationJsonInterfaceBuilder.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited