rebuild abstract method

Rebuilds the instance.

The result is the same as this instance but with updates applied. updates is a function that takes a builder $ShareapiGenerateTokenResponseApplicationJson_Ocs_DataInterfaceBuilder.

Implementation

$ShareapiGenerateTokenResponseApplicationJson_Ocs_DataInterface rebuild(
  void Function($ShareapiGenerateTokenResponseApplicationJson_Ocs_DataInterfaceBuilder) updates,
);