rebuild abstract method

  1. @override
$ShareeRoomInterface rebuild(
  1. void updates(
    1. $ShareeRoomInterfaceBuilder
    )
)
override

Rebuilds the instance.

The result is the same as this instance but with updates applied. updates is a function that takes a builder $ShareeRoomInterfaceBuilder.

Implementation

@override
$ShareeRoomInterface rebuild(void Function($ShareeRoomInterfaceBuilder) updates);