findRecommended method

Future<DynamiteResponse<ShareesapiFindRecommendedResponseApplicationJson, void>> findRecommended({
  1. required String itemType,
  2. ShareesapiFindRecommendedShareType? shareType,
  3. bool? oCSAPIRequest,
})

Find recommended sharees.

Returns a Future containing a DynamiteResponse with the status code, deserialized body and headers. Throws a DynamiteApiException if the API call does not return an expected status code.

Parameters:

  • itemType Limit to specific item types.
  • shareType Limit to specific share types.
  • oCSAPIRequest Required to be true for the API request to pass. Defaults to true.

Status codes:

  • 200: Recommended sharees returned

See:

Implementation

Future<_i1.DynamiteResponse<ShareesapiFindRecommendedResponseApplicationJson, void>> findRecommended({
  required String itemType,
  ShareesapiFindRecommendedShareType? shareType,
  bool? oCSAPIRequest,
}) async {
  final _request = $findRecommended_Request(itemType: itemType, shareType: shareType, oCSAPIRequest: oCSAPIRequest);
  final _streamedResponse = await _rootClient.httpClient.send(_request);
  final _response = await _i3.Response.fromStream(_streamedResponse);

  final _serializer = $findRecommended_Serializer();
  return _i1.ResponseConverter<ShareesapiFindRecommendedResponseApplicationJson, void>(
    _serializer,
  ).convert(_response);
}