Capabilities_FilesSharing_Public class abstract

Implemented types

Constructors

Capabilities_FilesSharing_Public([void b(Capabilities_FilesSharing_PublicBuilder)?])
Creates a new Capabilities_FilesSharing_Public object using the builder pattern.
factory
Capabilities_FilesSharing_Public.fromJson(Map<String, dynamic> json)
Creates a new object from the given json data.
factory

Properties

customTokens → bool?
no setterinherited
enabled → bool
no setterinherited
expireDate → Capabilities_FilesSharing_Public_ExpireDate?
no setterinherited
expireDateInternal → Capabilities_FilesSharing_Public_ExpireDateInternal?
no setterinherited
expireDateRemote → Capabilities_FilesSharing_Public_ExpireDateRemote?
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
no setterinherited
password → Capabilities_FilesSharing_Public_Password?
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sendMail → bool?
no setterinherited
upload → bool?
no setterinherited
uploadFilesDrop → bool?
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(Capabilities_FilesSharing_PublicBuilder)) → Capabilities_FilesSharing_Public
Rebuilds the instance.
inherited
toBuilder() → Capabilities_FilesSharing_PublicBuilder
Converts the instance to a builder B.
inherited
toJson() → Map<String, dynamic>
Parses this object into a json like map.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

serializer → Serializer<Capabilities_FilesSharing_Public>
Serializer for Capabilities_FilesSharing_Public.
no setter