DeletedShare class abstract

Implemented types

Constructors

DeletedShare([void b(DeletedShareBuilder)?])
Creates a new DeletedShare object using the builder pattern.
factory
DeletedShare.fromJson(Map<String, dynamic> json)
Creates a new object from the given json data.
factory

Properties

displaynameFileOwner → String
no setterinherited
displaynameOwner → String
no setterinherited
expiration → String?
no setterinherited
fileParent → int
no setterinherited
fileSource → int
no setterinherited
fileTarget → int
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
id → String
no setterinherited
itemSource → int
no setterinherited
itemType → String
no setterinherited
mimetype → String
no setterinherited
path → String
no setterinherited
permissions → int
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
shareType → int
no setterinherited
shareWith → String?
no setterinherited
shareWithDisplayname → String?
no setterinherited
no setterinherited
stime → int
no setterinherited
storage → int
no setterinherited
uidFileOwner → String
no setterinherited
uidOwner → String
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(DeletedShareBuilder)) → DeletedShare
Rebuilds the instance.
inherited
toBuilder() → DeletedShareBuilder
Converts the instance to a builder B.
inherited
toJson() → Map<String, dynamic>
Parses this object into a json like map.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

serializer → Serializer<DeletedShare>
Serializer for DeletedShare.
no setter