ShareInfoInfoRequestApplicationJson class abstract

Implemented types

Constructors

ShareInfoInfoRequestApplicationJson([void b(ShareInfoInfoRequestApplicationJsonBuilder)?])
Creates a new ShareInfoInfoRequestApplicationJson object using the builder pattern.
factory
ShareInfoInfoRequestApplicationJson.fromJson(Map<String, dynamic> json)
Creates a new object from the given json data.
factory

Properties

depth → int
Maximum depth to get info about.
no setterinherited
dir → String?
Subdirectory to get info about.
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
password → String?
Password of the share.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
t → String
Token of the share.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(ShareInfoInfoRequestApplicationJsonBuilder)) → ShareInfoInfoRequestApplicationJson
Rebuilds the instance.
inherited
toBuilder() → ShareInfoInfoRequestApplicationJsonBuilder
Converts the instance to a builder B.
inherited
toJson() → Map<String, dynamic>
Parses this object into a json like map.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

serializer → Serializer<ShareInfoInfoRequestApplicationJson>
Serializer for ShareInfoInfoRequestApplicationJson.
no setter