ShareapiUpdateShareRequestApplicationJson class abstract

Implemented types

Constructors

ShareapiUpdateShareRequestApplicationJson([void b(ShareapiUpdateShareRequestApplicationJsonBuilder)?])
Creates a new ShareapiUpdateShareRequestApplicationJson object using the builder pattern.
factory
ShareapiUpdateShareRequestApplicationJson.fromJson(Map<String, dynamic> json)
Creates a new object from the given json data.
factory

Properties

attributes → String?
New additional attributes.
no setterinherited
expireDate → String?
New expiry date.
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
hideDownload → String?
New condition if the download should be hidden.
no setterinherited
label → String?
New label.
no setterinherited
note → String?
New note.
no setterinherited
password → String?
New password.
no setterinherited
permissions → int?
New permissions.
no setterinherited
publicUpload → String?
New condition if public uploading is allowed.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sendMail → String?
if the share should be send by mail. Considering the share already exists, no mail will be send after the share is updated. You will have to use the sendMail action to send the mail.
no setterinherited
sendPasswordByTalk → String?
New condition if the password should be send over Talk.
no setterinherited
token → String?
New token.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(ShareapiUpdateShareRequestApplicationJsonBuilder)) → ShareapiUpdateShareRequestApplicationJson
Rebuilds the instance.
inherited
toBuilder() → ShareapiUpdateShareRequestApplicationJsonBuilder
Converts the instance to a builder B.
inherited
toJson() → Map<String, dynamic>
Parses this object into a json like map.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

serializer → Serializer<ShareapiUpdateShareRequestApplicationJson>
Serializer for ShareapiUpdateShareRequestApplicationJson.
no setter