ShareeRemote class abstract

Implemented types

Constructors

ShareeRemote([void b(ShareeRemoteBuilder)?])
Creates a new ShareeRemote object using the builder pattern.
factory
ShareeRemote.fromJson(Map<String, dynamic> json)
Creates a new object from the given json data.
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
label String
no setterinherited
name String
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type String
no setterinherited
uuid String
no setterinherited
value ShareeRemote_Value
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(ShareeRemoteBuilder)) ShareeRemote
Rebuilds the instance.
inherited
toBuilder() ShareeRemoteBuilder
Converts the instance to a builder B.
inherited
toJson() Map<String, dynamic>
Parses this object into a json like map.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

serializer → Serializer<ShareeRemote>
Serializer for ShareeRemote.
no setter