ShareesSearchResult class abstract

Implemented types

Constructors

ShareesSearchResult([void b(ShareesSearchResultBuilder)?])
Creates a new ShareesSearchResult object using the builder pattern.
factory
ShareesSearchResult.fromJson(Map<String, dynamic> json)
Creates a new object from the given json data.
factory

Properties

circles → BuiltList<ShareeCircle>
no setterinherited
emails → BuiltList<ShareeEmail>
no setterinherited
exact → ShareesSearchResult_Exact
no setterinherited
groups → BuiltList<ShareeGroup>
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
lookup → BuiltList<ShareeLookup>
no setterinherited
lookupEnabled → bool
no setterinherited
remoteGroups → BuiltList<ShareeRemoteGroup>
no setterinherited
remotes → BuiltList<ShareeRemote>
no setterinherited
rooms → BuiltList<ShareeRoom>
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
users → BuiltList<ShareeUser>
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(ShareesSearchResultBuilder)) → ShareesSearchResult
Rebuilds the instance.
inherited
toBuilder() → ShareesSearchResultBuilder
Converts the instance to a builder B.
inherited
toJson() → Map<String, dynamic>
Parses this object into a json like map.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

serializer → Serializer<ShareesSearchResult>
Serializer for ShareesSearchResult.
no setter