$PreviewClient class
Properties
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
$getPreview_Request({String? file, int? x, int? y, String? version, PreviewGetPreviewMimeFallback? mimeFallback})
→ Request
-
Get the preview for a file version.
-
$getPreview_Serializer()
→ DynamiteSerializer<Uint8List, void>
-
Builds a serializer to parse the response of $getPreview_Request.
-
getPreview({String? file, int? x, int? y, String? version, PreviewGetPreviewMimeFallback? mimeFallback})
→ Future<DynamiteResponse<Uint8List, void>>
-
Get the preview for a file version.
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
toString()
→ String
-
A string representation of this object.
inherited