$getPreview_Request method
- @experimental
- String? file,
- int? x,
- int? y,
- String? version,
- PreviewGetPreviewMimeFallback? mimeFallback,
Get the preview for a file version.
Returns a DynamiteRequest backing the getPreview operation.
Throws a DynamiteApiException if the API call does not return an expected status code.
Parameters:
filePath of the file. Defaults to"".xWidth of the preview. Defaults to44.yHeight of the preview. Defaults to44.versionVersion of the file to get the preview for. Defaults to"".mimeFallbackWhether to fallback to the mime icon if no preview is available. Defaults to0.
Status codes:
- 200: Preview returned
- 400: Getting preview is not possible
- 404: Preview not found
- 303: Redirect to the mime icon url if mimeFallback is true
See:
- getPreview for a method executing this request and parsing the response.
- $getPreview_Serializer for a converter to parse the
Responsefrom an executed this request.
Implementation
@_i2.experimental
_i3.Request $getPreview_Request({
String? file,
int? x,
int? y,
String? version,
PreviewGetPreviewMimeFallback? mimeFallback,
}) {
final _parameters = <String, Object?>{};
var __file = _$jsonSerializers.serialize(file, specifiedType: const FullType(String));
__file ??= '';
_parameters['file'] = __file;
var __x = _$jsonSerializers.serialize(x, specifiedType: const FullType(int));
__x ??= 44;
_parameters['x'] = __x;
var __y = _$jsonSerializers.serialize(y, specifiedType: const FullType(int));
__y ??= 44;
_parameters['y'] = __y;
var __version = _$jsonSerializers.serialize(version, specifiedType: const FullType(String));
__version ??= '';
_parameters['version'] = __version;
var __mimeFallback = _$jsonSerializers.serialize(
mimeFallback,
specifiedType: const FullType(PreviewGetPreviewMimeFallback),
);
__mimeFallback ??= 0;
_parameters['mimeFallback'] = __mimeFallback;
final _path = _i4.UriTemplate(
'/index.php/apps/files_versions/preview{?file*,x*,y*,version*,mimeFallback*}',
).expand(_parameters);
final _uri = Uri.parse('${_rootClient.baseURL}$_path');
final _request = _i3.Request('get', _uri);
_request.headers['Accept'] = '*/*';
// coverage:ignore-start
final authentication = _i5.IterableExtension(_rootClient.authentications)?.firstWhereOrNull(
(auth) => switch (auth) {
_i1.DynamiteHttpBearerAuthentication() || _i1.DynamiteHttpBasicAuthentication() => true,
_ => false,
},
);
if (authentication != null) {
_request.headers.addAll(authentication.headers);
} else {
throw Exception('Missing authentication for bearer_auth or basic_auth');
}
// coverage:ignore-end
return _request;
}