getPreview method
Future<DynamiteResponse<Uint8List, void> >
getPreview({
- String? file,
- int? x,
- int? y,
- String? version,
- PreviewGetPreviewMimeFallback? mimeFallback,
Get the preview for a file version.
Returns a Future containing a DynamiteResponse with the status code, deserialized body and headers.
Throws a DynamiteApiException if the API call does not return an expected status code.
Parameters:
filePath of the file. Defaults to"".xWidth of the preview. Defaults to44.yHeight of the preview. Defaults to44.versionVersion of the file to get the preview for. Defaults to"".mimeFallbackWhether to fallback to the mime icon if no preview is available. Defaults to0.
Status codes:
- 200: Preview returned
- 400: Getting preview is not possible
- 404: Preview not found
- 303: Redirect to the mime icon url if mimeFallback is true
See:
- $getPreview_Request for the request send by this method.
- $getPreview_Serializer for a converter to parse the
Responsefrom an executed request.
Implementation
Future<_i1.DynamiteResponse<Uint8List, void>> getPreview({
String? file,
int? x,
int? y,
String? version,
PreviewGetPreviewMimeFallback? mimeFallback,
}) async {
final _request = $getPreview_Request(file: file, x: x, y: y, version: version, mimeFallback: mimeFallback);
final _streamedResponse = await _rootClient.httpClient.send(_request);
final _response = await _i3.Response.fromStream(_streamedResponse);
final _serializer = $getPreview_Serializer();
return _i1.ResponseConverter<Uint8List, void>(_serializer).convert(_response);
}