$Client class

Available extensions

Constructors

$Client(Uri baseURL, {Client? httpClient, List<DynamiteAuthentication>? authentications})
Creates a new DynamiteClient for untagged requests.
$Client.fromClient(DynamiteClient client)
Creates a new $Client from another client.

Properties

authentications → List<DynamiteAuthentication>?
The available authentications for this client.
finalinherited
baseURL → Uri
The base server url used to build the request uri.
finalinherited
feeds → $FeedsClient
latefinal
folders → $FoldersClient
latefinal
hashCode → int
The hash code for this object.
no setterinherited
httpClient → Client
The base http client.
finalinherited
items → $ItemsClient
latefinal
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

$getSupportedApiVersions_Request() → Request
Returns a DynamiteRequest backing the getSupportedApiVersions operation. Throws a DynamiteApiException if the API call does not return an expected status code.
$getSupportedApiVersions_Serializer() → DynamiteSerializer<SupportedAPIVersions, void>
Builds a serializer to parse the response of $getSupportedApiVersions_Request.
getSupportedApiVersions() → Future<DynamiteResponse<SupportedAPIVersions, void>>
Returns a Future containing a DynamiteResponse with the status code, deserialized body and headers. Throws a DynamiteApiException if the API call does not return an expected status code.
getVersionCheck() → Future<VersionCheck>

Available on $Client, provided by the NewsVersionCheck extension

Check if the news app version is supported by this client
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited