addFeed method
Returns a Future containing a DynamiteResponse with the status code, deserialized body and headers.
Throws a DynamiteApiException if the API call does not return an expected status code.
Parameters:
urlfolderId
Status codes:
- 200
See:
- addFeedRaw for an experimental operation that returns a
DynamiteRawResponsethat can be serialized.
Implementation
Future<_i1.DynamiteResponse<ListFeeds, void>> addFeed({
required String url,
int? folderId,
}) async {
final rawResponse = addFeedRaw(
url: url,
folderId: folderId,
);
return rawResponse.future;
}