createFolder method
Returns a Future containing a DynamiteResponse with the status code, deserialized body and headers.
Throws a DynamiteApiException if the API call does not return an expected status code.
Parameters:
name
Status codes:
- 200
See:
- createFolderRaw for an experimental operation that returns a
DynamiteRawResponsethat can be serialized.
Implementation
Future<_i1.DynamiteResponse<ListFolders, void>> createFolder({required String name}) async {
final rawResponse = createFolderRaw(
name: name,
);
return rawResponse.future;
}