listArticles method
Returns a Future containing a DynamiteResponse with the status code, deserialized body and headers.
Throws a DynamiteApiException if the API call does not return an expected status code.
Parameters:
typeDefaults to3.idDefaults to0.getReadDefaults to1.batchSizeDefaults to-1.offsetDefaults to0.oldestFirstDefaults to0.
Status codes:
- 200
See:
- listArticlesRaw for an experimental operation that returns a
DynamiteRawResponsethat can be serialized.
Implementation
Future<_i1.DynamiteResponse<ListArticles, void>> listArticles({
int? type,
int? id,
int? getRead,
int? batchSize,
int? offset,
int? oldestFirst,
}) async {
final rawResponse = listArticlesRaw(
type: type,
id: id,
getRead: getRead,
batchSize: batchSize,
offset: offset,
oldestFirst: oldestFirst,
);
return rawResponse.future;
}