listUpdatedArticles method
Returns a Future containing a DynamiteResponse with the status code, deserialized body and headers.
Throws a DynamiteApiException if the API call does not return an expected status code.
Parameters:
typeDefaults to3.idDefaults to0.lastModifiedDefaults to0.
Status codes:
- 200
See:
- listUpdatedArticlesRaw for an experimental operation that returns a
DynamiteRawResponsethat can be serialized.
Implementation
Future<_i1.DynamiteResponse<ListArticles, void>> listUpdatedArticles({
int? type,
int? id,
int? lastModified,
}) async {
final rawResponse = listUpdatedArticlesRaw(
type: type,
id: id,
lastModified: lastModified,
);
return rawResponse.future;
}