unstarArticle method
Returns a Future containing a DynamiteResponse with the status code, deserialized body and headers.
Throws a DynamiteApiException if the API call does not return an expected status code.
Status codes:
- 200
See:
- unstarArticleRaw for an experimental operation that returns a
DynamiteRawResponsethat can be serialized.
Implementation
Future<_i1.DynamiteResponse<void, void>> unstarArticle({required int itemId}) async {
final rawResponse = unstarArticleRaw(
itemId: itemId,
);
return rawResponse.future;
}