$EmptyOCS_OcsInterface class sealed

Implementers
Annotations
  • @BuiltValue.new(instantiable: false)

Properties

data → BuiltList<JsonObject>
no setter
hashCode → int
The hash code for this object.
no setterinherited
meta → OCSMeta
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(void updates($EmptyOCS_OcsInterfaceBuilder)) → $EmptyOCS_OcsInterface
Rebuilds the instance.
toBuilder() → $EmptyOCS_OcsInterfaceBuilder
Converts the instance to a builder $EmptyOCS_OcsInterfaceBuilder.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited