$FeedInterface class sealed

Implementers
Annotations
  • @BuiltValue.new(instantiable: false)

Properties

added → int
no setter
no setter
folderId → int?
no setter
hashCode → int
The hash code for this object.
no setterinherited
id → int
no setter
items → BuiltList<Article>
no setter
lastUpdateError → String?
no setter
no setter
ordering → int
no setter
pinned → bool
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
title → String
no setter
unreadCount → int?
no setter
updateErrorCount → int
no setter
url → String
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(void updates($FeedInterfaceBuilder)) → $FeedInterface
Rebuilds the instance.
toBuilder() → $FeedInterfaceBuilder
Converts the instance to a builder $FeedInterfaceBuilder.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited