addFeed method
Returns a Future containing a DynamiteResponse with the status code, deserialized body and headers.
Throws a DynamiteApiException if the API call does not return an expected status code.
Parameters:
urlfolderId
Status codes:
- 200
See:
- $addFeed_Request for the request send by this method.
- $addFeed_Serializer for a converter to parse the
Responsefrom an executed request.
Implementation
Future<_i1.DynamiteResponse<ListFeeds, void>> addFeed({required String url, int? folderId}) async {
final _request = $addFeed_Request(url: url, folderId: folderId);
final _streamedResponse = await _rootClient.httpClient.send(_request);
final _response = await _i3.Response.fromStream(_streamedResponse);
final _serializer = $addFeed_Serializer();
return _i1.ResponseConverter<ListFeeds, void>(_serializer).convert(_response);
}