listArticles method
Returns a Future containing a DynamiteResponse with the status code, deserialized body and headers.
Throws a DynamiteApiException if the API call does not return an expected status code.
Parameters:
typeDefaults to3.idDefaults to0.getReadDefaults to1.batchSizeDefaults to-1.offsetDefaults to0.oldestFirstDefaults to0.
Status codes:
- 200
See:
- $listArticles_Request for the request send by this method.
- $listArticles_Serializer for a converter to parse the
Responsefrom an executed request.
Implementation
Future<_i1.DynamiteResponse<ListArticles, void>> listArticles({
int? type,
int? id,
int? getRead,
int? batchSize,
int? offset,
int? oldestFirst,
}) async {
final _request = $listArticles_Request(
type: type,
id: id,
getRead: getRead,
batchSize: batchSize,
offset: offset,
oldestFirst: oldestFirst,
);
final _streamedResponse = await _rootClient.httpClient.send(_request);
final _response = await _i3.Response.fromStream(_streamedResponse);
final _serializer = $listArticles_Serializer();
return _i1.ResponseConverter<ListArticles, void>(_serializer).convert(_response);
}