Article class abstract

Implemented types

Constructors

Article([void b(ArticleBuilder)?])
Creates a new Article object using the builder pattern.
factory
Article.fromJson(Map<String, dynamic> json)
Creates a new object from the given json data.
factory

Properties

author → String?
no setterinherited
body → String
no setterinherited
contentHash → String
no setterinherited
no setterinherited
enclosureMime → String?
no setterinherited
feedId → int
no setterinherited
fingerprint → String
no setterinherited
guid → String
no setterinherited
guidHash → String
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
id → int
no setterinherited
lastModified → int
no setterinherited
mediaDescription → String?
no setterinherited
mediaThumbnail → String?
no setterinherited
pubDate → int
no setterinherited
rtl → bool
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
starred → bool
no setterinherited
title → String
no setterinherited
unread → bool
no setterinherited
updatedDate → int?
no setterinherited
url → String?
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(ArticleBuilder)) → Article
Rebuilds the instance.
inherited
toBuilder() → ArticleBuilder
Converts the instance to a builder B.
inherited
toJson() → Map<String, dynamic>
Parses this object into a json like map.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

serializer → Serializer<Article>
Serializer for Article.
no setter