Feed class abstract

Implemented types

Constructors

Feed([void b(FeedBuilder)?])
Creates a new Feed object using the builder pattern.
factory
Feed.fromJson(Map<String, dynamic> json)
Creates a new object from the given json data.
factory

Properties

added → int
no setterinherited
no setterinherited
folderId → int?
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
id → int
no setterinherited
items → BuiltList<Article>
no setterinherited
lastUpdateError → String?
no setterinherited
no setterinherited
ordering → int
no setterinherited
pinned → bool
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
title → String
no setterinherited
unreadCount → int?
no setterinherited
updateErrorCount → int
no setterinherited
url → String
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(FeedBuilder)) → Feed
Rebuilds the instance.
inherited
toBuilder() → FeedBuilder
Converts the instance to a builder B.
inherited
toJson() → Map<String, dynamic>
Parses this object into a json like map.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

serializer → Serializer<Feed>
Serializer for Feed.
no setter