$Client class

Available extensions

Constructors

$Client(Uri baseURL, {Client? httpClient, List<DynamiteAuthentication>? authentications})
Creates a new DynamiteClient for untagged requests.
$Client.fromClient(DynamiteClient client)
Creates a new $Client from another client.

Properties

authentications → List<DynamiteAuthentication>?
The available authentications for this client.
finalinherited
baseURL → Uri
The base server url used to build the request uri.
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
httpClient → Client
The base http client.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

$createNote_Request({String? category, String? title, String? content, int? modified, int? favorite}) → Request
Returns a DynamiteRequest backing the createNote operation. Throws a DynamiteApiException if the API call does not return an expected status code.
$createNote_Serializer() → DynamiteSerializer<Note, void>
Builds a serializer to parse the response of $createNote_Request.
$deleteNote_Request({required int id}) → Request
Returns a DynamiteRequest backing the deleteNote operation. Throws a DynamiteApiException if the API call does not return an expected status code.
$deleteNote_Serializer() → DynamiteSerializer<BuiltList<Never>, void>
Builds a serializer to parse the response of $deleteNote_Request.
$getNote_Request({required int id, String? exclude, String? ifNoneMatch}) → Request
Returns a DynamiteRequest backing the getNote operation. Throws a DynamiteApiException if the API call does not return an expected status code.
$getNote_Serializer() → DynamiteSerializer<Note, void>
Builds a serializer to parse the response of $getNote_Request.
$getNotes_Request({String? category, String? exclude, int? pruneBefore, int? chunkSize, String? chunkCursor, String? ifNoneMatch}) → Request
Returns a DynamiteRequest backing the getNotes operation. Throws a DynamiteApiException if the API call does not return an expected status code.
$getNotes_Serializer() → DynamiteSerializer<BuiltList<Note>, void>
Builds a serializer to parse the response of $getNotes_Request.
$getSettings_Request() → Request
Returns a DynamiteRequest backing the getSettings operation. Throws a DynamiteApiException if the API call does not return an expected status code.
$getSettings_Serializer() → DynamiteSerializer<Settings, void>
Builds a serializer to parse the response of $getSettings_Request.
$updateNote_Request({required int id, String? content, int? modified, String? title, String? category, int? favorite, String? ifMatch}) → Request
Returns a DynamiteRequest backing the updateNote operation. Throws a DynamiteApiException if the API call does not return an expected status code.
$updateNote_Serializer() → DynamiteSerializer<Note, void>
Builds a serializer to parse the response of $updateNote_Request.
$updateSettings_Request({required Settings $body}) → Request
Returns a DynamiteRequest backing the updateSettings operation. Throws a DynamiteApiException if the API call does not return an expected status code.
$updateSettings_Serializer() → DynamiteSerializer<Settings, void>
Builds a serializer to parse the response of $updateSettings_Request.
createNote({String? category, String? title, String? content, int? modified, int? favorite}) → Future<DynamiteResponse<Note, void>>
Returns a Future containing a DynamiteResponse with the status code, deserialized body and headers. Throws a DynamiteApiException if the API call does not return an expected status code.
deleteNote({required int id}) → Future<DynamiteResponse<BuiltList<Never>, void>>
Returns a Future containing a DynamiteResponse with the status code, deserialized body and headers. Throws a DynamiteApiException if the API call does not return an expected status code.
getNote({required int id, String? exclude, String? ifNoneMatch}) → Future<DynamiteResponse<Note, void>>
Returns a Future containing a DynamiteResponse with the status code, deserialized body and headers. Throws a DynamiteApiException if the API call does not return an expected status code.
getNotes({String? category, String? exclude, int? pruneBefore, int? chunkSize, String? chunkCursor, String? ifNoneMatch}) → Future<DynamiteResponse<BuiltList<Note>, void>>
Returns a Future containing a DynamiteResponse with the status code, deserialized body and headers. Throws a DynamiteApiException if the API call does not return an expected status code.
getSettings() → Future<DynamiteResponse<Settings, void>>
Returns a Future containing a DynamiteResponse with the status code, deserialized body and headers. Throws a DynamiteApiException if the API call does not return an expected status code.
getVersionCheck(OcsGetCapabilitiesResponseApplicationJson_Ocs_Data capabilities) → VersionCheck

Available on $Client, provided by the NotesVersionCheck extension

Check if the notes app version is supported by this client
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
updateNote({required int id, String? content, int? modified, String? title, String? category, int? favorite, String? ifMatch}) → Future<DynamiteResponse<Note, void>>
Returns a Future containing a DynamiteResponse with the status code, deserialized body and headers. Throws a DynamiteApiException if the API call does not return an expected status code.
updateSettings({required Settings $body}) → Future<DynamiteResponse<Settings, void>>
Returns a Future containing a DynamiteResponse with the status code, deserialized body and headers. Throws a DynamiteApiException if the API call does not return an expected status code.

Operators

operator ==(Object other) → bool
The equality operator.
inherited