$NoteInterface class sealed

Implementers
Annotations
  • @BuiltValue.new(instantiable: false)

Properties

category → String
no setter
content → String
no setter
error → bool
no setter
errorType → String
no setter
etag → String
no setter
favorite → bool
no setter
hashCode → int
The hash code for this object.
no setterinherited
id → int
no setter
modified → int
no setter
readonly → bool
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
title → String
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(void updates($NoteInterfaceBuilder)) → $NoteInterface
Rebuilds the instance.
toBuilder() → $NoteInterfaceBuilder
Converts the instance to a builder $NoteInterfaceBuilder.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited