$SettingsInterface class sealed

Implementers
Annotations
  • @BuiltValue.new(instantiable: false)

Properties

fileSuffix → String
no setter
hashCode → int
The hash code for this object.
no setterinherited
noteMode → Settings_NoteMode
no setter
notesPath → String
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(void updates($SettingsInterfaceBuilder)) → $SettingsInterface
Rebuilds the instance.
toBuilder() → $SettingsInterfaceBuilder
Converts the instance to a builder $SettingsInterfaceBuilder.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited