Note class abstract

Implemented types

Constructors

Note([void b(NoteBuilder)?])
Creates a new Note object using the builder pattern.
factory
Note.fromJson(Map<String, dynamic> json)
Creates a new object from the given json data.
factory

Properties

category → String
no setterinherited
content → String
no setterinherited
error → bool
no setterinherited
errorType → String
no setterinherited
etag → String
no setterinherited
favorite → bool
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
id → int
no setterinherited
modified → int
no setterinherited
readonly → bool
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
title → String
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(NoteBuilder)) → Note
Rebuilds the instance.
inherited
toBuilder() → NoteBuilder
Converts the instance to a builder B.
inherited
toJson() → Map<String, dynamic>
Parses this object into a json like map.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

serializer → Serializer<Note>
Serializer for Note.
no setter