selfTestPush method

Future<DynamiteResponse<ApiSelfTestPushResponseApplicationJson, void>> selfTestPush({
  1. required String apiVersion3,
  2. bool? oCSAPIRequest,
})

Send a test notification to push registered mobile apps.

Required capability: ocs-endpoints > test-push.

Returns a Future containing a DynamiteResponse with the status code, deserialized body and headers. Throws a DynamiteApiException if the API call does not return an expected status code.

Parameters:

  • apiVersion3
  • oCSAPIRequest Required to be true for the API request to pass. Defaults to true.

Status codes:

  • 200: Test notification generated successfully, but the device should still show the message to the user
  • 400: Test notification could not be generated, show the message to the user

See:

Implementation

Future<_i1.DynamiteResponse<ApiSelfTestPushResponseApplicationJson, void>> selfTestPush({
  required String apiVersion3,
  bool? oCSAPIRequest,
}) async {
  final _request = $selfTestPush_Request(apiVersion3: apiVersion3, oCSAPIRequest: oCSAPIRequest);
  final _streamedResponse = await _rootClient.httpClient.send(_request);
  final _response = await _i3.Response.fromStream(_streamedResponse);

  final _serializer = $selfTestPush_Serializer();
  return _i1.ResponseConverter<ApiSelfTestPushResponseApplicationJson, void>(_serializer).convert(_response);
}