$ApiGenerateNotificationV3RequestApplicationJsonInterface class sealed
- Implementers
- Annotations
-
- @BuiltValue.new(instantiable: false)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- message → String
-
Message of the notification.
no setter
-
messageParameters
→ BuiltMap<
String, BuiltMap< ?String, JsonObject> > -
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- subject → String
-
Subject of the notification.
no setter
-
subjectParameters
→ BuiltMap<
String, BuiltMap< ?String, JsonObject> > -
no setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
rebuild(
void updates($ApiGenerateNotificationV3RequestApplicationJsonInterfaceBuilder)) → $ApiGenerateNotificationV3RequestApplicationJsonInterface - Rebuilds the instance.
-
toBuilder(
) → $ApiGenerateNotificationV3RequestApplicationJsonInterfaceBuilder - Converts the instance to a builder $ApiGenerateNotificationV3RequestApplicationJsonInterfaceBuilder.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited