$ApiClient class

Constructors

$ApiClient($Client _rootClient)
Creates a new DynamiteClient for api requests.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

$generate_Request({bool? oCSAPIRequest}) → Request
Generate a random password that validates against the enabled password policy rules.
$generate_Serializer() → DynamiteSerializer<ApiGenerateResponseApplicationJson, void>
Builds a serializer to parse the response of $generate_Request.
$validate_Request({required ApiValidateRequestApplicationJson $body, bool? oCSAPIRequest}) → Request
Validate a password against the enabled password policy rules.
$validate_Serializer() → DynamiteSerializer<ApiValidateResponseApplicationJson, void>
Builds a serializer to parse the response of $validate_Request.
generate({bool? oCSAPIRequest}) Future<DynamiteResponse<ApiGenerateResponseApplicationJson, void>>
Generate a random password that validates against the enabled password policy rules.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
validate({required ApiValidateRequestApplicationJson $body, bool? oCSAPIRequest}) Future<DynamiteResponse<ApiValidateResponseApplicationJson, void>>
Validate a password against the enabled password policy rules.

Operators

operator ==(Object other) bool
The equality operator.
inherited