generate method
Future<DynamiteResponse<ApiGenerateResponseApplicationJson, void> >
generate({
- bool? oCSAPIRequest,
Generate a random password that validates against the enabled password policy rules.
Returns a Future containing a DynamiteResponse with the status code, deserialized body and headers.
Throws a DynamiteApiException if the API call does not return an expected status code.
Parameters:
oCSAPIRequestRequired to be true for the API request to pass. Defaults totrue.
Status codes:
- 200: Password generated
- 409: Generated password accidentally failed to validate against the rules, retry.
See:
- $generate_Request for the request send by this method.
- $generate_Serializer for a converter to parse the
Responsefrom an executed request.
Implementation
Future<_i1.DynamiteResponse<ApiGenerateResponseApplicationJson, void>> generate({bool? oCSAPIRequest}) async {
final _request = $generate_Request(oCSAPIRequest: oCSAPIRequest);
final _streamedResponse = await _rootClient.httpClient.send(_request);
final _response = await _i3.Response.fromStream(_streamedResponse);
final _serializer = $generate_Serializer();
return _i1.ResponseConverter<ApiGenerateResponseApplicationJson, void>(_serializer).convert(_response);
}