rebuild abstract method

Rebuilds the instance.

The result is the same as this instance but with updates applied. updates is a function that takes a builder $ApiGenerateResponseApplicationJson_Ocs_DataInterfaceBuilder.

Implementation

$ApiGenerateResponseApplicationJson_Ocs_DataInterface rebuild(
  void Function($ApiGenerateResponseApplicationJson_Ocs_DataInterfaceBuilder) updates,
);