$Capabilities_PasswordPolicyInterface class sealed

Implementers
Annotations
  • @BuiltValue.new(instantiable: false)

Properties

api Capabilities_PasswordPolicy_Api
no setter
enforceNonCommonPassword bool
no setter
enforceNumericCharacters bool
no setter
enforceSpecialCharacters bool
no setter
enforceUpperLowerCase bool
no setter
hashCode int
The hash code for this object.
no setterinherited
minLength int
no setter
policies → BuiltMap<String, Capabilities_PasswordPolicy_Policies>
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(void updates($Capabilities_PasswordPolicyInterfaceBuilder)) $Capabilities_PasswordPolicyInterface
Rebuilds the instance.
toBuilder() $Capabilities_PasswordPolicyInterfaceBuilder
Converts the instance to a builder $Capabilities_PasswordPolicyInterfaceBuilder.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited