rebuild abstract method

Rebuilds the instance.

The result is the same as this instance but with updates applied. updates is a function that takes a builder $Capabilities_PasswordPolicyInterfaceBuilder.

Implementation

$Capabilities_PasswordPolicyInterface rebuild(void Function($Capabilities_PasswordPolicyInterfaceBuilder) updates);