$Capabilities_PasswordPolicy_ApiInterface class sealed

Implementers
Annotations
  • @BuiltValue.new(instantiable: false)

Properties

generate String
no setter
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
validate String
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(void updates($Capabilities_PasswordPolicy_ApiInterfaceBuilder)) $Capabilities_PasswordPolicy_ApiInterface
Rebuilds the instance.
toBuilder() $Capabilities_PasswordPolicy_ApiInterfaceBuilder
Converts the instance to a builder $Capabilities_PasswordPolicy_ApiInterfaceBuilder.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited