$Capabilities_PasswordPolicy_PoliciesInterface class sealed

Implementers
Annotations
  • @BuiltValue.new(instantiable: false)

Properties

enforceHaveIBeenPwned bool
no setter
enforceNonCommonPassword bool
no setter
enforceNumericCharacters bool
no setter
enforceSpecialCharacters bool
no setter
enforceUpperLowerCase bool
no setter
hashCode int
The hash code for this object.
no setterinherited
minLength int
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(void updates($Capabilities_PasswordPolicy_PoliciesInterfaceBuilder)) $Capabilities_PasswordPolicy_PoliciesInterface
Rebuilds the instance.
toBuilder() $Capabilities_PasswordPolicy_PoliciesInterfaceBuilder
Converts the instance to a builder $Capabilities_PasswordPolicy_PoliciesInterfaceBuilder.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited