ApiValidateResponseApplicationJson_Ocs_Data class abstract

Implemented types

Constructors

ApiValidateResponseApplicationJson_Ocs_Data([void b(ApiValidateResponseApplicationJson_Ocs_DataBuilder)?])
Creates a new ApiValidateResponseApplicationJson_Ocs_Data object using the builder pattern.
factory
ApiValidateResponseApplicationJson_Ocs_Data.fromJson(Map<String, dynamic> json)
Creates a new object from the given json data.
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
passed bool
no setterinherited
reason String?
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(ApiValidateResponseApplicationJson_Ocs_DataBuilder)) ApiValidateResponseApplicationJson_Ocs_Data
Rebuilds the instance.
inherited
toBuilder() ApiValidateResponseApplicationJson_Ocs_DataBuilder
Converts the instance to a builder B.
inherited
toJson() Map<String, dynamic>
Parses this object into a json like map.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

serializer → Serializer<ApiValidateResponseApplicationJson_Ocs_Data>
Serializer for ApiValidateResponseApplicationJson_Ocs_Data.
no setter