Capabilities_PasswordPolicy class abstract

Implemented types

Constructors

Capabilities_PasswordPolicy([void b(Capabilities_PasswordPolicyBuilder)?])
Creates a new Capabilities_PasswordPolicy object using the builder pattern.
factory
Capabilities_PasswordPolicy.fromJson(Map<String, dynamic> json)
Creates a new object from the given json data.
factory

Properties

api Capabilities_PasswordPolicy_Api
no setterinherited
enforceNonCommonPassword bool
no setterinherited
enforceNumericCharacters bool
no setterinherited
enforceSpecialCharacters bool
no setterinherited
enforceUpperLowerCase bool
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
minLength int
no setterinherited
policies → BuiltMap<String, Capabilities_PasswordPolicy_Policies>
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(Capabilities_PasswordPolicyBuilder)) Capabilities_PasswordPolicy
Rebuilds the instance.
inherited
toBuilder() Capabilities_PasswordPolicyBuilder
Converts the instance to a builder B.
inherited
toJson() Map<String, dynamic>
Parses this object into a json like map.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

serializer → Serializer<Capabilities_PasswordPolicy>
Serializer for Capabilities_PasswordPolicy.
no setter