Capabilities_PasswordPolicyBuilder class

Implemented types

Properties

api Capabilities_PasswordPolicy_ApiBuilder
covariantgetter/setter pairoverride
enforceNonCommonPassword bool?
covariantgetter/setter pairoverride
enforceNumericCharacters bool?
covariantgetter/setter pairoverride
enforceSpecialCharacters bool?
covariantgetter/setter pairoverride
enforceUpperLowerCase bool?
covariantgetter/setter pairoverride
hashCode int
The hash code for this object.
no setterinherited
minLength int?
covariantgetter/setter pairoverride
policies ↔ MapBuilder<String, Capabilities_PasswordPolicy_Policies>
covariantgetter/setter pairoverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

build() Capabilities_PasswordPolicy
Builds.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
replace(covariant Capabilities_PasswordPolicy other) → void
Replaces the value in the builder with a new one.
override
toString() String
A string representation of this object.
inherited
update(void updates(Capabilities_PasswordPolicyBuilder)?) → void
Applies updates.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited