Capabilities_PasswordPolicy_Policies class abstract

Implemented types

Constructors

Capabilities_PasswordPolicy_Policies([void b(Capabilities_PasswordPolicy_PoliciesBuilder)?])
Creates a new Capabilities_PasswordPolicy_Policies object using the builder pattern.
factory
Capabilities_PasswordPolicy_Policies.fromJson(Map<String, dynamic> json)
Creates a new object from the given json data.
factory

Properties

enforceHaveIBeenPwned bool
no setterinherited
enforceNonCommonPassword bool
no setterinherited
enforceNumericCharacters bool
no setterinherited
enforceSpecialCharacters bool
no setterinherited
enforceUpperLowerCase bool
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
minLength int
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(Capabilities_PasswordPolicy_PoliciesBuilder)) Capabilities_PasswordPolicy_Policies
Rebuilds the instance.
inherited
toBuilder() Capabilities_PasswordPolicy_PoliciesBuilder
Converts the instance to a builder B.
inherited
toJson() Map<String, dynamic>
Parses this object into a json like map.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

serializer → Serializer<Capabilities_PasswordPolicy_Policies>
Serializer for Capabilities_PasswordPolicy_Policies.
no setter