$UserDetails_BackendCapabilitiesInterface class sealed

Implementers
Annotations
  • @BuiltValue.new(instantiable: false)

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
setDisplayName → bool
no setter
setPassword → bool
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(void updates($UserDetails_BackendCapabilitiesInterfaceBuilder)) → $UserDetails_BackendCapabilitiesInterface
Rebuilds the instance.
toBuilder() → $UserDetails_BackendCapabilitiesInterfaceBuilder
Converts the instance to a builder $UserDetails_BackendCapabilitiesInterfaceBuilder.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited