$UsersAddUserRequestApplicationJsonInterfaceBuilder class abstract mixin

Implementers

Properties

displayName ↔ String?
getter/setter pair
email ↔ String?
getter/setter pair
groups ↔ ListBuilder<String>
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
language ↔ String?
getter/setter pair
manager ↔ String?
getter/setter pair
password ↔ String?
getter/setter pair
quota ↔ String?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
subadmin ↔ ListBuilder<String>
getter/setter pair
userid ↔ String?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
replace($UsersAddUserRequestApplicationJsonInterface other) → void
toString() → String
A string representation of this object.
inherited
update(void updates($UsersAddUserRequestApplicationJsonInterfaceBuilder)) → void

Operators

operator ==(Object other) → bool
The equality operator.
inherited