$UsersDisableUserResponseApplicationJsonInterface class sealed

Implementers
Annotations
  • @BuiltValue.new(instantiable: false)

Properties

hashCode → int
The hash code for this object.
no setterinherited
ocs → UsersDisableUserResponseApplicationJson_Ocs
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(void updates($UsersDisableUserResponseApplicationJsonInterfaceBuilder)) → $UsersDisableUserResponseApplicationJsonInterface
Rebuilds the instance.
toBuilder() → $UsersDisableUserResponseApplicationJsonInterfaceBuilder
Converts the instance to a builder $UsersDisableUserResponseApplicationJsonInterfaceBuilder.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited