rebuild abstract method
Rebuilds the instance.
The result is the same as this instance but with updates applied.
updates is a function that takes a builder $UsersGetUserSubAdminGroupsDetailsResponseApplicationJson_Ocs_DataInterfaceBuilder.
Implementation
$UsersGetUserSubAdminGroupsDetailsResponseApplicationJson_Ocs_DataInterface rebuild(
void Function($UsersGetUserSubAdminGroupsDetailsResponseApplicationJson_Ocs_DataInterfaceBuilder) updates,
);