rebuild abstract method

Rebuilds the instance.

The result is the same as this instance but with updates applied. updates is a function that takes a builder $UsersGetUsersGroupsDetailsResponseApplicationJson_OcsInterfaceBuilder.

Implementation

$UsersGetUsersGroupsDetailsResponseApplicationJson_OcsInterface rebuild(
  void Function($UsersGetUsersGroupsDetailsResponseApplicationJson_OcsInterfaceBuilder) updates,
);