AppConfigGetAppsResponseApplicationJson class abstract

Implemented types

Constructors

AppConfigGetAppsResponseApplicationJson([void b(AppConfigGetAppsResponseApplicationJsonBuilder)?])
Creates a new AppConfigGetAppsResponseApplicationJson object using the builder pattern.
factory
AppConfigGetAppsResponseApplicationJson.fromJson(Map<String, dynamic> json)
Creates a new object from the given json data.
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
ocs → AppConfigGetAppsResponseApplicationJson_Ocs
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(AppConfigGetAppsResponseApplicationJsonBuilder)) → AppConfigGetAppsResponseApplicationJson
Rebuilds the instance.
inherited
toBuilder() → AppConfigGetAppsResponseApplicationJsonBuilder
Converts the instance to a builder B.
inherited
toJson() → Map<String, dynamic>
Parses this object into a json like map.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

serializer → Serializer<AppConfigGetAppsResponseApplicationJson>
Serializer for AppConfigGetAppsResponseApplicationJson.
no setter