UserDetailsQuotaBuilder class

Implemented types

Constructors

UserDetailsQuotaBuilder()

Properties

free ↔ num?
covariantgetter/setter pairoverride
hashCode → int
The hash code for this object.
no setterinherited
quota ↔ UserDetailsQuota_Quota?
covariantgetter/setter pairoverride
relative ↔ num?
covariantgetter/setter pairoverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
total ↔ num?
covariantgetter/setter pairoverride
used ↔ num?
covariantgetter/setter pairoverride

Methods

build() → UserDetailsQuota
Builds.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
replace(covariant UserDetailsQuota other) → void
Replaces the value in the builder with a new one.
override
toString() → String
A string representation of this object.
inherited
update(void updates(UserDetailsQuotaBuilder)?) → void
Applies updates.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited