UsersAddUserRequestApplicationJson class abstract

Implemented types

Constructors

UsersAddUserRequestApplicationJson([void b(UsersAddUserRequestApplicationJsonBuilder)?])
Creates a new UsersAddUserRequestApplicationJson object using the builder pattern.
factory
UsersAddUserRequestApplicationJson.fromJson(Map<String, dynamic> json)
Creates a new object from the given json data.
factory

Properties

displayName → String
Display name of the user.
no setterinherited
email → String
Email of the user.
no setterinherited
groups → BuiltList<String>
Groups of the user.
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
language → String
Language of the user.
no setterinherited
manager → String?
Manager of the user.
no setterinherited
password → String
Password of the user.
no setterinherited
quota → String
Quota of the user.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
subadmin → BuiltList<String>
Groups where the user is subadmin.
no setterinherited
userid → String
ID of the user.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(UsersAddUserRequestApplicationJsonBuilder)) → UsersAddUserRequestApplicationJson
Rebuilds the instance.
inherited
toBuilder() → UsersAddUserRequestApplicationJsonBuilder
Converts the instance to a builder B.
inherited
toJson() → Map<String, dynamic>
Parses this object into a json like map.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

serializer → Serializer<UsersAddUserRequestApplicationJson>
Serializer for UsersAddUserRequestApplicationJson.
no setter