UsersGetUserSubAdminGroupsDetailsResponseApplicationJson class abstract

Implemented types

Constructors

UsersGetUserSubAdminGroupsDetailsResponseApplicationJson([void b(UsersGetUserSubAdminGroupsDetailsResponseApplicationJsonBuilder)?])
Creates a new UsersGetUserSubAdminGroupsDetailsResponseApplicationJson object using the builder pattern.
factory
UsersGetUserSubAdminGroupsDetailsResponseApplicationJson.fromJson(Map<String, dynamic> json)
Creates a new object from the given json data.
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
ocs UsersGetUserSubAdminGroupsDetailsResponseApplicationJson_Ocs
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(UsersGetUserSubAdminGroupsDetailsResponseApplicationJsonBuilder)) UsersGetUserSubAdminGroupsDetailsResponseApplicationJson
Rebuilds the instance.
inherited
toBuilder() UsersGetUserSubAdminGroupsDetailsResponseApplicationJsonBuilder
Converts the instance to a builder B.
inherited
toJson() Map<String, dynamic>
Parses this object into a json like map.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

serializer → Serializer<UsersGetUserSubAdminGroupsDetailsResponseApplicationJson>
Serializer for UsersGetUserSubAdminGroupsDetailsResponseApplicationJson.
no setter