replace method
Replaces the value in the builder with a new one.
The implementation of this method will be generated for you by the built_value generator.
Implementation
@override
void replace(covariant UsersGetUserSubAdminGroupsDetailsResponseApplicationJson other) {
_$v = other as _$UsersGetUserSubAdminGroupsDetailsResponseApplicationJson;
}