UsersGetUserSubAdminGroupsDetailsResponseApplicationJson_Ocs_Data class abstract

Implemented types

Constructors

UsersGetUserSubAdminGroupsDetailsResponseApplicationJson_Ocs_Data([void b(UsersGetUserSubAdminGroupsDetailsResponseApplicationJson_Ocs_DataBuilder)?])
Creates a new UsersGetUserSubAdminGroupsDetailsResponseApplicationJson_Ocs_Data object using the builder pattern.
factory
UsersGetUserSubAdminGroupsDetailsResponseApplicationJson_Ocs_Data.fromJson(Map<String, dynamic> json)
Creates a new object from the given json data.
factory

Properties

groups → BuiltList<GroupDetails>
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(UsersGetUserSubAdminGroupsDetailsResponseApplicationJson_Ocs_DataBuilder)) UsersGetUserSubAdminGroupsDetailsResponseApplicationJson_Ocs_Data
Rebuilds the instance.
inherited
toBuilder() UsersGetUserSubAdminGroupsDetailsResponseApplicationJson_Ocs_DataBuilder
Converts the instance to a builder B.
inherited
toJson() Map<String, dynamic>
Parses this object into a json like map.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

serializer → Serializer<UsersGetUserSubAdminGroupsDetailsResponseApplicationJson_Ocs_Data>
Serializer for UsersGetUserSubAdminGroupsDetailsResponseApplicationJson_Ocs_Data.
no setter