UsersGetUsersGroupsDetailsResponseApplicationJson_Ocs class abstract

Implemented types

Constructors

UsersGetUsersGroupsDetailsResponseApplicationJson_Ocs([void b(UsersGetUsersGroupsDetailsResponseApplicationJson_OcsBuilder)?])
Creates a new UsersGetUsersGroupsDetailsResponseApplicationJson_Ocs object using the builder pattern.
factory
UsersGetUsersGroupsDetailsResponseApplicationJson_Ocs.fromJson(Map<String, dynamic> json)
Creates a new object from the given json data.
factory

Properties

data → UsersGetUsersGroupsDetailsResponseApplicationJson_Ocs_Data
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
meta → OCSMeta
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(UsersGetUsersGroupsDetailsResponseApplicationJson_OcsBuilder)) → UsersGetUsersGroupsDetailsResponseApplicationJson_Ocs
Rebuilds the instance.
inherited
toBuilder() → UsersGetUsersGroupsDetailsResponseApplicationJson_OcsBuilder
Converts the instance to a builder B.
inherited
toJson() → Map<String, dynamic>
Parses this object into a json like map.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

serializer → Serializer<UsersGetUsersGroupsDetailsResponseApplicationJson_Ocs>
Serializer for UsersGetUsersGroupsDetailsResponseApplicationJson_Ocs.
no setter