UsersGetUsersGroupsResponseApplicationJson_Ocs class abstract

Implemented types

Constructors

UsersGetUsersGroupsResponseApplicationJson_Ocs([void b(UsersGetUsersGroupsResponseApplicationJson_OcsBuilder)?])
Creates a new UsersGetUsersGroupsResponseApplicationJson_Ocs object using the builder pattern.
factory
UsersGetUsersGroupsResponseApplicationJson_Ocs.fromJson(Map<String, dynamic> json)
Creates a new object from the given json data.
factory

Properties

data → UsersGetUsersGroupsResponseApplicationJson_Ocs_Data
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
meta → OCSMeta
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(UsersGetUsersGroupsResponseApplicationJson_OcsBuilder)) → UsersGetUsersGroupsResponseApplicationJson_Ocs
Rebuilds the instance.
inherited
toBuilder() → UsersGetUsersGroupsResponseApplicationJson_OcsBuilder
Converts the instance to a builder B.
inherited
toJson() → Map<String, dynamic>
Parses this object into a json like map.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

serializer → Serializer<UsersGetUsersGroupsResponseApplicationJson_Ocs>
Serializer for UsersGetUsersGroupsResponseApplicationJson_Ocs.
no setter