$DeclarativeFormInterface class sealed

Implementers
Annotations
  • @BuiltValue.new(instantiable: false)

Properties

app → String
no setter
description → String?
no setter
docUrl → String?
no setter
fields → BuiltList<DeclarativeFormField>
no setter
hashCode → int
The hash code for this object.
no setterinherited
id → String
no setter
priority → int
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sectionId → String
no setter
sectionType → DeclarativeForm_SectionType
no setter
storageType → DeclarativeForm_StorageType
no setter
title → String
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(void updates($DeclarativeFormInterfaceBuilder)) → $DeclarativeFormInterface
Rebuilds the instance.
toBuilder() → $DeclarativeFormInterfaceBuilder
Converts the instance to a builder $DeclarativeFormInterfaceBuilder.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited