$DeclarativeSettingsSetValueRequestApplicationJsonInterface class sealed

Implementers
Annotations
  • @BuiltValue.new(instantiable: false)

Properties

app → String
ID of the app.
no setter
fieldId → String
ID of the field.
no setter
formId → String
ID of the form.
no setter
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
value → JsonObject
Value to be saved.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(void updates($DeclarativeSettingsSetValueRequestApplicationJsonInterfaceBuilder)) → $DeclarativeSettingsSetValueRequestApplicationJsonInterface
Rebuilds the instance.
toBuilder() → $DeclarativeSettingsSetValueRequestApplicationJsonInterfaceBuilder
Converts the instance to a builder $DeclarativeSettingsSetValueRequestApplicationJsonInterfaceBuilder.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited