DeclarativeForm class abstract

Implemented types

Constructors

DeclarativeForm([void b(DeclarativeFormBuilder)?])
Creates a new DeclarativeForm object using the builder pattern.
factory
DeclarativeForm.fromJson(Map<String, dynamic> json)
Creates a new object from the given json data.
factory

Properties

app → String
no setterinherited
description → String?
no setterinherited
docUrl → String?
no setterinherited
fields → BuiltList<DeclarativeFormField>
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
id → String
no setterinherited
priority → int
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sectionId → String
no setterinherited
sectionType → DeclarativeForm_SectionType
no setterinherited
storageType → DeclarativeForm_StorageType
no setterinherited
title → String
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(DeclarativeFormBuilder)) → DeclarativeForm
Rebuilds the instance.
inherited
toBuilder() → DeclarativeFormBuilder
Converts the instance to a builder B.
inherited
toJson() → Map<String, dynamic>
Parses this object into a json like map.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

serializer → Serializer<DeclarativeForm>
Serializer for DeclarativeForm.
no setter