DeclarativeSettingsSetValueRequestApplicationJson class abstract

Implemented types

Constructors

DeclarativeSettingsSetValueRequestApplicationJson([void b(DeclarativeSettingsSetValueRequestApplicationJsonBuilder)?])
Creates a new DeclarativeSettingsSetValueRequestApplicationJson object using the builder pattern.
factory
DeclarativeSettingsSetValueRequestApplicationJson.fromJson(Map<String, dynamic> json)
Creates a new object from the given json data.
factory

Properties

app → String
ID of the app.
no setterinherited
fieldId → String
ID of the field.
no setterinherited
formId → String
ID of the form.
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
value → JsonObject
Value to be saved.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(DeclarativeSettingsSetValueRequestApplicationJsonBuilder)) → DeclarativeSettingsSetValueRequestApplicationJson
Rebuilds the instance.
inherited
toBuilder() → DeclarativeSettingsSetValueRequestApplicationJsonBuilder
Converts the instance to a builder B.
inherited
toJson() → Map<String, dynamic>
Parses this object into a json like map.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

serializer → Serializer<DeclarativeSettingsSetValueRequestApplicationJson>
Serializer for DeclarativeSettingsSetValueRequestApplicationJson.
no setter