$Capabilities_FilesSharing_SharebymailInterface class sealed

Implementers
Annotations
  • @BuiltValue.new(instantiable: false)

Properties

enabled → bool
no setter
expireDate → Capabilities_FilesSharing_Sharebymail_ExpireDate
no setter
hashCode → int
The hash code for this object.
no setterinherited
password → Capabilities_FilesSharing_Sharebymail_Password
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sendPasswordByMail → bool
no setter
uploadFilesDrop → Capabilities_FilesSharing_Sharebymail_UploadFilesDrop
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(void updates($Capabilities_FilesSharing_SharebymailInterfaceBuilder)) → $Capabilities_FilesSharing_SharebymailInterface
Rebuilds the instance.
toBuilder() → $Capabilities_FilesSharing_SharebymailInterfaceBuilder
Converts the instance to a builder $Capabilities_FilesSharing_SharebymailInterfaceBuilder.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited