$AvatarEmojiAvatarRequestApplicationJsonInterface class sealed

Implementers
Annotations
  • @BuiltValue.new(instantiable: false)

Properties

color → String?
Color of the emoji.
no setter
emoji → String
Emoji.
no setter
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(void updates($AvatarEmojiAvatarRequestApplicationJsonInterfaceBuilder)) → $AvatarEmojiAvatarRequestApplicationJsonInterface
Rebuilds the instance.
toBuilder() → $AvatarEmojiAvatarRequestApplicationJsonInterfaceBuilder
Converts the instance to a builder $AvatarEmojiAvatarRequestApplicationJsonInterfaceBuilder.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited