$BotWithDetailsInterface class sealed

Implemented types
Implementers
Annotations
  • @BuiltValue.new(instantiable: false)

Properties

description → String?
no setterinherited
errorCount → int
no setter
features → int
no setter
hashCode → int
The hash code for this object.
no setterinherited
id → int
no setterinherited
lastErrorDate → int
no setter
lastErrorMessage → String
no setter
name → String
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
state → int
no setterinherited
url → String
no setter
urlHash → String
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(void updates($BotWithDetailsInterfaceBuilder)) → $BotWithDetailsInterface
Rebuilds the instance.
override
toBuilder() → $BotWithDetailsInterfaceBuilder
Converts the instance to a builder $BotWithDetailsInterfaceBuilder.
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited