stopBreakoutRooms method
Future<DynamiteResponse<BreakoutRoomStopBreakoutRoomsResponseApplicationJson, void> >
stopBreakoutRooms({
- required String token,
- BreakoutRoomStopBreakoutRoomsApiVersion? apiVersion,
- bool? oCSAPIRequest,
Stop the breakout rooms.
Returns a Future containing a DynamiteResponse with the status code, deserialized body and headers.
Throws a DynamiteApiException if the API call does not return an expected status code.
Parameters:
apiVersionDefaults to"v1".tokenoCSAPIRequestRequired to be true for the API request to pass. Defaults totrue.
Status codes:
- 200: Breakout rooms stopped successfully
- 400: Stopping breakout rooms is not possible
See:
- $stopBreakoutRooms_Request for the request send by this method.
- $stopBreakoutRooms_Serializer for a converter to parse the
Responsefrom an executed request.
Implementation
Future<_i1.DynamiteResponse<BreakoutRoomStopBreakoutRoomsResponseApplicationJson, void>> stopBreakoutRooms({
required String token,
BreakoutRoomStopBreakoutRoomsApiVersion? apiVersion,
bool? oCSAPIRequest,
}) async {
final _request = $stopBreakoutRooms_Request(token: token, apiVersion: apiVersion, oCSAPIRequest: oCSAPIRequest);
final _streamedResponse = await _rootClient.httpClient.send(_request);
final _response = await _i3.Response.fromStream(_streamedResponse);
final _serializer = $stopBreakoutRooms_Serializer();
return _i1.ResponseConverter<BreakoutRoomStopBreakoutRoomsResponseApplicationJson, void>(
_serializer,
).convert(_response);
}