$BreakoutRoomConfigureBreakoutRoomsRequestApplicationJsonInterfaceBuilder class abstract mixin

Implementers

Properties

amount ↔ int?
getter/setter pair
attendeeMap ↔ String?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
mode ↔ BreakoutRoomConfigureBreakoutRoomsRequestApplicationJson_Mode?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
replace($BreakoutRoomConfigureBreakoutRoomsRequestApplicationJsonInterface other) → void
toString() → String
A string representation of this object.
inherited
update(void updates($BreakoutRoomConfigureBreakoutRoomsRequestApplicationJsonInterfaceBuilder)) → void

Operators

operator ==(Object other) → bool
The equality operator.
inherited