$CalendarIntegrationClient class

Constructors

$CalendarIntegrationClient($Client _rootClient)
Creates a new DynamiteClient for calendar_integration requests.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

$getDashboardEvents_Request({CalendarIntegrationGetDashboardEventsApiVersion? apiVersion, bool? oCSAPIRequest}) → Request
Get up to 10 rooms that have events in the next 7 days sorted by their start timestamp ascending.
$getDashboardEvents_Serializer() → DynamiteSerializer<CalendarIntegrationGetDashboardEventsResponseApplicationJson, void>
Builds a serializer to parse the response of $getDashboardEvents_Request.
$getMutualEvents_Request({required String token, CalendarIntegrationGetMutualEventsApiVersion? apiVersion, bool? oCSAPIRequest}) → Request
Get up to 3 events in the next 7 days sorted by their start timestamp ascending.
$getMutualEvents_Serializer() → DynamiteSerializer<CalendarIntegrationGetMutualEventsResponseApplicationJson, void>
Builds a serializer to parse the response of $getMutualEvents_Request.
getDashboardEvents({CalendarIntegrationGetDashboardEventsApiVersion? apiVersion, bool? oCSAPIRequest}) Future<DynamiteResponse<CalendarIntegrationGetDashboardEventsResponseApplicationJson, void>>
Get up to 10 rooms that have events in the next 7 days sorted by their start timestamp ascending.
getMutualEvents({required String token, CalendarIntegrationGetMutualEventsApiVersion? apiVersion, bool? oCSAPIRequest}) Future<DynamiteResponse<CalendarIntegrationGetMutualEventsResponseApplicationJson, void>>
Get up to 3 events in the next 7 days sorted by their start timestamp ascending.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited