getDashboardEvents method

Get up to 10 rooms that have events in the next 7 days sorted by their start timestamp ascending.

Required capability: dashboard-event-rooms.

Returns a Future containing a DynamiteResponse with the status code, deserialized body and headers. Throws a DynamiteApiException if the API call does not return an expected status code.

Parameters:

  • apiVersion Defaults to "v4".
  • oCSAPIRequest Required to be true for the API request to pass. Defaults to true.

Status codes:

  • 200: A list of dashboard entries or an empty array

See:

Implementation

Future<_i1.DynamiteResponse<CalendarIntegrationGetDashboardEventsResponseApplicationJson, void>> getDashboardEvents({
  CalendarIntegrationGetDashboardEventsApiVersion? apiVersion,
  bool? oCSAPIRequest,
}) async {
  final _request = $getDashboardEvents_Request(apiVersion: apiVersion, oCSAPIRequest: oCSAPIRequest);
  final _streamedResponse = await _rootClient.httpClient.send(_request);
  final _response = await _i3.Response.fromStream(_streamedResponse);

  final _serializer = $getDashboardEvents_Serializer();
  return _i1.ResponseConverter<CalendarIntegrationGetDashboardEventsResponseApplicationJson, void>(
    _serializer,
  ).convert(_response);
}