rebuild abstract method

Rebuilds the instance.

The result is the same as this instance but with updates applied. updates is a function that takes a builder $CalendarIntegrationGetDashboardEventsResponseApplicationJson_OcsInterfaceBuilder.

Implementation

$CalendarIntegrationGetDashboardEventsResponseApplicationJson_OcsInterface rebuild(
  void Function($CalendarIntegrationGetDashboardEventsResponseApplicationJson_OcsInterfaceBuilder) updates,
);