rebuild abstract method

Rebuilds the instance.

The result is the same as this instance but with updates applied. updates is a function that takes a builder $CalendarIntegrationGetMutualEventsResponseApplicationJson_OcsInterfaceBuilder.

Implementation

$CalendarIntegrationGetMutualEventsResponseApplicationJson_OcsInterface rebuild(
  void Function($CalendarIntegrationGetMutualEventsResponseApplicationJson_OcsInterfaceBuilder) updates,
);