$downloadParticipantsForCall_Request method
- @experimental
- required String token,
- CallDownloadParticipantsForCallApiVersion? apiVersion,
- CallDownloadParticipantsForCallFormat? format,
- bool? oCSAPIRequest,
Download the list of current call participants.
Required capability: download-call-participants.
Returns a DynamiteRequest backing the downloadParticipantsForCall operation.
Throws a DynamiteApiException if the API call does not return an expected status code.
Parameters:
apiVersionDefaults to"v4".tokenformatDownload format. Defaults to"csv".oCSAPIRequestRequired to be true for the API request to pass. Defaults totrue.
Status codes:
- 200: List of participants in the call downloaded in the requested format
- 400: No call in progress
See:
- downloadParticipantsForCall for a method executing this request and parsing the response.
- $downloadParticipantsForCall_Serializer for a converter to parse the
Responsefrom an executed this request.
Implementation
@_i2.experimental
_i3.Request $downloadParticipantsForCall_Request({
required String token,
CallDownloadParticipantsForCallApiVersion? apiVersion,
CallDownloadParticipantsForCallFormat? format,
bool? oCSAPIRequest,
}) {
final _parameters = <String, Object?>{};
final __token = _$jsonSerializers.serialize(token, specifiedType: const FullType(String));
_i4.checkString(__token, 'token', pattern: RegExp(r'^[a-z0-9]{4,30}$'));
_parameters['token'] = __token;
var __apiVersion = _$jsonSerializers.serialize(
apiVersion,
specifiedType: const FullType(CallDownloadParticipantsForCallApiVersion),
);
__apiVersion ??= 'v4';
_parameters['apiVersion'] = __apiVersion;
var __format = _$jsonSerializers.serialize(
format,
specifiedType: const FullType(CallDownloadParticipantsForCallFormat),
);
__format ??= 'csv';
_parameters['format'] = __format;
final _path = _i5.UriTemplate(
'/ocs/v2.php/apps/spreed/api/{apiVersion}/call/{token}/download{?format*}',
).expand(_parameters);
final _uri = Uri.parse('${_rootClient.baseURL}$_path');
final _request = _i3.Request('get', _uri);
_request.headers['Accept'] = 'text/csv';
// coverage:ignore-start
final authentication = _i6.IterableExtension(_rootClient.authentications)?.firstWhereOrNull(
(auth) => switch (auth) {
_i1.DynamiteHttpBearerAuthentication() || _i1.DynamiteHttpBasicAuthentication() => true,
_ => false,
},
);
if (authentication != null) {
_request.headers.addAll(authentication.headers);
}
// coverage:ignore-end
var __oCSAPIRequest = _$jsonSerializers.serialize(oCSAPIRequest, specifiedType: const FullType(bool));
__oCSAPIRequest ??= true;
_request.headers['OCS-APIRequest'] = const _i4.HeaderEncoder().convert(__oCSAPIRequest);
return _request;
}