downloadParticipantsForCall method

Future<DynamiteResponse<String, void>> downloadParticipantsForCall({
  1. required String token,
  2. CallDownloadParticipantsForCallApiVersion? apiVersion,
  3. CallDownloadParticipantsForCallFormat? format,
  4. bool? oCSAPIRequest,
})

Download the list of current call participants.

Required capability: download-call-participants.

Returns a Future containing a DynamiteResponse with the status code, deserialized body and headers. Throws a DynamiteApiException if the API call does not return an expected status code.

Parameters:

  • apiVersion Defaults to "v4".
  • token
  • format Download format. Defaults to "csv".
  • oCSAPIRequest Required to be true for the API request to pass. Defaults to true.

Status codes:

  • 200: List of participants in the call downloaded in the requested format
  • 400: No call in progress

See:

Implementation

Future<_i1.DynamiteResponse<String, void>> downloadParticipantsForCall({
  required String token,
  CallDownloadParticipantsForCallApiVersion? apiVersion,
  CallDownloadParticipantsForCallFormat? format,
  bool? oCSAPIRequest,
}) async {
  final _request = $downloadParticipantsForCall_Request(
    token: token,
    apiVersion: apiVersion,
    format: format,
    oCSAPIRequest: oCSAPIRequest,
  );
  final _streamedResponse = await _rootClient.httpClient.send(_request);
  final _response = await _i3.Response.fromStream(_streamedResponse);

  final _serializer = $downloadParticipantsForCall_Serializer();
  return _i1.ResponseConverter<String, void>(_serializer).convert(_response);
}