rebuild abstract method
Rebuilds the instance.
The result is the same as this instance but with updates applied.
updates is a function that takes a builder $CallNotificationStateResponseApplicationJson_OcsInterfaceBuilder.
Implementation
$CallNotificationStateResponseApplicationJson_OcsInterface rebuild(
void Function($CallNotificationStateResponseApplicationJson_OcsInterfaceBuilder) updates,
);