$Capabilities_Config_CallInterface class sealed

Implementers
Annotations
  • @BuiltValue.new(instantiable: false)

Properties

blurVirtualBackground bool?
no setter
breakoutRooms bool
no setter
canEnableSip bool
no setter
canUploadBackground bool
no setter
enabled bool
no setter
endToEndEncryption bool?
no setter
hashCode int
The hash code for this object.
no setterinherited
maxDuration int?
no setter
predefinedBackgrounds → BuiltList<String>
List of file names relative to the spreed/img/backgrounds/ web path, e.g. 2_home.jpg.
no setter
predefinedBackgroundsV2 → BuiltList<String>?
List of file paths relative to the server web root with leading slash, e.g. /apps/spreed/img/backgrounds/2_home.jpg.
no setter
recording bool
no setter
recordingConsent int
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sipDialoutEnabled bool
no setter
sipEnabled bool
no setter
startWithoutMedia bool?
no setter
supportedReactions → BuiltList<String>
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(void updates($Capabilities_Config_CallInterfaceBuilder)) $Capabilities_Config_CallInterface
Rebuilds the instance.
toBuilder() $Capabilities_Config_CallInterfaceBuilder
Converts the instance to a builder $Capabilities_Config_CallInterfaceBuilder.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited