$Capabilities_Config_ConversationsInterface class sealed
- Implementers
- Annotations
-
- @BuiltValue.new(instantiable: false)
Properties
- canCreate → bool
-
no setter
- descriptionLength → int?
-
no setter
- forcePasswords → bool?
-
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- listStyle → Capabilities_Config_Conversations_ListStyle?
-
no setter
- retentionEvent → int?
-
no setter
- retentionInstantMeetings → int?
-
no setter
- retentionPhone → int?
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
rebuild(
void updates($Capabilities_Config_ConversationsInterfaceBuilder)) → $Capabilities_Config_ConversationsInterface - Rebuilds the instance.
-
toBuilder(
) → $Capabilities_Config_ConversationsInterfaceBuilder - Converts the instance to a builder $Capabilities_Config_ConversationsInterfaceBuilder.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited