$summarizeChat_Request method
- @experimental
- required String token,
- required ChatSummarizeChatRequestApplicationJson $body,
- ChatSummarizeChatApiVersion? apiVersion,
- bool? oCSAPIRequest,
Summarize the next bunch of chat messages from a given offset.
Required capability: chat-summary-api.
Returns a DynamiteRequest backing the summarizeChat operation.
Throws a DynamiteApiException if the API call does not return an expected status code.
Parameters:
apiVersionDefaults to"v1".tokenoCSAPIRequestRequired to be true for the API request to pass. Defaults totrue.
Status codes:
- 201: Summary was scheduled, use the returned taskId to get the status information and output from the TaskProcessing API: OCS TaskProcessing API. If the response data contains nextOffset, not all messages could be handled in a single request. After receiving the response a second summary should be requested with the provided nextOffset.
- 400: No AI provider available or summarizing failed
- 204: No messages found to summarize
- 500
See:
- summarizeChat for a method executing this request and parsing the response.
- $summarizeChat_Serializer for a converter to parse the
Responsefrom an executed this request.
Implementation
@_i2.experimental
_i3.Request $summarizeChat_Request({
required String token,
required ChatSummarizeChatRequestApplicationJson $body,
ChatSummarizeChatApiVersion? apiVersion,
bool? oCSAPIRequest,
}) {
final _parameters = <String, Object?>{};
final __token = _$jsonSerializers.serialize(token, specifiedType: const FullType(String));
_i4.checkString(__token, 'token', pattern: RegExp(r'^[a-z0-9]{4,30}$'));
_parameters['token'] = __token;
var __apiVersion = _$jsonSerializers.serialize(
apiVersion,
specifiedType: const FullType(ChatSummarizeChatApiVersion),
);
__apiVersion ??= 'v1';
_parameters['apiVersion'] = __apiVersion;
final _path = _i5.UriTemplate(
'/ocs/v2.php/apps/spreed/api/{apiVersion}/chat/{token}/summarize',
).expand(_parameters);
final _uri = Uri.parse('${_rootClient.baseURL}$_path');
final _request = _i3.Request('post', _uri);
_request.headers['Accept'] = 'application/json';
// coverage:ignore-start
final authentication = _i6.IterableExtension(_rootClient.authentications)?.firstWhereOrNull(
(auth) => switch (auth) {
_i1.DynamiteHttpBearerAuthentication() || _i1.DynamiteHttpBasicAuthentication() => true,
_ => false,
},
);
if (authentication != null) {
_request.headers.addAll(authentication.headers);
}
// coverage:ignore-end
var __oCSAPIRequest = _$jsonSerializers.serialize(oCSAPIRequest, specifiedType: const FullType(bool));
__oCSAPIRequest ??= true;
_request.headers['OCS-APIRequest'] = const _i4.HeaderEncoder().convert(__oCSAPIRequest);
_request.headers['Content-Type'] = 'application/json';
_request.body = json.encode(
_$jsonSerializers.serialize($body, specifiedType: const FullType(ChatSummarizeChatRequestApplicationJson)),
);
return _request;
}