getUpcomingReminders method

Get all upcoming reminders.

Required capability: upcoming-reminders.

Returns a Future containing a DynamiteResponse with the status code, deserialized body and headers. Throws a DynamiteApiException if the API call does not return an expected status code.

Parameters:

  • apiVersion Defaults to "v1".
  • oCSAPIRequest Required to be true for the API request to pass. Defaults to true.

Status codes:

  • 200: Reminders returned

See:

Implementation

Future<_i1.DynamiteResponse<ChatGetUpcomingRemindersResponseApplicationJson, void>> getUpcomingReminders({
  ChatGetUpcomingRemindersApiVersion? apiVersion,
  bool? oCSAPIRequest,
}) async {
  final _request = $getUpcomingReminders_Request(apiVersion: apiVersion, oCSAPIRequest: oCSAPIRequest);
  final _streamedResponse = await _rootClient.httpClient.send(_request);
  final _response = await _i3.Response.fromStream(_streamedResponse);

  final _serializer = $getUpcomingReminders_Serializer();
  return _i1.ResponseConverter<ChatGetUpcomingRemindersResponseApplicationJson, void>(_serializer).convert(_response);
}