rebuild abstract method
Rebuilds the instance.
The result is the same as this instance but with updates applied.
updates is a function that takes a builder $ChatGetUpcomingRemindersResponseApplicationJson_OcsInterfaceBuilder.
Implementation
$ChatGetUpcomingRemindersResponseApplicationJson_OcsInterface rebuild(
void Function($ChatGetUpcomingRemindersResponseApplicationJson_OcsInterfaceBuilder) updates,
);