$ChatMentionSuggestionInterfaceBuilder class abstract mixin

Implementers

Properties

details ↔ String?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
id ↔ String?
getter/setter pair
label ↔ String?
getter/setter pair
mentionId ↔ String?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
source ↔ String?
getter/setter pair
status ↔ String?
getter/setter pair
statusClearAt ↔ int?
getter/setter pair
statusIcon ↔ String?
getter/setter pair
statusMessage ↔ String?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
replace($ChatMentionSuggestionInterface other) → void
toString() → String
A string representation of this object.
inherited
update(void updates($ChatMentionSuggestionInterfaceBuilder)) → void

Operators

operator ==(Object other) → bool
The equality operator.
inherited