fromMessageId property
int
get
fromMessageId
Offset from where on the summary should be generated.
Implementation
int get fromMessageId;
Offset from where on the summary should be generated.
int get fromMessageId;