rebuild abstract method
Rebuilds the instance.
The result is the same as this instance but with updates applied.
updates is a function that takes a builder $ChatSummarizeChatResponseApplicationJson_OcsInterfaceBuilder.
Implementation
$ChatSummarizeChatResponseApplicationJson_OcsInterface rebuild(
void Function($ChatSummarizeChatResponseApplicationJson_OcsInterfaceBuilder) updates,
);