rebuild abstract method

Rebuilds the instance.

The result is the same as this instance but with updates applied. updates is a function that takes a builder $DashboardEventAttachmentInterfaceBuilder.

Implementation

$DashboardEventAttachmentInterface rebuild(void Function($DashboardEventAttachmentInterfaceBuilder) updates);