$DashboardEventAttachmentInterfaceBuilder class abstract mixin

Implementers

Properties

calendars ↔ ListBuilder<String>
getter/setter pair
fileid int?
getter/setter pair
filename String?
getter/setter pair
fmttype String?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
preview bool?
getter/setter pair
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
replace($DashboardEventAttachmentInterface other) → void
toString() String
A string representation of this object.
inherited
update(void updates($DashboardEventAttachmentInterfaceBuilder)) → void

Operators

operator ==(Object other) bool
The equality operator.
inherited