$DashboardEventCalendarInterfaceBuilder class abstract mixin

Implementers

Properties

calendarColor String?
getter/setter pair
calendarName String?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
principalUri String?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
replace($DashboardEventCalendarInterface other) → void
toString() String
A string representation of this object.
inherited
update(void updates($DashboardEventCalendarInterfaceBuilder)) → void

Operators

operator ==(Object other) bool
The equality operator.
inherited