$DashboardEventInterface class sealed

Implementers
Annotations
  • @BuiltValue.new(instantiable: false)

Properties

accepted int?
no setter
calendars → BuiltList<DashboardEventCalendar>
no setter
declined int?
no setter
end int
no setter
eventAttachments → BuiltMap<String, DashboardEventAttachment>
no setter
eventDescription String?
no setter
no setter
eventName String
no setter
hashCode int
The hash code for this object.
no setterinherited
invited int?
no setter
roomActiveSince int?
no setter
roomAvatarVersion String
no setter
roomDisplayName String
no setter
roomName String
no setter
roomToken String
no setter
roomType int
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
start int
no setter
tentative int?
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(void updates($DashboardEventInterfaceBuilder)) $DashboardEventInterface
Rebuilds the instance.
toBuilder() $DashboardEventInterfaceBuilder
Converts the instance to a builder $DashboardEventInterfaceBuilder.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited