rebuild abstract method

Rebuilds the instance.

The result is the same as this instance but with updates applied. updates is a function that takes a builder $DashboardEventInterfaceBuilder.

Implementation

$DashboardEventInterface rebuild(void Function($DashboardEventInterfaceBuilder) updates);