$DashboardEventInterfaceBuilder class abstract mixin

Implementers

Properties

accepted int?
getter/setter pair
calendars ↔ ListBuilder<DashboardEventCalendar>
getter/setter pair
declined int?
getter/setter pair
end int?
getter/setter pair
eventAttachments ↔ MapBuilder<String, DashboardEventAttachment>
getter/setter pair
eventDescription String?
getter/setter pair
getter/setter pair
eventName String?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
invited int?
getter/setter pair
roomActiveSince int?
getter/setter pair
roomAvatarVersion String?
getter/setter pair
roomDisplayName String?
getter/setter pair
roomName String?
getter/setter pair
roomToken String?
getter/setter pair
roomType int?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
start int?
getter/setter pair
tentative int?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
replace($DashboardEventInterface other) → void
toString() String
A string representation of this object.
inherited
update(void updates($DashboardEventInterfaceBuilder)) → void

Operators

operator ==(Object other) bool
The equality operator.
inherited