$InvitationListInterface class sealed

Implementers
Annotations
  • @BuiltValue.new(instantiable: false)

Properties

emails → BuiltList<String>?
no setter
federatedUsers → BuiltList<String>?
no setter
groups → BuiltList<String>?
no setter
hashCode int
The hash code for this object.
no setterinherited
phones → BuiltList<String>?
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
teams → BuiltList<String>?
no setter
users → BuiltList<String>?
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(void updates($InvitationListInterfaceBuilder)) $InvitationListInterface
Rebuilds the instance.
toBuilder() $InvitationListInterfaceBuilder
Converts the instance to a builder $InvitationListInterfaceBuilder.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited