- Implementers
Constructors
Properties
-
emails
↔ ListBuilder<
String> -
getter/setter pair
-
federatedUsers
↔ ListBuilder<
String> -
getter/setter pair
-
groups
↔ ListBuilder<
String> -
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
-
phones
↔ ListBuilder<
String> -
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
teams
↔ ListBuilder<
String> -
getter/setter pair
-
users
↔ ListBuilder<
String> -
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
replace(
$InvitationListInterface other) → void -
toString(
) → String -
A string representation of this object.
inherited
-
update(
void updates($InvitationListInterfaceBuilder)) → void
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited