getAllDraftPolls method

Future<DynamiteResponse<PollGetAllDraftPollsResponseApplicationJson, void>> getAllDraftPolls({
  1. required String token,
  2. PollGetAllDraftPollsApiVersion? apiVersion,
  3. bool? oCSAPIRequest,
})

Get all drafted polls.

Required capability: talk-polls-drafts.

Returns a Future containing a DynamiteResponse with the status code, deserialized body and headers. Throws a DynamiteApiException if the API call does not return an expected status code.

Parameters:

  • apiVersion Defaults to "v1".
  • token
  • oCSAPIRequest Required to be true for the API request to pass. Defaults to true.

Status codes:

  • 200: Poll returned
  • 403: User is not a moderator
  • 404: Poll not found

See:

Implementation

Future<_i1.DynamiteResponse<PollGetAllDraftPollsResponseApplicationJson, void>> getAllDraftPolls({
  required String token,
  PollGetAllDraftPollsApiVersion? apiVersion,
  bool? oCSAPIRequest,
}) async {
  final _request = $getAllDraftPolls_Request(token: token, apiVersion: apiVersion, oCSAPIRequest: oCSAPIRequest);
  final _streamedResponse = await _rootClient.httpClient.send(_request);
  final _response = await _i3.Response.fromStream(_streamedResponse);

  final _serializer = $getAllDraftPolls_Serializer();
  return _i1.ResponseConverter<PollGetAllDraftPollsResponseApplicationJson, void>(_serializer).convert(_response);
}