draft property
bool
get
draft
Whether the poll should be saved as a draft (only allowed for moderators and with talk-polls-drafts capability).
Implementation
bool get draft;
Whether the poll should be saved as a draft (only allowed for moderators and with talk-polls-drafts capability).
bool get draft;