$PollDraftInterface class sealed

Implementers
Annotations
  • @BuiltValue.new(instantiable: false)

Properties

actorDisplayName String
no setter
actorId String
no setter
actorType ActorTypes
no setter
hashCode int
The hash code for this object.
no setterinherited
id int
no setter
maxVotes int
no setter
options → BuiltList<String>
no setter
question String
no setter
resultMode PollDraft_ResultMode
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
status PollDraft_Status
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(void updates($PollDraftInterfaceBuilder)) $PollDraftInterface
Rebuilds the instance.
toBuilder() $PollDraftInterfaceBuilder
Converts the instance to a builder $PollDraftInterfaceBuilder.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited