rebuild abstract method

$PollDraftInterface rebuild(
  1. void updates(
    1. $PollDraftInterfaceBuilder
    )
)

Rebuilds the instance.

The result is the same as this instance but with updates applied. updates is a function that takes a builder $PollDraftInterfaceBuilder.

Implementation

$PollDraftInterface rebuild(void Function($PollDraftInterfaceBuilder) updates);