rebuild abstract method
Rebuilds the instance.
The result is the same as this instance but with updates applied.
updates is a function that takes a builder $PollGetAllDraftPollsResponseApplicationJson_OcsInterfaceBuilder.
Implementation
$PollGetAllDraftPollsResponseApplicationJson_OcsInterface rebuild(
void Function($PollGetAllDraftPollsResponseApplicationJson_OcsInterfaceBuilder) updates,
);