$PollInterface class sealed

Implemented types
Implementers
Annotations
  • @BuiltValue.new(instantiable: false)

Properties

actorDisplayName String
no setterinherited
actorId String
no setterinherited
actorType ActorTypes
no setterinherited
details → BuiltList<PollVote>?
no setter
hashCode int
The hash code for this object.
no setterinherited
id int
no setterinherited
maxVotes int
no setterinherited
numVoters int?
no setter
options → BuiltList<String>
no setterinherited
question String
no setterinherited
resultMode PollDraft_ResultMode
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
status PollDraft_Status
no setterinherited
votedSelf → BuiltList<int>?
no setter
votes → BuiltMap<String, int>?
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(void updates($PollInterfaceBuilder)) $PollInterface
Rebuilds the instance.
override
toBuilder() $PollInterfaceBuilder
Converts the instance to a builder $PollInterfaceBuilder.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited