rebuild abstract method

  1. @override
$PollInterface rebuild(
  1. void updates(
    1. $PollInterfaceBuilder
    )
)
override

Rebuilds the instance.

The result is the same as this instance but with updates applied. updates is a function that takes a builder $PollInterfaceBuilder.

Implementation

@override
$PollInterface rebuild(void Function($PollInterfaceBuilder) updates);