rebuild abstract method
Rebuilds the instance.
The result is the same as this instance but with updates applied.
updates is a function that takes a builder $PollUpdateDraftPollResponseApplicationJson_OcsInterfaceBuilder.
Implementation
$PollUpdateDraftPollResponseApplicationJson_OcsInterface rebuild(
void Function($PollUpdateDraftPollResponseApplicationJson_OcsInterfaceBuilder) updates,
);