getReactionsRaw method
- @experimental
- required String token,
- required int messageId,
- String? reaction,
- ReactionGetReactionsApiVersion? apiVersion,
- bool? oCSAPIRequest,
Get a list of reactions for a message.
This method and the response it returns is experimental. The API might change without a major version bump.
Returns a Future containing a DynamiteRawResponse with the raw HttpClientResponse and serialization helpers.
Throws a DynamiteApiException if the API call does not return an expected status code.
Parameters:
reactionEmoji to filter.apiVersionDefaults tov1.tokenmessageIdID of the message.oCSAPIRequestRequired to be true for the API request to pass. Defaults totrue.
Status codes:
- 200: Reactions returned
- 404: Message or reaction not found
See:
- getReactions for an operation that returns a
DynamiteResponsewith a stable API.
Implementation
@_i4.experimental
_i1.DynamiteRawResponse<ReactionGetReactionsResponseApplicationJson, void> getReactionsRaw({
required String token,
required int messageId,
String? reaction,
ReactionGetReactionsApiVersion? apiVersion,
bool? oCSAPIRequest,
}) {
final _parameters = <String, dynamic>{};
final _headers = <String, String>{'Accept': 'application/json'};
// coverage:ignore-start
final authentication = _rootClient.authentications?.firstWhereOrNull(
(auth) => switch (auth) {
_i1.DynamiteHttpBearerAuthentication() || _i1.DynamiteHttpBasicAuthentication() => true,
_ => false,
},
);
if (authentication != null) {
_headers.addAll(
authentication.headers,
);
}
// coverage:ignore-end
final $token = _$jsonSerializers.serialize(token, specifiedType: const FullType(String));
_i2.checkPattern(
$token as String?,
RegExp(r'^[a-z0-9]{4,30}$'),
'token',
);
_parameters['token'] = $token;
final $messageId = _$jsonSerializers.serialize(messageId, specifiedType: const FullType(int));
_parameters['messageId'] = $messageId;
final $reaction = _$jsonSerializers.serialize(reaction, specifiedType: const FullType(String));
_parameters['reaction'] = $reaction;
var $apiVersion =
_$jsonSerializers.serialize(apiVersion, specifiedType: const FullType(ReactionGetReactionsApiVersion));
$apiVersion ??= 'v1';
_parameters['apiVersion'] = $apiVersion;
var $oCSAPIRequest = _$jsonSerializers.serialize(oCSAPIRequest, specifiedType: const FullType(bool));
$oCSAPIRequest ??= true;
_headers['OCS-APIRequest'] = const _i2.HeaderEncoder().convert($oCSAPIRequest);
final _path = _i3.UriTemplate('/ocs/v2.php/apps/spreed/api/{apiVersion}/reaction/{token}/{messageId}{?reaction*}')
.expand(_parameters);
return _i1.DynamiteRawResponse<ReactionGetReactionsResponseApplicationJson, void>(
response: _rootClient.executeRequest(
'get',
_path,
headers: _headers,
validStatuses: const {200},
),
bodyType: const FullType(ReactionGetReactionsResponseApplicationJson),
headersType: null,
serializers: _$jsonSerializers,
);
}