$directDialIn_Request method
- @experimental
- required RoomDirectDialInRequestApplicationJson $body,
- RoomDirectDialInApiVersion? apiVersion,
- bool? oCSAPIRequest,
Direct dial-in (SIP bridge).
Required capability: sip-direct-dialin.
Returns a DynamiteRequest backing the directDialIn operation.
Throws a DynamiteApiException if the API call does not return an expected status code.
Parameters:
apiVersionDefaults to"v4".oCSAPIRequestRequired to be true for the API request to pass. Defaults totrue.
Status codes:
- 200: Call conversation created
- 401: SIP request invalid
- 404: Number is not assigned to any user
- 500: Error occurred while creating conversation
- 501: SIP dial-in is not configured
See:
- directDialIn for a method executing this request and parsing the response.
- $directDialIn_Serializer for a converter to parse the
Responsefrom an executed this request.
Implementation
@_i2.experimental
_i3.Request $directDialIn_Request({
required RoomDirectDialInRequestApplicationJson $body,
RoomDirectDialInApiVersion? apiVersion,
bool? oCSAPIRequest,
}) {
final _parameters = <String, Object?>{};
var __apiVersion = _$jsonSerializers.serialize(
apiVersion,
specifiedType: const FullType(RoomDirectDialInApiVersion),
);
__apiVersion ??= 'v4';
_parameters['apiVersion'] = __apiVersion;
final _path = _i5.UriTemplate('/ocs/v2.php/apps/spreed/api/{apiVersion}/room/direct-dial-in').expand(_parameters);
final _uri = Uri.parse('${_rootClient.baseURL}$_path');
final _request = _i3.Request('post', _uri);
_request.headers['Accept'] = 'application/json';
// coverage:ignore-start
final authentication = _i6.IterableExtension(_rootClient.authentications)?.firstWhereOrNull(
(auth) => switch (auth) {
_i1.DynamiteHttpBearerAuthentication() || _i1.DynamiteHttpBasicAuthentication() => true,
_ => false,
},
);
if (authentication != null) {
_request.headers.addAll(authentication.headers);
}
// coverage:ignore-end
var __oCSAPIRequest = _$jsonSerializers.serialize(oCSAPIRequest, specifiedType: const FullType(bool));
__oCSAPIRequest ??= true;
_request.headers['OCS-APIRequest'] = const _i4.HeaderEncoder().convert(__oCSAPIRequest);
_request.headers['Content-Type'] = 'application/json';
_request.body = json.encode(
_$jsonSerializers.serialize($body, specifiedType: const FullType(RoomDirectDialInRequestApplicationJson)),
);
return _request;
}