directDialIn method

Direct dial-in (SIP bridge).

Required capability: sip-direct-dialin.

Returns a Future containing a DynamiteResponse with the status code, deserialized body and headers. Throws a DynamiteApiException if the API call does not return an expected status code.

Parameters:

  • apiVersion Defaults to "v4".
  • oCSAPIRequest Required to be true for the API request to pass. Defaults to true.

Status codes:

  • 200: Call conversation created
  • 401: SIP request invalid
  • 404: Number is not assigned to any user
  • 500: Error occurred while creating conversation
  • 501: SIP dial-in is not configured

See:

Implementation

Future<_i1.DynamiteResponse<RoomDirectDialInResponseApplicationJson, void>> directDialIn({
  required RoomDirectDialInRequestApplicationJson $body,
  RoomDirectDialInApiVersion? apiVersion,
  bool? oCSAPIRequest,
}) async {
  final _request = $directDialIn_Request(apiVersion: apiVersion, oCSAPIRequest: oCSAPIRequest, $body: $body);
  final _streamedResponse = await _rootClient.httpClient.send(_request);
  final _response = await _i3.Response.fromStream(_streamedResponse);

  final _serializer = $directDialIn_Serializer();
  return _i1.ResponseConverter<RoomDirectDialInResponseApplicationJson, void>(_serializer).convert(_response);
}