getBreakoutRoomsRaw method
- @experimental
- required String token,
- RoomGetBreakoutRoomsApiVersion? apiVersion,
- bool? oCSAPIRequest,
Get breakout rooms.
All for moderators and in case of "free selection", or the assigned breakout room for other participants.
This method and the response it returns is experimental. The API might change without a major version bump.
Returns a Future containing a DynamiteRawResponse with the raw HttpClientResponse and serialization helpers.
Throws a DynamiteApiException if the API call does not return an expected status code.
Parameters:
apiVersionDefaults tov4.tokenoCSAPIRequestRequired to be true for the API request to pass. Defaults totrue.
Status codes:
- 200: Breakout rooms returned
- 400: Getting breakout rooms is not possible
See:
- getBreakoutRooms for an operation that returns a
DynamiteResponsewith a stable API.
Implementation
@_i4.experimental
_i1.DynamiteRawResponse<RoomGetBreakoutRoomsResponseApplicationJson, void> getBreakoutRoomsRaw({
required String token,
RoomGetBreakoutRoomsApiVersion? apiVersion,
bool? oCSAPIRequest,
}) {
final _parameters = <String, dynamic>{};
final _headers = <String, String>{'Accept': 'application/json'};
// coverage:ignore-start
final authentication = _rootClient.authentications?.firstWhereOrNull(
(auth) => switch (auth) {
_i1.DynamiteHttpBearerAuthentication() || _i1.DynamiteHttpBasicAuthentication() => true,
_ => false,
},
);
if (authentication != null) {
_headers.addAll(
authentication.headers,
);
} else {
throw Exception('Missing authentication for bearer_auth or basic_auth');
}
// coverage:ignore-end
final $token = _$jsonSerializers.serialize(token, specifiedType: const FullType(String));
_i2.checkPattern(
$token as String?,
RegExp(r'^[a-z0-9]{4,30}$'),
'token',
);
_parameters['token'] = $token;
var $apiVersion =
_$jsonSerializers.serialize(apiVersion, specifiedType: const FullType(RoomGetBreakoutRoomsApiVersion));
$apiVersion ??= 'v4';
_parameters['apiVersion'] = $apiVersion;
var $oCSAPIRequest = _$jsonSerializers.serialize(oCSAPIRequest, specifiedType: const FullType(bool));
$oCSAPIRequest ??= true;
_headers['OCS-APIRequest'] = const _i2.HeaderEncoder().convert($oCSAPIRequest);
final _path =
_i3.UriTemplate('/ocs/v2.php/apps/spreed/api/{apiVersion}/room/{token}/breakout-rooms').expand(_parameters);
return _i1.DynamiteRawResponse<RoomGetBreakoutRoomsResponseApplicationJson, void>(
response: _rootClient.executeRequest(
'get',
_path,
headers: _headers,
validStatuses: const {200},
),
bodyType: const FullType(RoomGetBreakoutRoomsResponseApplicationJson),
headersType: null,
serializers: _$jsonSerializers,
);
}