importEmailsAsParticipants method

Import a list of email attendees.

Content format is comma separated values: - Header line is required and must match "email","name" or "email" - One entry per line (e.g. "John Doe","john@example.tld"). Required capability: email-csv-import.

Returns a Future containing a DynamiteResponse with the status code, deserialized body and headers. Throws a DynamiteApiException if the API call does not return an expected status code.

Parameters:

  • apiVersion Defaults to "v4".
  • token
  • oCSAPIRequest Required to be true for the API request to pass. Defaults to true.

Status codes:

  • 200: All entries imported successfully
  • 400: Import was not successful. When message is provided the string is in user language and should be displayed as an error.

See:

Implementation

Future<_i1.DynamiteResponse<RoomImportEmailsAsParticipantsResponseApplicationJson, void>> importEmailsAsParticipants({
  required String token,
  RoomImportEmailsAsParticipantsApiVersion? apiVersion,
  bool? oCSAPIRequest,
  RoomImportEmailsAsParticipantsRequestApplicationJson? $body,
}) async {
  final _request = $importEmailsAsParticipants_Request(
    token: token,
    apiVersion: apiVersion,
    oCSAPIRequest: oCSAPIRequest,
    $body: $body,
  );
  final _streamedResponse = await _rootClient.httpClient.send(_request);
  final _response = await _i3.Response.fromStream(_streamedResponse);

  final _serializer = $importEmailsAsParticipants_Serializer();
  return _i1.ResponseConverter<RoomImportEmailsAsParticipantsResponseApplicationJson, void>(
    _serializer,
  ).convert(_response);
}