unbindRoomFromObject method
Future<DynamiteResponse<RoomUnbindRoomFromObjectResponseApplicationJson, void> >
unbindRoomFromObject({
- required String token,
- RoomUnbindRoomFromObjectApiVersion? apiVersion,
- bool? oCSAPIRequest,
Unbind a room from its object to prevent automatic retention.
Required capability: unbind-conversation.
Returns a Future containing a DynamiteResponse with the status code, deserialized body and headers.
Throws a DynamiteApiException if the API call does not return an expected status code.
Parameters:
apiVersionDefaults to"v4".tokenoCSAPIRequestRequired to be true for the API request to pass. Defaults totrue.
Status codes:
- 200: Room successfully unbound
- 400: Unbinding room is not possible
See:
- $unbindRoomFromObject_Request for the request send by this method.
- $unbindRoomFromObject_Serializer for a converter to parse the
Responsefrom an executed request.
Implementation
Future<_i1.DynamiteResponse<RoomUnbindRoomFromObjectResponseApplicationJson, void>> unbindRoomFromObject({
required String token,
RoomUnbindRoomFromObjectApiVersion? apiVersion,
bool? oCSAPIRequest,
}) async {
final _request = $unbindRoomFromObject_Request(token: token, apiVersion: apiVersion, oCSAPIRequest: oCSAPIRequest);
final _streamedResponse = await _rootClient.httpClient.send(_request);
final _response = await _i3.Response.fromStream(_streamedResponse);
final _serializer = $unbindRoomFromObject_Serializer();
return _i1.ResponseConverter<RoomUnbindRoomFromObjectResponseApplicationJson, void>(_serializer).convert(_response);
}