roomName property

String get roomName

Name of the room, unless the legacy mode providing $invite and $source is used, the name must no longer be empty with the conversation-creation-all capability (Ignored if $roomType is {@see Room::TYPE_ONE_TO_ONE}).

Implementation

String get roomName;