$RoomCreateRoomRequestApplicationJsonInterfaceBuilder class abstract mixin

Implementers

Properties

avatarColor String?
getter/setter pair
description String?
getter/setter pair
emoji String?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
invite String?
getter/setter pair
listable RoomCreateRoomRequestApplicationJson_Listable?
getter/setter pair
lobbyState RoomCreateRoomRequestApplicationJson_LobbyState?
getter/setter pair
lobbyTimer int?
getter/setter pair
mentionPermissions RoomCreateRoomRequestApplicationJson_MentionPermissions?
getter/setter pair
messageExpiration int?
getter/setter pair
objectId String?
getter/setter pair
objectType String?
getter/setter pair
participants InvitationListBuilder
getter/setter pair
password String?
getter/setter pair
permissions int?
getter/setter pair
readOnly RoomCreateRoomRequestApplicationJson_ReadOnly?
getter/setter pair
recordingConsent RoomCreateRoomRequestApplicationJson_RecordingConsent?
getter/setter pair
roomName String?
getter/setter pair
roomType int?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sipEnabled RoomCreateRoomRequestApplicationJson_SipEnabled?
getter/setter pair
source String?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
replace($RoomCreateRoomRequestApplicationJsonInterface other) → void
toString() String
A string representation of this object.
inherited
update(void updates($RoomCreateRoomRequestApplicationJsonInterfaceBuilder)) → void

Operators

operator ==(Object other) bool
The equality operator.
inherited