$RoomDirectDialInRequestApplicationJsonInterface class sealed

Implementers
Annotations
  • @BuiltValue.new(instantiable: false)

Properties

caller String
Phone number of the person calling in.
no setter
hashCode int
The hash code for this object.
no setterinherited
phoneNumber String
Phone number that is called.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(void updates($RoomDirectDialInRequestApplicationJsonInterfaceBuilder)) $RoomDirectDialInRequestApplicationJsonInterface
Rebuilds the instance.
toBuilder() $RoomDirectDialInRequestApplicationJsonInterfaceBuilder
Converts the instance to a builder $RoomDirectDialInRequestApplicationJsonInterfaceBuilder.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited