$RoomImportEmailsAsParticipantsRequestApplicationJsonInterface class sealed

Implementers
Annotations
  • @BuiltValue.new(instantiable: false)

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
testRun bool
When set to true, the file is validated and no email is actually sent nor any participant added to the conversation.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(void updates($RoomImportEmailsAsParticipantsRequestApplicationJsonInterfaceBuilder)) $RoomImportEmailsAsParticipantsRequestApplicationJsonInterface
Rebuilds the instance.
toBuilder() $RoomImportEmailsAsParticipantsRequestApplicationJsonInterfaceBuilder
Converts the instance to a builder $RoomImportEmailsAsParticipantsRequestApplicationJsonInterfaceBuilder.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited