testRun property
bool
get
testRun
When set to true, the file is validated and no email is actually sent nor any participant added to the conversation.
Implementation
bool get testRun;
When set to true, the file is validated and no email is actually sent nor any participant added to the conversation.
bool get testRun;