$RoomImportEmailsAsParticipantsResponseApplicationJson_Ocs_DataInterface class sealed

Implementers
Annotations
  • @BuiltValue.new(instantiable: false)

Properties

duplicates int
no setter
hashCode int
The hash code for this object.
no setterinherited
invalid int?
no setter
invalidLines → BuiltList<int>?
no setter
invites int
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type int?
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(void updates($RoomImportEmailsAsParticipantsResponseApplicationJson_Ocs_DataInterfaceBuilder)) $RoomImportEmailsAsParticipantsResponseApplicationJson_Ocs_DataInterface
Rebuilds the instance.
toBuilder() $RoomImportEmailsAsParticipantsResponseApplicationJson_Ocs_DataInterfaceBuilder
Converts the instance to a builder $RoomImportEmailsAsParticipantsResponseApplicationJson_Ocs_DataInterfaceBuilder.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited