rebuild abstract method
Rebuilds the instance.
The result is the same as this instance but with updates applied.
updates is a function that takes a builder $RoomImportEmailsAsParticipantsResponseApplicationJson_Ocs_DataInterfaceBuilder.
Implementation
$RoomImportEmailsAsParticipantsResponseApplicationJson_Ocs_DataInterface rebuild(
void Function($RoomImportEmailsAsParticipantsResponseApplicationJson_Ocs_DataInterfaceBuilder) updates,
);