$RoomInterface class sealed

Implementers
Annotations
  • @BuiltValue.new(instantiable: false)

Properties

actorId String
The unique identifier for the given actor type.
no setter
actorType ActorTypes
no setter
attendeeId int
Unique attendee id.
no setter
attendeePermissions int
Dedicated permissions for the current participant, if not Custom this are not the resulting permissions (see constants list).
no setter
attendeePin String?
Unique dial-in authentication code for this user, when the conversation has SIP enabled (see sipEnabled attribute).
no setter
avatarVersion String
Version of conversation avatar used to easier expiration of the avatar in case a moderator updates it, since the avatar endpoint should be cached for 24 hours. (only available with avatar capability).
no setter
breakoutRoomMode int
Breakout room configuration mode (see constants list) (only available with breakout-rooms-v1 capability).
no setter
breakoutRoomStatus int
Breakout room status (see constants list) (only available with breakout-rooms-v1 capability).
no setter
callFlag int
Combined flag of all participants in the current call (see constants list, only available with conversation-call-flags capability).
no setter
callPermissions int
Call permissions, if not Custom this are not the resulting permissions, if set they will reset after the end of the call (see constants list).
no setter
callRecording int
no setter
callStartTime int
no setter
canDeleteConversation bool
Flag if the user can delete the conversation for everyone (not possible without moderator permissions or in one-to-one conversations).
no setter
canEnableSIP bool
Whether the given user can enable SIP for this conversation. Note that when the token is not-numeric only, SIP can not be enabled even if the user is permitted and a moderator of the conversation.
no setter
canLeaveConversation bool
Flag if the user can leave the conversation (not possible for the last user with moderator permissions).
no setter
canStartCall bool
Flag if the user can start a new call in this conversation (joining is always possible) (only available with start-call-flag capability).
no setter
defaultPermissions int
Default permissions for new participants (see constants list).
no setter
description String
Description of the conversation (can also be empty) (only available with room-description capability).
no setter
displayName String
name if non-empty, otherwise it falls back to a list of participants.
no setter
hasCall bool
Flag if the conversation has an active call.
no setter
hashCode int
The hash code for this object.
no setterinherited
hasPassword bool
Flag if the conversation has a password.
no setter
id int
Numeric identifier of the conversation.
no setter
invitedActorId String?
The cloud id of the invited user.
no setter
isArchived bool
Flag if the conversation is archived by the user (only available with archived-conversations-v2 capability).
no setter
isCustomAvatar bool
Flag if the conversation has a custom avatar (only available with avatar capability).
no setter
isFavorite bool
Flag if the conversation is favorited by the user.
no setter
isImportant bool?
Required capability: important-conversations.
no setter
isSensitive bool?
Required capability: sensitive-conversations.
no setter
lastActivity int
Timestamp of the last activity in the conversation, in seconds and UTC time zone.
no setter
lastCommonReadMessage int
ID of the last message read by every user that has read privacy set to public in a room. When the user themself has it set to private the value is 0 (only available with chat-read-status capability).
no setter
lastMessage RoomLastMessage?
Last message in a conversation if available, otherwise empty. Note: Even when given the message will not contain the parent or reactionsSelf attribute due to performance reasons.
no setter
lastPing int
Timestamp of the user's session making the request.
no setter
lastReadMessage int
ID of the last read message in a room (only available with chat-read-marker capability).
no setter
listable int
Listable scope for the room (only available with listable-rooms capability).
no setter
lobbyState int
Webinar lobby restriction (0-1), if the participant is a moderator they can always join the conversation (only available with webinary-lobby capability) (See Webinar lobby states).
no setter
lobbyTimer int
Timestamp when the lobby will be automatically disabled (only available with webinary-lobby capability).
no setter
mentionPermissions int
no setter
messageExpiration int
no setter
name String
Name of the conversation (can also be empty).
no setter
notificationCalls int
no setter
notificationLevel int
The notification level for the user (See Participant notification levels).
no setter
objectId String
See Object types documentation for explanation.
no setter
objectType String
The type of object that the conversation is associated with (See Object types).
no setter
participantFlags int
"In call" flags of the user's session making the request (only available with in-call-flags capability).
no setter
participantType int
Permissions level of the current user.
no setter
permissions int
Combined final permissions for the current participant, permissions are picked in order of attendee then call then default and the first which is Custom will apply (see constants list).
no setter
readOnly int
Read-only state for the current user (only available with read-only-rooms capability).
no setter
recordingConsent int
Whether recording consent is required before joining a call (Only 0 and 1 will be returned, see constants list) (only available with recording-consent capability).
no setter
remoteServer String?
no setter
remoteToken String?
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sessionId String
'0' if not connected, otherwise an up to 512 character long string that is the identifier of the user's session making the request. Should only be used to pre-check if the user joined already with this session, but this might be outdated by the time of usage, so better check via Get list of participants in a conversation.
no setter
sipEnabled int
SIP enable status (see constants list).
no setter
status String?
Optional: Only available for one-to-one conversations, when includeStatus=true is set and the user has a status.
no setter
statusClearAt int?
Optional: Only available for one-to-one conversations, when includeStatus=true is set and the user has a status, can still be null even with a status.
no setter
statusIcon String?
Optional: Only available for one-to-one conversations, when includeStatus=true is set and the user has a status, can still be null even with a status.
no setter
statusMessage String?
Optional: Only available for one-to-one conversations, when includeStatus=true is set and the user has a status, can still be null even with a status.
no setter
token String
Token identifier of the conversation which is used for further interaction.
no setter
type int
See list of conversation types in the constants list.
no setter
unreadMention bool
Flag if the user was mentioned since their last visit.
no setter
unreadMentionDirect bool
Flag if the user was mentioned directly (ignoring @all mentions) since their last visit (only available with direct-mention-flag capability).
no setter
unreadMessages int
Number of unread chat messages in the conversation (only available with chat-v2 capability).
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(void updates($RoomInterfaceBuilder)) $RoomInterface
Rebuilds the instance.
toBuilder() $RoomInterfaceBuilder
Converts the instance to a builder $RoomInterfaceBuilder.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited