attendeePin property
String?
get
attendeePin
Unique dial-in authentication code for this user, when the conversation has SIP enabled (see sipEnabled attribute).
Implementation
String? get attendeePin;
Unique dial-in authentication code for this user, when the conversation has SIP enabled (see sipEnabled attribute).
String? get attendeePin;