avatarVersion property

String get avatarVersion

Version of conversation avatar used to easier expiration of the avatar in case a moderator updates it, since the avatar endpoint should be cached for 24 hours. (only available with avatar capability).

Implementation

String get avatarVersion;