callFlag property
int
get
callFlag
Combined flag of all participants in the current call (see constants list, only available with conversation-call-flags capability).
Implementation
int get callFlag;
Combined flag of all participants in the current call (see constants list, only available with conversation-call-flags capability).
int get callFlag;