displayName property
String
get
displayName
name if non-empty, otherwise it falls back to a list of participants.
Implementation
String get displayName;
name if non-empty, otherwise it falls back to a list of participants.
String get displayName;