isArchived property
bool
get
isArchived
Flag if the conversation is archived by the user (only available with archived-conversations-v2 capability).
Implementation
bool get isArchived;
Flag if the conversation is archived by the user (only available with archived-conversations-v2 capability).
bool get isArchived;