isCustomAvatar property
bool
get
isCustomAvatar
Flag if the conversation has a custom avatar (only available with avatar capability).
Implementation
bool get isCustomAvatar;
Flag if the conversation has a custom avatar (only available with avatar capability).
bool get isCustomAvatar;