lastActivity property
int
get
lastActivity
Timestamp of the last activity in the conversation, in seconds and UTC time zone.
Implementation
int get lastActivity;
Timestamp of the last activity in the conversation, in seconds and UTC time zone.
int get lastActivity;