lastCommonReadMessage property

int get lastCommonReadMessage

ID of the last message read by every user that has read privacy set to public in a room. When the user themself has it set to private the value is 0 (only available with chat-read-status capability).

Implementation

int get lastCommonReadMessage;