lastMessage property

RoomLastMessage? get lastMessage

Last message in a conversation if available, otherwise empty. Note: Even when given the message will not contain the parent or reactionsSelf attribute due to performance reasons.

Implementation

RoomLastMessage? get lastMessage;