objectType property
String
get
objectType
The type of object that the conversation is associated with (See Object types).
Implementation
String get objectType;
The type of object that the conversation is associated with (See Object types).
String get objectType;