permissions property

int get permissions

Combined final permissions for the current participant, permissions are picked in order of attendee then call then default and the first which is Custom will apply (see constants list).

Implementation

int get permissions;