status property
String?
get
status
Optional: Only available for one-to-one conversations, when includeStatus=true is set and the user has a status.
Implementation
String? get status;
Optional: Only available for one-to-one conversations, when includeStatus=true is set and the user has a status.
String? get status;