statusIcon property

String? get statusIcon

Optional: Only available for one-to-one conversations, when includeStatus=true is set and the user has a status, can still be null even with a status.

Implementation

String? get statusIcon;