token property
String
get
token
Token identifier of the conversation which is used for further interaction.
Implementation
String get token;
Token identifier of the conversation which is used for further interaction.
String get token;