unreadMention property
bool
get
unreadMention
Flag if the user was mentioned since their last visit.
Implementation
bool get unreadMention;
Flag if the user was mentioned since their last visit.
bool get unreadMention;