$RoomScheduleMeetingRequestApplicationJsonInterface class sealed

Implementers
Annotations
  • @BuiltValue.new(instantiable: false)

Properties

attendeeIds → BuiltList<int>?
List of attendee ids to invite, if null everyone will be invited, if empty array only the actor will receive the event.
no setter
calendarUri → String
Last part of the calendar URI as seen by the participant e.g. 'personal' or 'company_shared_by_other_user'.
no setter
description → String?
Description of the event, falling back to the conversation description if none is given.
no setter
end → int?
Unix timestamp when the meeting ends, falls back to 60 minutes after start.
no setter
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
start → int
Unix timestamp when the meeting starts.
no setter
title → String?
Title or summary of the event, falling back to the conversation name if none is given.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(void updates($RoomScheduleMeetingRequestApplicationJsonInterfaceBuilder)) → $RoomScheduleMeetingRequestApplicationJsonInterface
Rebuilds the instance.
toBuilder() → $RoomScheduleMeetingRequestApplicationJsonInterfaceBuilder
Converts the instance to a builder $RoomScheduleMeetingRequestApplicationJsonInterfaceBuilder.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited