description property
String?
get
description
Description of the event, falling back to the conversation description if none is given.
Implementation
String? get description;
Description of the event, falling back to the conversation description if none is given.
String? get description;