end property
int?
get
end
Unix timestamp when the meeting ends, falls back to 60 minutes after start.
Implementation
int? get end;
Unix timestamp when the meeting ends, falls back to 60 minutes after start.
int? get end;