title property
String?
get
title
Title or summary of the event, falling back to the conversation name if none is given.
Implementation
String? get title;
Title or summary of the event, falling back to the conversation name if none is given.
String? get title;