$RoomScheduleMeetingRequestApplicationJsonInterfaceBuilder class abstract mixin

Implementers

Properties

attendeeIds ↔ ListBuilder<int>
getter/setter pair
calendarUri String?
getter/setter pair
description String?
getter/setter pair
end int?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
start int?
getter/setter pair
title String?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
replace($RoomScheduleMeetingRequestApplicationJsonInterface other) → void
toString() String
A string representation of this object.
inherited
update(void updates($RoomScheduleMeetingRequestApplicationJsonInterfaceBuilder)) → void

Operators

operator ==(Object other) bool
The equality operator.
inherited