$RoomScheduleMeetingResponseApplicationJsonInterface class sealed

Implementers
Annotations
  • @BuiltValue.new(instantiable: false)

Properties

hashCode int
The hash code for this object.
no setterinherited
ocs RoomScheduleMeetingResponseApplicationJson_Ocs
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(void updates($RoomScheduleMeetingResponseApplicationJsonInterfaceBuilder)) $RoomScheduleMeetingResponseApplicationJsonInterface
Rebuilds the instance.
toBuilder() $RoomScheduleMeetingResponseApplicationJsonInterfaceBuilder
Converts the instance to a builder $RoomScheduleMeetingResponseApplicationJsonInterfaceBuilder.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited