rebuild abstract method

Rebuilds the instance.

The result is the same as this instance but with updates applied. updates is a function that takes a builder $RoomScheduleMeetingResponseApplicationJsonInterfaceBuilder.

Implementation

$RoomScheduleMeetingResponseApplicationJsonInterface rebuild(
  void Function($RoomScheduleMeetingResponseApplicationJsonInterfaceBuilder) updates,
);