rebuild abstract method
Rebuilds the instance.
The result is the same as this instance but with updates applied.
updates is a function that takes a builder $RoomScheduleMeetingResponseApplicationJson_OcsInterfaceBuilder.
Implementation
$RoomScheduleMeetingResponseApplicationJson_OcsInterface rebuild(
void Function($RoomScheduleMeetingResponseApplicationJson_OcsInterfaceBuilder) updates,
);