$RoomSetDescriptionRequestApplicationJsonInterface class sealed

Implementers
Annotations
  • @BuiltValue.new(instantiable: false)

Properties

description String
New description for the conversation (limited to 2.000 characters, was 500 before Talk 21).
no setter
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(void updates($RoomSetDescriptionRequestApplicationJsonInterfaceBuilder)) $RoomSetDescriptionRequestApplicationJsonInterface
Rebuilds the instance.
toBuilder() $RoomSetDescriptionRequestApplicationJsonInterfaceBuilder
Converts the instance to a builder $RoomSetDescriptionRequestApplicationJsonInterfaceBuilder.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited