$RoomSetLobbyRequestApplicationJsonInterface class sealed
- Implementers
- Annotations
-
- @BuiltValue.new(instantiable: false)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- state → RoomSetLobbyRequestApplicationJson_State
-
New state.
no setter
- timer → int?
-
Timer when the lobby will be removed.
no setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
rebuild(
void updates($RoomSetLobbyRequestApplicationJsonInterfaceBuilder)) → $RoomSetLobbyRequestApplicationJsonInterface - Rebuilds the instance.
-
toBuilder(
) → $RoomSetLobbyRequestApplicationJsonInterfaceBuilder - Converts the instance to a builder $RoomSetLobbyRequestApplicationJsonInterfaceBuilder.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited