rebuild abstract method
Rebuilds the instance.
The result is the same as this instance but with updates applied.
updates is a function that takes a builder $RoomUnarchiveConversationResponseApplicationJson_OcsInterfaceBuilder.
Implementation
$RoomUnarchiveConversationResponseApplicationJson_OcsInterface rebuild(
void Function($RoomUnarchiveConversationResponseApplicationJson_OcsInterfaceBuilder) updates,
);