rebuild abstract method

Rebuilds the instance.

The result is the same as this instance but with updates applied. updates is a function that takes a builder $RoomUnbindRoomFromObjectResponseApplicationJson_OcsInterfaceBuilder.

Implementation

$RoomUnbindRoomFromObjectResponseApplicationJson_OcsInterface rebuild(
  void Function($RoomUnbindRoomFromObjectResponseApplicationJson_OcsInterfaceBuilder) updates,
);