$SignalingFederationSettingsInterface class sealed

Implementers
Annotations
  • @BuiltValue.new(instantiable: false)

Properties

hashCode int
The hash code for this object.
no setterinherited
helloAuthParams SignalingFederationSettings_HelloAuthParams
no setter
nextcloudServer String
no setter
roomId String
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
server String
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(void updates($SignalingFederationSettingsInterfaceBuilder)) $SignalingFederationSettingsInterface
Rebuilds the instance.
toBuilder() $SignalingFederationSettingsInterfaceBuilder
Converts the instance to a builder $SignalingFederationSettingsInterfaceBuilder.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited