rebuild abstract method
Rebuilds the instance.
The result is the same as this instance but with updates applied.
updates is a function that takes a builder $SignalingGetWelcomeMessageResponseApplicationJson_Ocs_DataInterfaceBuilder.
Implementation
$SignalingGetWelcomeMessageResponseApplicationJson_Ocs_DataInterface rebuild(
void Function($SignalingGetWelcomeMessageResponseApplicationJson_Ocs_DataInterfaceBuilder) updates,
);