ActorTypes class

Inheritance

Properties

hashCode int
The hash code for this object.
no setterinherited
name String
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
Returns the serialized value of this enum value.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

serializer → Serializer<ActorTypes>
Serializer for ActorTypes.
no setter
values → BuiltSet<ActorTypes>
Returns a set with all values this enum contains.
no setter

Static Methods

valueOf(String name) ActorTypes
Returns the enum value associated to the name.

Constants

bots → const ActorTypes
bots
bridged → const ActorTypes
bridged
circles → const ActorTypes
circles
emails → const ActorTypes
emails
federatedUsers → const ActorTypes
federated_users
groups → const ActorTypes
groups
guests → const ActorTypes
guests
phones → const ActorTypes
phones
users → const ActorTypes
users