BanBuilder class

Implemented types

Constructors

BanBuilder()

Properties

bannedActorId ↔ String?
covariantgetter/setter pairoverride
bannedActorType ↔ String?
covariantgetter/setter pairoverride
bannedDisplayName ↔ String?
covariantgetter/setter pairoverride
bannedTime ↔ int?
covariantgetter/setter pairoverride
hashCode → int
The hash code for this object.
no setterinherited
id ↔ int?
covariantgetter/setter pairoverride
internalNote ↔ String?
covariantgetter/setter pairoverride
moderatorActorId ↔ String?
covariantgetter/setter pairoverride
moderatorActorType ↔ String?
covariantgetter/setter pairoverride
moderatorDisplayName ↔ String?
covariantgetter/setter pairoverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

build() → Ban
Builds.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
replace(covariant Ban other) → void
Replaces the value in the builder with a new one.
override
toString() → String
A string representation of this object.
inherited
update(void updates(BanBuilder)?) → void
Applies updates.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited