BanListBansResponseApplicationJson class abstract

Implemented types

Constructors

BanListBansResponseApplicationJson([void b(BanListBansResponseApplicationJsonBuilder)?])
Creates a new BanListBansResponseApplicationJson object using the builder pattern.
factory
BanListBansResponseApplicationJson.fromJson(Map<String, dynamic> json)
Creates a new object from the given json data.
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
ocs → BanListBansResponseApplicationJson_Ocs
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(BanListBansResponseApplicationJsonBuilder)) → BanListBansResponseApplicationJson
Rebuilds the instance.
inherited
toBuilder() → BanListBansResponseApplicationJsonBuilder
Converts the instance to a builder B.
inherited
toJson() → Map<String, dynamic>
Parses this object into a json like map.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

serializer → Serializer<BanListBansResponseApplicationJson>
Serializer for BanListBansResponseApplicationJson.
no setter