BotBuilder class

Implemented types

Constructors

BotBuilder()

Properties

description ↔ String?
covariantgetter/setter pairoverride
hashCode → int
The hash code for this object.
no setterinherited
id ↔ int?
covariantgetter/setter pairoverride
name ↔ String?
covariantgetter/setter pairoverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
state ↔ int?
covariantgetter/setter pairoverride

Methods

build() → Bot
Builds.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
replace(covariant Bot other) → void
Replaces the value in the builder with a new one.
override
toString() → String
A string representation of this object.
inherited
update(void updates(BotBuilder)?) → void
Applies updates.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited