Capabilities_Config_Call class abstract
- Implemented types
Constructors
- Capabilities_Config_Call([void b(Capabilities_Config_CallBuilder)?])
-
Creates a new Capabilities_Config_Call object using the builder pattern.
factory
-
Capabilities_Config_Call.fromJson(Map<
String, dynamic> json) -
Creates a new object from the given
jsondata.factory
Properties
- blurVirtualBackground → bool?
-
no setterinherited
- breakoutRooms → bool
-
no setterinherited
- canEnableSip → bool
-
no setterinherited
- canUploadBackground → bool
-
no setterinherited
- enabled → bool
-
no setterinherited
- endToEndEncryption → bool?
-
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- maxDuration → int?
-
no setterinherited
-
predefinedBackgrounds
→ BuiltList<
String> -
List of file names relative to the spreed/img/backgrounds/ web path, e.g.
2_home.jpg.no setterinherited -
predefinedBackgroundsV2
→ BuiltList<
String> ? -
List of file paths relative to the server web root with leading slash, e.g.
/apps/spreed/img/backgrounds/2_home.jpg.no setterinherited - recording → bool
-
no setterinherited
- recordingConsent → int
-
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sipDialoutEnabled → bool
-
no setterinherited
- sipEnabled → bool
-
no setterinherited
- startWithoutMedia → bool?
-
no setterinherited
-
supportedReactions
→ BuiltList<
String> -
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
rebuild(
dynamic updates(Capabilities_Config_CallBuilder)) → Capabilities_Config_Call -
Rebuilds the instance.
inherited
-
toBuilder(
) → Capabilities_Config_CallBuilder -
Converts the instance to a builder
B.inherited -
toJson(
) → Map< String, dynamic> - Parses this object into a json like map.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
-
serializer
→ Serializer<
Capabilities_Config_Call> -
Serializer for Capabilities_Config_Call.
no setter