Capabilities_Config_ConversationsBuilder class
- Implemented types
Constructors
Properties
- canCreate ↔ bool?
-
covariantgetter/setter pairoverride
- descriptionLength ↔ int?
-
covariantgetter/setter pairoverride
- forcePasswords ↔ bool?
-
covariantgetter/setter pairoverride
- hashCode → int
-
The hash code for this object.
no setterinherited
- listStyle ↔ Capabilities_Config_Conversations_ListStyle?
-
covariantgetter/setter pairoverride
- retentionEvent ↔ int?
-
covariantgetter/setter pairoverride
- retentionInstantMeetings ↔ int?
-
covariantgetter/setter pairoverride
- retentionPhone ↔ int?
-
covariantgetter/setter pairoverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
build(
) → Capabilities_Config_Conversations -
Builds.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
replace(
covariant Capabilities_Config_Conversations other) → void -
Replaces the value in the builder with a new one.
override
-
toString(
) → String -
A string representation of this object.
inherited
-
update(
void updates(Capabilities_Config_ConversationsBuilder)?) → void -
Applies updates.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited