Capabilities_Config_SignalingBuilder class

Implemented types

Properties

hashCode → int
The hash code for this object.
no setterinherited
helloV2TokenKey ↔ String?
covariantgetter/setter pairoverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sessionPingLimit ↔ int?
covariantgetter/setter pairoverride

Methods

build() → Capabilities_Config_Signaling
Builds.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
replace(covariant Capabilities_Config_Signaling other) → void
Replaces the value in the builder with a new one.
override
toString() → String
A string representation of this object.
inherited
update(void updates(Capabilities_Config_SignalingBuilder)?) → void
Applies updates.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited