ChatGetUpcomingRemindersResponseApplicationJson class abstract

Implemented types

Constructors

ChatGetUpcomingRemindersResponseApplicationJson([void b(ChatGetUpcomingRemindersResponseApplicationJsonBuilder)?])
Creates a new ChatGetUpcomingRemindersResponseApplicationJson object using the builder pattern.
factory
ChatGetUpcomingRemindersResponseApplicationJson.fromJson(Map<String, dynamic> json)
Creates a new object from the given json data.
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
ocs ChatGetUpcomingRemindersResponseApplicationJson_Ocs
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(ChatGetUpcomingRemindersResponseApplicationJsonBuilder)) ChatGetUpcomingRemindersResponseApplicationJson
Rebuilds the instance.
inherited
toBuilder() ChatGetUpcomingRemindersResponseApplicationJsonBuilder
Converts the instance to a builder B.
inherited
toJson() Map<String, dynamic>
Parses this object into a json like map.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

serializer → Serializer<ChatGetUpcomingRemindersResponseApplicationJson>
Serializer for ChatGetUpcomingRemindersResponseApplicationJson.
no setter