ChatMentionSuggestion class abstract

Implemented types

Constructors

ChatMentionSuggestion([void b(ChatMentionSuggestionBuilder)?])
Creates a new ChatMentionSuggestion object using the builder pattern.
factory
ChatMentionSuggestion.fromJson(Map<String, dynamic> json)
Creates a new object from the given json data.
factory

Properties

details → String?
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
id → String
no setterinherited
label → String
no setterinherited
mentionId → String
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
source → String
no setterinherited
status → String?
no setterinherited
statusClearAt → int?
no setterinherited
statusIcon → String?
no setterinherited
statusMessage → String?
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(ChatMentionSuggestionBuilder)) → ChatMentionSuggestion
Rebuilds the instance.
inherited
toBuilder() → ChatMentionSuggestionBuilder
Converts the instance to a builder B.
inherited
toJson() → Map<String, dynamic>
Parses this object into a json like map.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

serializer → Serializer<ChatMentionSuggestion>
Serializer for ChatMentionSuggestion.
no setter