ChatMentionSuggestionBuilder class

Implemented types

Properties

details ↔ String?
covariantgetter/setter pairoverride
hashCode → int
The hash code for this object.
no setterinherited
id ↔ String?
covariantgetter/setter pairoverride
label ↔ String?
covariantgetter/setter pairoverride
mentionId ↔ String?
covariantgetter/setter pairoverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
source ↔ String?
covariantgetter/setter pairoverride
status ↔ String?
covariantgetter/setter pairoverride
statusClearAt ↔ int?
covariantgetter/setter pairoverride
statusIcon ↔ String?
covariantgetter/setter pairoverride
statusMessage ↔ String?
covariantgetter/setter pairoverride

Methods

build() → ChatMentionSuggestion
Builds.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
replace(covariant ChatMentionSuggestion other) → void
Replaces the value in the builder with a new one.
override
toString() → String
A string representation of this object.
inherited
update(void updates(ChatMentionSuggestionBuilder)?) → void
Applies updates.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited