ChatReminderUpcoming class abstract

Implemented types

Constructors

ChatReminderUpcoming([void b(ChatReminderUpcomingBuilder)?])
Creates a new ChatReminderUpcoming object using the builder pattern.
factory
ChatReminderUpcoming.fromJson(Map<String, dynamic> json)
Creates a new object from the given json data.
factory

Properties

actorDisplayName → String
no setterinherited
actorId → String
no setterinherited
actorType → String
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
message → String
no setterinherited
messageId → int
no setterinherited
messageParameters → BuiltMap<String, BuiltMap<String, JsonObject>>
no setterinherited
reminderTimestamp → int
no setterinherited
roomToken → String
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(ChatReminderUpcomingBuilder)) → ChatReminderUpcoming
Rebuilds the instance.
inherited
toBuilder() → ChatReminderUpcomingBuilder
Converts the instance to a builder B.
inherited
toJson() → Map<String, dynamic>
Parses this object into a json like map.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

serializer → Serializer<ChatReminderUpcoming>
Serializer for ChatReminderUpcoming.
no setter