DashboardEvent class abstract

Implemented types

Constructors

DashboardEvent([void b(DashboardEventBuilder)?])
Creates a new DashboardEvent object using the builder pattern.
factory
DashboardEvent.fromJson(Map<String, dynamic> json)
Creates a new object from the given json data.
factory

Properties

accepted int?
no setterinherited
calendars → BuiltList<DashboardEventCalendar>
no setterinherited
declined int?
no setterinherited
end int
no setterinherited
eventAttachments → BuiltMap<String, DashboardEventAttachment>
no setterinherited
eventDescription String?
no setterinherited
no setterinherited
eventName String
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
invited int?
no setterinherited
roomActiveSince int?
no setterinherited
roomAvatarVersion String
no setterinherited
roomDisplayName String
no setterinherited
roomName String
no setterinherited
roomToken String
no setterinherited
roomType int
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
start int
no setterinherited
tentative int?
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(DashboardEventBuilder)) DashboardEvent
Rebuilds the instance.
inherited
toBuilder() DashboardEventBuilder
Converts the instance to a builder B.
inherited
toJson() Map<String, dynamic>
Parses this object into a json like map.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

serializer → Serializer<DashboardEvent>
Serializer for DashboardEvent.
no setter