DashboardEventAttachment class abstract

Implemented types

Constructors

DashboardEventAttachment([void b(DashboardEventAttachmentBuilder)?])
Creates a new DashboardEventAttachment object using the builder pattern.
factory
DashboardEventAttachment.fromJson(Map<String, dynamic> json)
Creates a new object from the given json data.
factory

Properties

calendars → BuiltList<String>
no setterinherited
fileid → int
no setterinherited
filename → String
no setterinherited
fmttype → String
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
preview → bool
no setterinherited
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(DashboardEventAttachmentBuilder)) → DashboardEventAttachment
Rebuilds the instance.
inherited
toBuilder() → DashboardEventAttachmentBuilder
Converts the instance to a builder B.
inherited
toJson() → Map<String, dynamic>
Parses this object into a json like map.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

serializer → Serializer<DashboardEventAttachment>
Serializer for DashboardEventAttachment.
no setter