DashboardEventAttachmentBuilder class

Implemented types

Properties

calendars ↔ ListBuilder<String>
covariantgetter/setter pairoverride
fileid int?
covariantgetter/setter pairoverride
filename String?
covariantgetter/setter pairoverride
fmttype String?
covariantgetter/setter pairoverride
hashCode int
The hash code for this object.
no setterinherited
preview bool?
covariantgetter/setter pairoverride
covariantgetter/setter pairoverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

build() DashboardEventAttachment
Builds.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
replace(covariant DashboardEventAttachment other) → void
Replaces the value in the builder with a new one.
override
toString() String
A string representation of this object.
inherited
update(void updates(DashboardEventAttachmentBuilder)?) → void
Applies updates.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited