DashboardEventCalendar class abstract

Implemented types

Constructors

DashboardEventCalendar([void b(DashboardEventCalendarBuilder)?])
Creates a new DashboardEventCalendar object using the builder pattern.
factory
DashboardEventCalendar.fromJson(Map<String, dynamic> json)
Creates a new object from the given json data.
factory

Properties

calendarColor → String?
no setterinherited
calendarName → String
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
principalUri → String
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(DashboardEventCalendarBuilder)) → DashboardEventCalendar
Rebuilds the instance.
inherited
toBuilder() → DashboardEventCalendarBuilder
Converts the instance to a builder B.
inherited
toJson() → Map<String, dynamic>
Parses this object into a json like map.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

serializer → Serializer<DashboardEventCalendar>
Serializer for DashboardEventCalendar.
no setter