InvitationList class abstract

Implemented types

Constructors

InvitationList([void b(InvitationListBuilder)?])
Creates a new InvitationList object using the builder pattern.
factory
InvitationList.fromJson(Map<String, dynamic> json)
Creates a new object from the given json data.
factory

Properties

emails → BuiltList<String>?
no setterinherited
federatedUsers → BuiltList<String>?
no setterinherited
groups → BuiltList<String>?
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
phones → BuiltList<String>?
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
teams → BuiltList<String>?
no setterinherited
users → BuiltList<String>?
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(InvitationListBuilder)) InvitationList
Rebuilds the instance.
inherited
toBuilder() InvitationListBuilder
Converts the instance to a builder B.
inherited
toJson() Map<String, dynamic>
Parses this object into a json like map.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

serializer → Serializer<InvitationList>
Serializer for InvitationList.
no setter