PollDraft class abstract

Implemented types

Constructors

PollDraft([void b(PollDraftBuilder)?])
Creates a new PollDraft object using the builder pattern.
factory
PollDraft.fromJson(Map<String, dynamic> json)
Creates a new object from the given json data.
factory

Properties

actorDisplayName String
no setterinherited
actorId String
no setterinherited
actorType ActorTypes
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
id int
no setterinherited
maxVotes int
no setterinherited
options → BuiltList<String>
no setterinherited
question String
no setterinherited
resultMode PollDraft_ResultMode
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
status PollDraft_Status
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(PollDraftBuilder)) PollDraft
Rebuilds the instance.
inherited
toBuilder() PollDraftBuilder
Converts the instance to a builder B.
inherited
toJson() Map<String, dynamic>
Parses this object into a json like map.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

serializer → Serializer<PollDraft>
Serializer for PollDraft.
no setter