PollDraft_Status class

Inheritance
  • Object
  • EnumClass
  • PollDraft_Status

Properties

hashCode int
The hash code for this object.
no setterinherited
name String
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value int
Returns the serialized value of this enum value.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

serializer → Serializer<PollDraft_Status>
Serializer for PollDraft_Status.
no setter
values → BuiltSet<PollDraft_Status>
Returns a set with all values this enum contains.
no setter

Static Methods

valueOf(String name) PollDraft_Status
Returns the enum value associated to the name.

Constants

$0 → const PollDraft_Status
0
$1 → const PollDraft_Status
1
$2 → const PollDraft_Status
2