PollUpdateDraftPollRequestApplicationJson class abstract

Implemented types

Constructors

PollUpdateDraftPollRequestApplicationJson([void b(PollUpdateDraftPollRequestApplicationJsonBuilder)?])
Creates a new PollUpdateDraftPollRequestApplicationJson object using the builder pattern.
factory
PollUpdateDraftPollRequestApplicationJson.fromJson(Map<String, dynamic> json)
Creates a new object from the given json data.
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
maxVotes int
Number of maximum votes per voter.
no setterinherited
options → BuiltList<String>
Options of the poll.
no setterinherited
question String
Question of the poll.
no setterinherited
resultMode PollUpdateDraftPollRequestApplicationJson_ResultMode
Mode how the results will be shown.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(PollUpdateDraftPollRequestApplicationJsonBuilder)) PollUpdateDraftPollRequestApplicationJson
Rebuilds the instance.
inherited
toBuilder() PollUpdateDraftPollRequestApplicationJsonBuilder
Converts the instance to a builder B.
inherited
toJson() Map<String, dynamic>
Parses this object into a json like map.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

serializer → Serializer<PollUpdateDraftPollRequestApplicationJson>
Serializer for PollUpdateDraftPollRequestApplicationJson.
no setter