RoomCreateRoomRequestApplicationJson class abstract

Implemented types

Constructors

RoomCreateRoomRequestApplicationJson([void b(RoomCreateRoomRequestApplicationJsonBuilder)?])
Creates a new RoomCreateRoomRequestApplicationJson object using the builder pattern.
factory
RoomCreateRoomRequestApplicationJson.fromJson(Map<String, dynamic> json)
Creates a new object from the given json data.
factory

Properties

avatarColor String?
Background color of the avatar (Only considered when an emoji was provided) (only available with conversation-creation-all capability).
no setterinherited
description String
Description for the conversation (limited to 2.000 characters) (only available with conversation-creation-all capability).
no setterinherited
emoji String?
Emoji for the avatar of the conversation (only available with conversation-creation-all capability).
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
invite String
User, group, … ID to invite Deprecated Use the $participants array instead.
no setterinherited
listable RoomCreateRoomRequestApplicationJson_Listable?
Scope where the conversation is listable (Default not listable for anyone) (only available with conversation-creation-all capability).
no setterinherited
lobbyState RoomCreateRoomRequestApplicationJson_LobbyState?
Lobby state of the conversation (Default lobby is disabled) (only available with conversation-creation-all capability).
no setterinherited
lobbyTimer int?
Timer when the lobby will be removed (Default null, will not be disabled automatically) (only available with conversation-creation-all capability).
no setterinherited
mentionPermissions RoomCreateRoomRequestApplicationJson_MentionPermissions?
Who can mention at-all in the chat (only available with conversation-creation-all capability).
no setterinherited
messageExpiration int
Seconds after which messages will disappear, 0 disables expiration (Default 0) (only available with conversation-creation-all capability).
no setterinherited
objectId String
ID of the object (Ignored if $roomType is {@see Room::TYPE_ONE_TO_ONE}).
no setterinherited
objectType String
Type of the object (Ignored if $roomType is {@see Room::TYPE_ONE_TO_ONE}).
no setterinherited
participants InvitationList
List of participants to add grouped by type (only available with conversation-creation-all capability).
no setterinherited
password String
The room password (only available with conversation-creation-password capability) (Ignored if $roomType is not {@see Room::TYPE_PUBLIC}).
no setterinherited
permissions int?
Default permissions for participants (only available with conversation-creation-all capability).
no setterinherited
readOnly RoomCreateRoomRequestApplicationJson_ReadOnly?
Read only state of the conversation (Default writable) (only available with conversation-creation-all capability).
no setterinherited
recordingConsent RoomCreateRoomRequestApplicationJson_RecordingConsent?
Whether participants need to agree to a recording before joining a call (only available with conversation-creation-all capability).
no setterinherited
roomName String
Name of the room, unless the legacy mode providing $invite and $source is used, the name must no longer be empty with the conversation-creation-all capability (Ignored if $roomType is {@see Room::TYPE_ONE_TO_ONE}).
no setterinherited
roomType int
Type of the room.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sipEnabled RoomCreateRoomRequestApplicationJson_SipEnabled?
Whether SIP dial-in shall be enabled (only available with conversation-creation-all capability).
no setterinherited
source String
Source of the invite ID ('circles' to create a room with a circle, etc.) Deprecated Use the $participants array instead.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(RoomCreateRoomRequestApplicationJsonBuilder)) RoomCreateRoomRequestApplicationJson
Rebuilds the instance.
inherited
toBuilder() RoomCreateRoomRequestApplicationJsonBuilder
Converts the instance to a builder B.
inherited
toJson() Map<String, dynamic>
Parses this object into a json like map.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

serializer → Serializer<RoomCreateRoomRequestApplicationJson>
Serializer for RoomCreateRoomRequestApplicationJson.
no setter