RoomDirectDialInRequestApplicationJson class abstract

Implemented types

Constructors

RoomDirectDialInRequestApplicationJson([void b(RoomDirectDialInRequestApplicationJsonBuilder)?])
Creates a new RoomDirectDialInRequestApplicationJson object using the builder pattern.
factory
RoomDirectDialInRequestApplicationJson.fromJson(Map<String, dynamic> json)
Creates a new object from the given json data.
factory

Properties

caller String
Phone number of the person calling in.
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
phoneNumber String
Phone number that is called.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(RoomDirectDialInRequestApplicationJsonBuilder)) RoomDirectDialInRequestApplicationJson
Rebuilds the instance.
inherited
toBuilder() RoomDirectDialInRequestApplicationJsonBuilder
Converts the instance to a builder B.
inherited
toJson() Map<String, dynamic>
Parses this object into a json like map.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

serializer → Serializer<RoomDirectDialInRequestApplicationJson>
Serializer for RoomDirectDialInRequestApplicationJson.
no setter