RoomImportEmailsAsParticipantsRequestApplicationJson class abstract

Implemented types

Constructors

RoomImportEmailsAsParticipantsRequestApplicationJson([void b(RoomImportEmailsAsParticipantsRequestApplicationJsonBuilder)?])
Creates a new RoomImportEmailsAsParticipantsRequestApplicationJson object using the builder pattern.
factory
RoomImportEmailsAsParticipantsRequestApplicationJson.fromJson(Map<String, dynamic> json)
Creates a new object from the given json data.
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
testRun bool
When set to true, the file is validated and no email is actually sent nor any participant added to the conversation.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(RoomImportEmailsAsParticipantsRequestApplicationJsonBuilder)) RoomImportEmailsAsParticipantsRequestApplicationJson
Rebuilds the instance.
inherited
toBuilder() RoomImportEmailsAsParticipantsRequestApplicationJsonBuilder
Converts the instance to a builder B.
inherited
toJson() Map<String, dynamic>
Parses this object into a json like map.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

serializer → Serializer<RoomImportEmailsAsParticipantsRequestApplicationJson>
Serializer for RoomImportEmailsAsParticipantsRequestApplicationJson.
no setter