RoomImportEmailsAsParticipantsResponseApplicationJson_Ocs_Data class abstract

Implemented types

Constructors

RoomImportEmailsAsParticipantsResponseApplicationJson_Ocs_Data([void b(RoomImportEmailsAsParticipantsResponseApplicationJson_Ocs_DataBuilder)?])
Creates a new RoomImportEmailsAsParticipantsResponseApplicationJson_Ocs_Data object using the builder pattern.
factory
RoomImportEmailsAsParticipantsResponseApplicationJson_Ocs_Data.fromJson(Map<String, dynamic> json)
Creates a new object from the given json data.
factory

Properties

duplicates → int
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
invalid → int?
no setterinherited
invalidLines → BuiltList<int>?
no setterinherited
invites → int
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → int?
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(RoomImportEmailsAsParticipantsResponseApplicationJson_Ocs_DataBuilder)) → RoomImportEmailsAsParticipantsResponseApplicationJson_Ocs_Data
Rebuilds the instance.
inherited
toBuilder() → RoomImportEmailsAsParticipantsResponseApplicationJson_Ocs_DataBuilder
Converts the instance to a builder B.
inherited
toJson() → Map<String, dynamic>
Parses this object into a json like map.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

serializer → Serializer<RoomImportEmailsAsParticipantsResponseApplicationJson_Ocs_Data>
Serializer for RoomImportEmailsAsParticipantsResponseApplicationJson_Ocs_Data.
no setter