RoomImportEmailsAsParticipantsResponseApplicationJson_Ocs_DataBuilder class

Implemented types

Properties

duplicates ↔ int?
covariantgetter/setter pairoverride
hashCode → int
The hash code for this object.
no setterinherited
invalid ↔ int?
covariantgetter/setter pairoverride
invalidLines ↔ ListBuilder<int>
covariantgetter/setter pairoverride
invites ↔ int?
covariantgetter/setter pairoverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type ↔ int?
covariantgetter/setter pairoverride

Methods

build() → RoomImportEmailsAsParticipantsResponseApplicationJson_Ocs_Data
Builds.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
replace(covariant RoomImportEmailsAsParticipantsResponseApplicationJson_Ocs_Data other) → void
Replaces the value in the builder with a new one.
override
toString() → String
A string representation of this object.
inherited
update(void updates(RoomImportEmailsAsParticipantsResponseApplicationJson_Ocs_DataBuilder)?) → void
Applies updates.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited