RoomLeaveFederatedRoomResponseApplicationJson class abstract

Implemented types

Constructors

RoomLeaveFederatedRoomResponseApplicationJson([void b(RoomLeaveFederatedRoomResponseApplicationJsonBuilder)?])
Creates a new RoomLeaveFederatedRoomResponseApplicationJson object using the builder pattern.
factory
RoomLeaveFederatedRoomResponseApplicationJson.fromJson(Map<String, dynamic> json)
Creates a new object from the given json data.
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
ocs → RoomLeaveFederatedRoomResponseApplicationJson_Ocs
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(RoomLeaveFederatedRoomResponseApplicationJsonBuilder)) → RoomLeaveFederatedRoomResponseApplicationJson
Rebuilds the instance.
inherited
toBuilder() → RoomLeaveFederatedRoomResponseApplicationJsonBuilder
Converts the instance to a builder B.
inherited
toJson() → Map<String, dynamic>
Parses this object into a json like map.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

serializer → Serializer<RoomLeaveFederatedRoomResponseApplicationJson>
Serializer for RoomLeaveFederatedRoomResponseApplicationJson.
no setter