RoomMakePublicRequestApplicationJson class abstract

Implemented types

Constructors

RoomMakePublicRequestApplicationJson([void b(RoomMakePublicRequestApplicationJsonBuilder)?])
Creates a new RoomMakePublicRequestApplicationJson object using the builder pattern.
factory
RoomMakePublicRequestApplicationJson.fromJson(Map<String, dynamic> json)
Creates a new object from the given json data.
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
password → String
New password (only available with conversation-creation-password capability).
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(RoomMakePublicRequestApplicationJsonBuilder)) → RoomMakePublicRequestApplicationJson
Rebuilds the instance.
inherited
toBuilder() → RoomMakePublicRequestApplicationJsonBuilder
Converts the instance to a builder B.
inherited
toJson() → Map<String, dynamic>
Parses this object into a json like map.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

serializer → Serializer<RoomMakePublicRequestApplicationJson>
Serializer for RoomMakePublicRequestApplicationJson.
no setter