RoomRenameRoomRequestApplicationJson class abstract

Implemented types

Constructors

RoomRenameRoomRequestApplicationJson([void b(RoomRenameRoomRequestApplicationJsonBuilder)?])
Creates a new RoomRenameRoomRequestApplicationJson object using the builder pattern.
factory
RoomRenameRoomRequestApplicationJson.fromJson(Map<String, dynamic> json)
Creates a new object from the given json data.
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
roomName → String
New name.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(RoomRenameRoomRequestApplicationJsonBuilder)) → RoomRenameRoomRequestApplicationJson
Rebuilds the instance.
inherited
toBuilder() → RoomRenameRoomRequestApplicationJsonBuilder
Converts the instance to a builder B.
inherited
toJson() → Map<String, dynamic>
Parses this object into a json like map.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

serializer → Serializer<RoomRenameRoomRequestApplicationJson>
Serializer for RoomRenameRoomRequestApplicationJson.
no setter