RoomRoomGetCapabilitiesHeaders class abstract

Implemented types

Constructors

RoomRoomGetCapabilitiesHeaders([void b(RoomRoomGetCapabilitiesHeadersBuilder)?])
Creates a new RoomRoomGetCapabilitiesHeaders object using the builder pattern.
factory
RoomRoomGetCapabilitiesHeaders.fromJson(Map<String, dynamic> json)
Creates a new object from the given json data.
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
xNextcloudTalkHash → String?
no setterinherited
xNextcloudTalkProxyHash → String?
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(RoomRoomGetCapabilitiesHeadersBuilder)) → RoomRoomGetCapabilitiesHeaders
Rebuilds the instance.
inherited
toBuilder() → RoomRoomGetCapabilitiesHeadersBuilder
Converts the instance to a builder B.
inherited
toJson() → Map<String, dynamic>
Parses this object into a json like map.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

serializer → Serializer<RoomRoomGetCapabilitiesHeaders>
Serializer for RoomRoomGetCapabilitiesHeaders.
no setter