RoomRoomSetAttendeePermissionsHeaders class abstract

Implemented types

Constructors

RoomRoomSetAttendeePermissionsHeaders([void b(RoomRoomSetAttendeePermissionsHeadersBuilder)?])
Creates a new RoomRoomSetAttendeePermissionsHeaders object using the builder pattern.
factory
RoomRoomSetAttendeePermissionsHeaders.fromJson(Map<String, dynamic> json)
Creates a new object from the given json data.
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
xNextcloudHasUserStatuses Header<RoomRoomSetAttendeePermissionsHeaders_XNextcloudHasUserStatuses?>?
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(RoomRoomSetAttendeePermissionsHeadersBuilder)) RoomRoomSetAttendeePermissionsHeaders
Rebuilds the instance.
inherited
toBuilder() RoomRoomSetAttendeePermissionsHeadersBuilder
Converts the instance to a builder B.
inherited
toJson() Map<String, dynamic>
Parses this object into a json like map.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

serializer → Serializer<RoomRoomSetAttendeePermissionsHeaders>
Serializer for RoomRoomSetAttendeePermissionsHeaders.
no setter