RoomRoomSetAttendeePermissionsHeaders_XNextcloudHasUserStatuses class

Inheritance
  • Object
  • EnumClass
  • RoomRoomSetAttendeePermissionsHeaders_XNextcloudHasUserStatuses

Properties

hashCode int
The hash code for this object.
no setterinherited
name String
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value bool
Returns the serialized value of this enum value.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

serializer → Serializer<RoomRoomSetAttendeePermissionsHeaders_XNextcloudHasUserStatuses>
Serializer for RoomRoomSetAttendeePermissionsHeaders_XNextcloudHasUserStatuses.
no setter
values → BuiltSet<RoomRoomSetAttendeePermissionsHeaders_XNextcloudHasUserStatuses>
Returns a set with all values this enum contains.
no setter

Static Methods

valueOf(String name) RoomRoomSetAttendeePermissionsHeaders_XNextcloudHasUserStatuses
Returns the enum value associated to the name.