RoomScheduleMeetingRequestApplicationJson class abstract

Implemented types

Constructors

RoomScheduleMeetingRequestApplicationJson([void b(RoomScheduleMeetingRequestApplicationJsonBuilder)?])
Creates a new RoomScheduleMeetingRequestApplicationJson object using the builder pattern.
factory
RoomScheduleMeetingRequestApplicationJson.fromJson(Map<String, dynamic> json)
Creates a new object from the given json data.
factory

Properties

attendeeIds → BuiltList<int>?
List of attendee ids to invite, if null everyone will be invited, if empty array only the actor will receive the event.
no setterinherited
calendarUri → String
Last part of the calendar URI as seen by the participant e.g. 'personal' or 'company_shared_by_other_user'.
no setterinherited
description → String?
Description of the event, falling back to the conversation description if none is given.
no setterinherited
end → int?
Unix timestamp when the meeting ends, falls back to 60 minutes after start.
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
start → int
Unix timestamp when the meeting starts.
no setterinherited
title → String?
Title or summary of the event, falling back to the conversation name if none is given.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(RoomScheduleMeetingRequestApplicationJsonBuilder)) → RoomScheduleMeetingRequestApplicationJson
Rebuilds the instance.
inherited
toBuilder() → RoomScheduleMeetingRequestApplicationJsonBuilder
Converts the instance to a builder B.
inherited
toJson() → Map<String, dynamic>
Parses this object into a json like map.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

serializer → Serializer<RoomScheduleMeetingRequestApplicationJson>
Serializer for RoomScheduleMeetingRequestApplicationJson.
no setter