SignalingBackendResponseApplicationJson_Ocs_Data_RoomBuilder class

Implemented types

Properties

hashCode → int
The hash code for this object.
no setterinherited
permissions ↔ ListBuilder<String>
covariantgetter/setter pairoverride
properties ↔ MapBuilder<String, JsonObject>
covariantgetter/setter pairoverride
roomid ↔ String?
covariantgetter/setter pairoverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
session ↔ MapBuilder<String, JsonObject>
covariantgetter/setter pairoverride
version ↔ String?
covariantgetter/setter pairoverride

Methods

build() → SignalingBackendResponseApplicationJson_Ocs_Data_Room
Builds.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
replace(covariant SignalingBackendResponseApplicationJson_Ocs_Data_Room other) → void
Replaces the value in the builder with a new one.
override
toString() → String
A string representation of this object.
inherited
update(void updates(SignalingBackendResponseApplicationJson_Ocs_Data_RoomBuilder)?) → void
Applies updates.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited