SignalingFederationSettings_HelloAuthParams class abstract

Implemented types

Constructors

SignalingFederationSettings_HelloAuthParams([void b(SignalingFederationSettings_HelloAuthParamsBuilder)?])
Creates a new SignalingFederationSettings_HelloAuthParams object using the builder pattern.
factory
SignalingFederationSettings_HelloAuthParams.fromJson(Map<String, dynamic> json)
Creates a new object from the given json data.
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
token String
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(SignalingFederationSettings_HelloAuthParamsBuilder)) SignalingFederationSettings_HelloAuthParams
Rebuilds the instance.
inherited
toBuilder() SignalingFederationSettings_HelloAuthParamsBuilder
Converts the instance to a builder B.
inherited
toJson() Map<String, dynamic>
Parses this object into a json like map.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

serializer → Serializer<SignalingFederationSettings_HelloAuthParams>
Serializer for SignalingFederationSettings_HelloAuthParams.
no setter