SignalingFederationSettings_HelloAuthParamsBuilder class
- Implemented types
Constructors
Properties
Methods
-
build(
) → SignalingFederationSettings_HelloAuthParams -
Builds.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
replace(
covariant SignalingFederationSettings_HelloAuthParams other) → void -
Replaces the value in the builder with a new one.
override
-
toString(
) → String -
A string representation of this object.
inherited
-
update(
void updates(SignalingFederationSettings_HelloAuthParamsBuilder)?) → void -
Applies updates.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited