updateColumn method

Future<DynamiteResponse<Column, void>> updateColumn({
  1. required int columnId,
  2. required Api1UpdateColumnRequestApplicationJson $body,
})

Update a column.

This endpoint allows CORS requests.

Returns a Future containing a DynamiteResponse with the status code, deserialized body and headers. Throws a DynamiteApiException if the API call does not return an expected status code.

Parameters:

  • columnId Column ID that will be updated.

Status codes:

  • 200: Updated column
  • 500
  • 400: Invalid arguments
  • 401: Current user is not logged in

See:

Implementation

Future<_i1.DynamiteResponse<Column, void>> updateColumn({
  required int columnId,
  required Api1UpdateColumnRequestApplicationJson $body,
}) async {
  final _request = $updateColumn_Request(columnId: columnId, $body: $body);
  final _streamedResponse = await _rootClient.httpClient.send(_request);
  final _response = await _i3.Response.fromStream(_streamedResponse);

  final _serializer = $updateColumn_Serializer();
  return _i1.ResponseConverter<Column, void>(_serializer).convert(_response);
}