createSelectionColumn method

api v2 Create new selection column.

Specify a subtype to use any special selection column.

Returns a Future containing a DynamiteResponse with the status code, deserialized body and headers. Throws a DynamiteApiException if the API call does not return an expected status code.

Parameters:

  • oCSAPIRequest Required to be true for the API request to pass. Defaults to true.

Status codes:

  • 200: Column created
  • 403: No permission
  • 500
  • 404: Not found
  • 401: Current user is not logged in

See:

Implementation

Future<_i1.DynamiteResponse<ApiColumnsCreateSelectionColumnResponseApplicationJson, void>> createSelectionColumn({
  required ApiColumnsCreateSelectionColumnRequestApplicationJson $body,
  bool? oCSAPIRequest,
}) async {
  final _request = $createSelectionColumn_Request(oCSAPIRequest: oCSAPIRequest, $body: $body);
  final _streamedResponse = await _rootClient.httpClient.send(_request);
  final _response = await _i3.Response.fromStream(_streamedResponse);

  final _serializer = $createSelectionColumn_Serializer();
  return _i1.ResponseConverter<ApiColumnsCreateSelectionColumnResponseApplicationJson, void>(
    _serializer,
  ).convert(_response);
}