$ApiColumnsCreateDatetimeColumnRequestApplicationJsonInterface class sealed

Implementers
Annotations
  • @BuiltValue.new(instantiable: false)

Properties

baseNodeId → int
Context of the column creation.
no setter
baseNodeType → ApiColumnsCreateDatetimeColumnRequestApplicationJson_BaseNodeType
Context type of the column creation.
no setter
datetimeDefault → ApiColumnsCreateDatetimeColumnRequestApplicationJson_DatetimeDefault?
For a subtype 'date' you can set 'today'. For a main type or subtype 'time' you can set to 'now'.
no setter
description → String?
Description.
no setter
hashCode → int
The hash code for this object.
no setterinherited
mandatory → bool
Is mandatory.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
selectedViewIds → BuiltList<int>?
View IDs where this columns should be added.
no setter
subtype → ApiColumnsCreateDatetimeColumnRequestApplicationJson_Subtype?
Subtype for the new column.
no setter
title → String
Title.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(void updates($ApiColumnsCreateDatetimeColumnRequestApplicationJsonInterfaceBuilder)) → $ApiColumnsCreateDatetimeColumnRequestApplicationJsonInterface
Rebuilds the instance.
toBuilder() → $ApiColumnsCreateDatetimeColumnRequestApplicationJsonInterfaceBuilder
Converts the instance to a builder $ApiColumnsCreateDatetimeColumnRequestApplicationJsonInterfaceBuilder.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited