$ApiColumnsCreateNumberColumnRequestApplicationJsonInterfaceBuilder class abstract mixin

Implementers

Properties

baseNodeId ↔ int?
getter/setter pair
baseNodeType ↔ ApiColumnsCreateNumberColumnRequestApplicationJson_BaseNodeType?
getter/setter pair
description ↔ String?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
mandatory ↔ bool?
getter/setter pair
numberDecimals ↔ int?
getter/setter pair
numberDefault ↔ double?
getter/setter pair
numberMax ↔ double?
getter/setter pair
numberMin ↔ double?
getter/setter pair
numberPrefix ↔ String?
getter/setter pair
numberSuffix ↔ String?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
selectedViewIds ↔ ListBuilder<int>
getter/setter pair
subtype ↔ ApiColumnsCreateNumberColumnRequestApplicationJson_Subtype?
getter/setter pair
title ↔ String?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
replace($ApiColumnsCreateNumberColumnRequestApplicationJsonInterface other) → void
toString() → String
A string representation of this object.
inherited
update(void updates($ApiColumnsCreateNumberColumnRequestApplicationJsonInterfaceBuilder)) → void

Operators

operator ==(Object other) → bool
The equality operator.
inherited