$ApiColumnsCreateTextColumnRequestApplicationJsonInterface class sealed

Implementers
Annotations
  • @BuiltValue.new(instantiable: false)

Properties

baseNodeId → int
Context of the column creation.
no setter
baseNodeType → ApiColumnsCreateTextColumnRequestApplicationJson_BaseNodeType
Context type of the column creation.
no setter
description → String?
Description.
no setter
hashCode → int
The hash code for this object.
no setterinherited
mandatory → bool
Is mandatory.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
selectedViewIds → BuiltList<int>?
View IDs where this columns should be added.
no setter
subtype → ApiColumnsCreateTextColumnRequestApplicationJson_Subtype?
Subtype for the new column.
no setter
textAllowedPattern → String?
Allowed regex pattern.
no setter
textDefault → String?
Default.
no setter
textMaxLength → int?
Max raw text length.
no setter
title → String
Title.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(void updates($ApiColumnsCreateTextColumnRequestApplicationJsonInterfaceBuilder)) → $ApiColumnsCreateTextColumnRequestApplicationJsonInterface
Rebuilds the instance.
toBuilder() → $ApiColumnsCreateTextColumnRequestApplicationJsonInterfaceBuilder
Converts the instance to a builder $ApiColumnsCreateTextColumnRequestApplicationJsonInterfaceBuilder.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited