$ApiColumnsCreateUsergroupColumnRequestApplicationJsonInterface class sealed

Implementers
Annotations
  • @BuiltValue.new(instantiable: false)

Properties

baseNodeId → int
Context of the column creation.
no setter
baseNodeType → ApiColumnsCreateUsergroupColumnRequestApplicationJson_BaseNodeType
Context type of the column creation.
no setter
description → String?
Description.
no setter
hashCode → int
The hash code for this object.
no setterinherited
mandatory → bool
Is mandatory.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
selectedViewIds → BuiltList<int>?
View IDs where this columns should be added.
no setter
showUserStatus → bool?
Whether to show the user's status.
no setter
title → String
Title.
no setter
usergroupDefault → String?
Json array{id: string, type: int}, eg {"id": "admin", "type": 0}, {"id": "user1", "type": 0}.
no setter
usergroupMultipleItems → bool?
Whether you can select multiple users or/and groups.
no setter
usergroupSelectGroups → bool?
Whether you can select groups.
no setter
usergroupSelectTeams → bool?
Whether you can select teams.
no setter
usergroupSelectUsers → bool?
Whether you can select users.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(void updates($ApiColumnsCreateUsergroupColumnRequestApplicationJsonInterfaceBuilder)) → $ApiColumnsCreateUsergroupColumnRequestApplicationJsonInterface
Rebuilds the instance.
toBuilder() → $ApiColumnsCreateUsergroupColumnRequestApplicationJsonInterfaceBuilder
Converts the instance to a builder $ApiColumnsCreateUsergroupColumnRequestApplicationJsonInterfaceBuilder.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited