createFromScheme method

creates table from scheme.

Returns a Future containing a DynamiteResponse with the status code, deserialized body and headers. Throws a DynamiteApiException if the API call does not return an expected status code.

Parameters:

  • oCSAPIRequest Required to be true for the API request to pass. Defaults to true.

Status codes:

  • 200: Tables returned
  • 500
  • 401: Current user is not logged in

See:

Implementation

Future<_i1.DynamiteResponse<ApiTablesCreateFromSchemeResponseApplicationJson, void>> createFromScheme({
  required ApiTablesCreateFromSchemeRequestApplicationJson $body,
  bool? oCSAPIRequest,
}) async {
  final _request = $createFromScheme_Request(oCSAPIRequest: oCSAPIRequest, $body: $body);
  final _streamedResponse = await _rootClient.httpClient.send(_request);
  final _response = await _i3.Response.fromStream(_streamedResponse);

  final _serializer = $createFromScheme_Serializer();
  return _i1.ResponseConverter<ApiTablesCreateFromSchemeResponseApplicationJson, void>(
    _serializer,
  ).convert(_response);
}