$RowInterface class sealed

Implementers
Annotations
  • @BuiltValue.new(instantiable: false)

Properties

createdAt → String
no setter
createdBy → String
no setter
data → Row_Data?
no setter
hashCode → int
The hash code for this object.
no setterinherited
id → int
no setter
lastEditAt → String
no setter
lastEditBy → String
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tableId → int
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(void updates($RowInterfaceBuilder)) → $RowInterface
Rebuilds the instance.
toBuilder() → $RowInterfaceBuilder
Converts the instance to a builder $RowInterfaceBuilder.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited