$createRow_Request method
- @experimental
- required RowocsCreateRowNodeCollection nodeCollection,
- required int nodeId,
- required RowocsCreateRowRequestApplicationJson $body,
- bool? oCSAPIRequest,
api v2 Create a new row in a table or a view.
Returns a DynamiteRequest backing the createRow operation.
Throws a DynamiteApiException if the API call does not return an expected status code.
Parameters:
nodeCollectionIndicates whether to create a row on a table or view.nodeIdThe identifier of the targeted table or view.oCSAPIRequestRequired to be true for the API request to pass. Defaults totrue.
Status codes:
- 200: Row returned
- 403: No permissions
- 400: Invalid request parameters
- 404: Not found
- 500: Internal error
- 401: Current user is not logged in
See:
- createRow for a method executing this request and parsing the response.
- $createRow_Serializer for a converter to parse the
Responsefrom an executed this request.
Implementation
@_i2.experimental
_i3.Request $createRow_Request({
required RowocsCreateRowNodeCollection nodeCollection,
required int nodeId,
required RowocsCreateRowRequestApplicationJson $body,
bool? oCSAPIRequest,
}) {
final _parameters = <String, Object?>{};
final __nodeCollection = _$jsonSerializers.serialize(
nodeCollection,
specifiedType: const FullType(RowocsCreateRowNodeCollection),
);
_i6.checkString(__nodeCollection, 'nodeCollection', pattern: RegExp(r'^(tables|views)$'));
_parameters['nodeCollection'] = __nodeCollection;
final __nodeId = _$jsonSerializers.serialize(nodeId, specifiedType: const FullType(int));
_parameters['nodeId'] = __nodeId;
final _path = _i5.UriTemplate('/ocs/v2.php/apps/tables/api/2/{nodeCollection}/{nodeId}/rows').expand(_parameters);
final _uri = Uri.parse('${_rootClient.baseURL}$_path');
final _request = _i3.Request('post', _uri);
_request.headers['Accept'] = 'application/json';
// coverage:ignore-start
final authentication = _i4.IterableExtension(_rootClient.authentications)?.firstWhereOrNull(
(auth) => switch (auth) {
_i1.DynamiteHttpBearerAuthentication() || _i1.DynamiteHttpBasicAuthentication() => true,
_ => false,
},
);
if (authentication != null) {
_request.headers.addAll(authentication.headers);
} else {
throw Exception('Missing authentication for bearer_auth or basic_auth');
}
// coverage:ignore-end
var __oCSAPIRequest = _$jsonSerializers.serialize(oCSAPIRequest, specifiedType: const FullType(bool));
__oCSAPIRequest ??= true;
_request.headers['OCS-APIRequest'] = const _i6.HeaderEncoder().convert(__oCSAPIRequest);
_request.headers['Content-Type'] = 'application/json';
_request.body = json.encode(
_$jsonSerializers.serialize($body, specifiedType: const FullType(RowocsCreateRowRequestApplicationJson)),
);
return _request;
}