$ViewInterface class sealed

Implementers
Annotations
  • @BuiltValue.new(instantiable: false)

Properties

columns → BuiltList<int>
no setter
columnSettings → BuiltList<View_ColumnSettings>
no setter
createdAt → String
no setter
createdBy → String
no setter
description → String?
no setter
emoji → String?
no setter
favorite → bool
no setter
filter → BuiltList<BuiltList<View_Filter>>
no setter
hashCode → int
The hash code for this object.
no setterinherited
hasShares → bool
no setter
id → int
no setter
isShared → bool
no setter
lastEditAt → String
no setter
lastEditBy → String
no setter
onSharePermissions → View_OnSharePermissions?
no setter
ownerDisplayName → String?
no setter
ownership → String
no setter
rowsCount → int
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sort → BuiltList<View_Sort>
no setter
tableId → int
no setter
title → String
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(void updates($ViewInterfaceBuilder)) → $ViewInterface
Rebuilds the instance.
toBuilder() → $ViewInterfaceBuilder
Converts the instance to a builder $ViewInterfaceBuilder.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited