rebuild abstract method

Rebuilds the instance.

The result is the same as this instance but with updates applied. updates is a function that takes a builder $View_ColumnSettingsInterfaceBuilder.

Implementation

$View_ColumnSettingsInterface rebuild(void Function($View_ColumnSettingsInterfaceBuilder) updates);