$View_FilterInterface class sealed

Implementers
Annotations
  • @BuiltValue.new(instantiable: false)

Properties

$operator → View_Filter_Operator
no setter
columnId → int
no setter
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
value → View_Filter_Value
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(void updates($View_FilterInterfaceBuilder)) → $View_FilterInterface
Rebuilds the instance.
toBuilder() → $View_FilterInterfaceBuilder
Converts the instance to a builder $View_FilterInterfaceBuilder.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited