Api1CreateRowInTableRequestApplicationJson class abstract

Implemented types

Constructors

Api1CreateRowInTableRequestApplicationJson([void b(Api1CreateRowInTableRequestApplicationJsonBuilder)?])
Creates a new Api1CreateRowInTableRequestApplicationJson object using the builder pattern.
factory
Api1CreateRowInTableRequestApplicationJson.fromJson(Map<String, dynamic> json)
Creates a new object from the given json data.
factory

Properties

data → Api1CreateRowInTableRequestApplicationJson_Data
Data as key - value store.
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(Api1CreateRowInTableRequestApplicationJsonBuilder)) → Api1CreateRowInTableRequestApplicationJson
Rebuilds the instance.
inherited
toBuilder() → Api1CreateRowInTableRequestApplicationJsonBuilder
Converts the instance to a builder B.
inherited
toJson() → Map<String, dynamic>
Parses this object into a json like map.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

serializer → Serializer<Api1CreateRowInTableRequestApplicationJson>
Serializer for Api1CreateRowInTableRequestApplicationJson.
no setter