ApiColumnsCreateTextColumnRequestApplicationJson class abstract

Implemented types

Constructors

ApiColumnsCreateTextColumnRequestApplicationJson([void b(ApiColumnsCreateTextColumnRequestApplicationJsonBuilder)?])
Creates a new ApiColumnsCreateTextColumnRequestApplicationJson object using the builder pattern.
factory
ApiColumnsCreateTextColumnRequestApplicationJson.fromJson(Map<String, dynamic> json)
Creates a new object from the given json data.
factory

Properties

baseNodeId → int
Context of the column creation.
no setterinherited
baseNodeType → ApiColumnsCreateTextColumnRequestApplicationJson_BaseNodeType
Context type of the column creation.
no setterinherited
description → String?
Description.
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
mandatory → bool
Is mandatory.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
selectedViewIds → BuiltList<int>?
View IDs where this columns should be added.
no setterinherited
subtype → ApiColumnsCreateTextColumnRequestApplicationJson_Subtype?
Subtype for the new column.
no setterinherited
textAllowedPattern → String?
Allowed regex pattern.
no setterinherited
textDefault → String?
Default.
no setterinherited
textMaxLength → int?
Max raw text length.
no setterinherited
title → String
Title.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(ApiColumnsCreateTextColumnRequestApplicationJsonBuilder)) → ApiColumnsCreateTextColumnRequestApplicationJson
Rebuilds the instance.
inherited
toBuilder() → ApiColumnsCreateTextColumnRequestApplicationJsonBuilder
Converts the instance to a builder B.
inherited
toJson() → Map<String, dynamic>
Parses this object into a json like map.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

serializer → Serializer<ApiColumnsCreateTextColumnRequestApplicationJson>
Serializer for ApiColumnsCreateTextColumnRequestApplicationJson.
no setter