Table class abstract

Implemented types

Constructors

Table([void b(TableBuilder)?])
Creates a new Table object using the builder pattern.
factory
Table.fromJson(Map<String, dynamic> json)
Creates a new object from the given json data.
factory

Properties

archived → bool
no setterinherited
columnsCount → int
no setterinherited
createdAt → String
no setterinherited
createdBy → String
no setterinherited
emoji → String?
no setterinherited
favorite → bool
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
hasShares → bool
no setterinherited
id → int
no setterinherited
isShared → bool
no setterinherited
lastEditAt → String
no setterinherited
lastEditBy → String
no setterinherited
onSharePermissions → Table_OnSharePermissions?
no setterinherited
ownerDisplayName → String
no setterinherited
ownership → String
no setterinherited
rowsCount → int
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
title → String
no setterinherited
views → BuiltList<View>
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(TableBuilder)) → Table
Rebuilds the instance.
inherited
toBuilder() → TableBuilder
Converts the instance to a builder B.
inherited
toJson() → Map<String, dynamic>
Parses this object into a json like map.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

serializer → Serializer<Table>
Serializer for Table.
no setter