View class abstract

Implemented types

Constructors

View([void b(ViewBuilder)?])
Creates a new View object using the builder pattern.
factory
View.fromJson(Map<String, dynamic> json)
Creates a new object from the given json data.
factory

Properties

columns → BuiltList<int>
no setterinherited
columnSettings → BuiltList<View_ColumnSettings>
no setterinherited
createdAt → String
no setterinherited
createdBy → String
no setterinherited
description → String?
no setterinherited
emoji → String?
no setterinherited
favorite → bool
no setterinherited
filter → BuiltList<BuiltList<View_Filter>>
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
hasShares → bool
no setterinherited
id → int
no setterinherited
isShared → bool
no setterinherited
lastEditAt → String
no setterinherited
lastEditBy → String
no setterinherited
onSharePermissions → View_OnSharePermissions?
no setterinherited
ownerDisplayName → String?
no setterinherited
ownership → String
no setterinherited
rowsCount → int
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sort → BuiltList<View_Sort>
no setterinherited
tableId → int
no setterinherited
title → String
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(ViewBuilder)) → View
Rebuilds the instance.
inherited
toBuilder() → ViewBuilder
Converts the instance to a builder B.
inherited
toJson() → Map<String, dynamic>
Parses this object into a json like map.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

serializer → Serializer<View>
Serializer for View.
no setter