View_ColumnSettings class abstract

Implemented types

Constructors

View_ColumnSettings([void b(View_ColumnSettingsBuilder)?])
Creates a new View_ColumnSettings object using the builder pattern.
factory
View_ColumnSettings.fromJson(Map<String, dynamic> json)
Creates a new object from the given json data.
factory

Properties

columnId int
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
order int
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(View_ColumnSettingsBuilder)) View_ColumnSettings
Rebuilds the instance.
inherited
toBuilder() View_ColumnSettingsBuilder
Converts the instance to a builder B.
inherited
toJson() Map<String, dynamic>
Parses this object into a json like map.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

serializer → Serializer<View_ColumnSettings>
Serializer for View_ColumnSettings.
no setter