$AdminFormDataInterface class sealed

Implementers
Annotations
  • @BuiltValue.new(instantiable: false)

Properties

countries → BuiltMap<String, String>
no setter
hashCode int
The hash code for this object.
no setterinherited
languages → BuiltMap<String, String>
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
terms → BuiltMap<String, Terms>
no setter
tosForUsers AdminFormData_TosForUsers
no setter
tosOnPublicShares AdminFormData_TosOnPublicShares
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(void updates($AdminFormDataInterfaceBuilder)) $AdminFormDataInterface
Rebuilds the instance.
toBuilder() $AdminFormDataInterfaceBuilder
Converts the instance to a builder $AdminFormDataInterfaceBuilder.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited