$PublicCapabilities_TermsOfServiceInterface class sealed

Implementers
Annotations
  • @BuiltValue.new(instantiable: false)

Properties

enabled PublicCapabilities_TermsOfService_Enabled
no setter
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
termUuid String
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(void updates($PublicCapabilities_TermsOfServiceInterfaceBuilder)) $PublicCapabilities_TermsOfServiceInterface
Rebuilds the instance.
toBuilder() $PublicCapabilities_TermsOfServiceInterfaceBuilder
Converts the instance to a builder $PublicCapabilities_TermsOfServiceInterfaceBuilder.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited