$signTermsPublic_Request method

  1. @experimental
Request $signTermsPublic_Request({
  1. required SigningSignTermsPublicRequestApplicationJson $body,
  2. bool? oCSAPIRequest,
})

As a guest sign the terms.

Returns a DynamiteRequest backing the signTermsPublic operation. Throws a DynamiteApiException if the API call does not return an expected status code.

Parameters:

  • oCSAPIRequest Required to be true for the API request to pass. Defaults to true.

Status codes:

  • 200: Signed successfully
  • 406: The user is already authenticated and therefore not allowed to sign the terms through this endpoint

See:

Implementation

@_i2.experimental
_i3.Request $signTermsPublic_Request({
  required SigningSignTermsPublicRequestApplicationJson $body,
  bool? oCSAPIRequest,
}) {
  const _path = '/ocs/v2.php/apps/terms_of_service/sign_public';
  final _uri = Uri.parse('${_rootClient.baseURL}$_path');
  final _request = _i3.Request('post', _uri);
  _request.headers['Accept'] = 'application/json';
  // coverage:ignore-start
  final authentication = _i4.IterableExtension(_rootClient.authentications)?.firstWhereOrNull(
    (auth) => switch (auth) {
      _i1.DynamiteHttpBearerAuthentication() || _i1.DynamiteHttpBasicAuthentication() => true,
      _ => false,
    },
  );

  if (authentication != null) {
    _request.headers.addAll(authentication.headers);
  }

  // coverage:ignore-end
  var __oCSAPIRequest = _$jsonSerializers.serialize(oCSAPIRequest, specifiedType: const FullType(bool));
  __oCSAPIRequest ??= true;
  _request.headers['OCS-APIRequest'] = const _i5.HeaderEncoder().convert(__oCSAPIRequest);

  _request.headers['Content-Type'] = 'application/json';
  _request.body = json.encode(
    _$jsonSerializers.serialize($body, specifiedType: const FullType(SigningSignTermsPublicRequestApplicationJson)),
  );
  return _request;
}