signTerms method

As a logged in user sign the terms.

Returns a Future containing a DynamiteResponse with the status code, deserialized body and headers. Throws a DynamiteApiException if the API call does not return an expected status code.

Parameters:

  • oCSAPIRequest Required to be true for the API request to pass. Defaults to true.

Status codes:

  • 200: Signed successfully

See:

Implementation

Future<_i1.DynamiteResponse<SigningSignTermsResponseApplicationJson, void>> signTerms({
  required SigningSignTermsRequestApplicationJson $body,
  bool? oCSAPIRequest,
}) async {
  final _request = $signTerms_Request(oCSAPIRequest: oCSAPIRequest, $body: $body);
  final _streamedResponse = await _rootClient.httpClient.send(_request);
  final _response = await _i3.Response.fromStream(_streamedResponse);

  final _serializer = $signTerms_Serializer();
  return _i1.ResponseConverter<SigningSignTermsResponseApplicationJson, void>(_serializer).convert(_response);
}