signTermsPublic method
Future<DynamiteResponse<SigningSignTermsPublicResponseApplicationJson, void> >
signTermsPublic({
- required SigningSignTermsPublicRequestApplicationJson $body,
- bool? oCSAPIRequest,
As a guest sign the terms.
Returns a Future containing a DynamiteResponse with the status code, deserialized body and headers.
Throws a DynamiteApiException if the API call does not return an expected status code.
Parameters:
oCSAPIRequestRequired to be true for the API request to pass. Defaults totrue.
Status codes:
- 200: Signed successfully
- 406: The user is already authenticated and therefore not allowed to sign the terms through this endpoint
See:
- $signTermsPublic_Request for the request send by this method.
- $signTermsPublic_Serializer for a converter to parse the
Responsefrom an executed request.
Implementation
Future<_i1.DynamiteResponse<SigningSignTermsPublicResponseApplicationJson, void>> signTermsPublic({
required SigningSignTermsPublicRequestApplicationJson $body,
bool? oCSAPIRequest,
}) async {
final _request = $signTermsPublic_Request(oCSAPIRequest: oCSAPIRequest, $body: $body);
final _streamedResponse = await _rootClient.httpClient.send(_request);
final _response = await _i3.Response.fromStream(_streamedResponse);
final _serializer = $signTermsPublic_Serializer();
return _i1.ResponseConverter<SigningSignTermsPublicResponseApplicationJson, void>(_serializer).convert(_response);
}