$TermsClient class

Constructors

$TermsClient($Client _rootClient)
Creates a new DynamiteClient for terms requests.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

$create_Request({required TermsCreateRequestApplicationJson $body, bool? oCSAPIRequest}) → Request
Create new terms.
$create_Serializer() → DynamiteSerializer<TermsCreateResponseApplicationJson, void>
Builds a serializer to parse the response of $create_Request.
$destroy_Request({required int id, bool? oCSAPIRequest}) → Request
Delete a given Term by id.
$destroy_Serializer() → DynamiteSerializer<TermsDestroyResponseApplicationJson, void>
Builds a serializer to parse the response of $destroy_Request.
$getAdminFormData_Request({bool? oCSAPIRequest}) → Request
Get the form data for the admin interface.
$getAdminFormData_Serializer() → DynamiteSerializer<TermsGetAdminFormDataResponseApplicationJson, void>
Builds a serializer to parse the response of $getAdminFormData_Request.
$index_Request({bool? oCSAPIRequest}) → Request
Get all available terms for the current country.
$index_Serializer() → DynamiteSerializer<TermsIndexResponseApplicationJson, void>
Builds a serializer to parse the response of $index_Request.
create({required TermsCreateRequestApplicationJson $body, bool? oCSAPIRequest}) Future<DynamiteResponse<TermsCreateResponseApplicationJson, void>>
Create new terms.
destroy({required int id, bool? oCSAPIRequest}) Future<DynamiteResponse<TermsDestroyResponseApplicationJson, void>>
Delete a given Term by id.
getAdminFormData({bool? oCSAPIRequest}) Future<DynamiteResponse<TermsGetAdminFormDataResponseApplicationJson, void>>
Get the form data for the admin interface.
index({bool? oCSAPIRequest}) Future<DynamiteResponse<TermsIndexResponseApplicationJson, void>>
Get all available terms for the current country.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited