create method
Future<DynamiteResponse<TermsCreateResponseApplicationJson, void> >
create({
- required TermsCreateRequestApplicationJson $body,
- bool? oCSAPIRequest,
Create new terms.
This endpoint requires admin access.
Returns a Future containing a DynamiteResponse with the status code, deserialized body and headers.
Throws a DynamiteApiException if the API call does not return an expected status code.
Parameters:
oCSAPIRequestRequired to be true for the API request to pass. Defaults totrue.
Status codes:
- 200: Created successfully
- 417: Country or language code was not a valid option
See:
- $create_Request for the request send by this method.
- $create_Serializer for a converter to parse the
Responsefrom an executed request.
Implementation
Future<_i1.DynamiteResponse<TermsCreateResponseApplicationJson, void>> create({
required TermsCreateRequestApplicationJson $body,
bool? oCSAPIRequest,
}) async {
final _request = $create_Request(oCSAPIRequest: oCSAPIRequest, $body: $body);
final _streamedResponse = await _rootClient.httpClient.send(_request);
final _response = await _i3.Response.fromStream(_streamedResponse);
final _serializer = $create_Serializer();
return _i1.ResponseConverter<TermsCreateResponseApplicationJson, void>(_serializer).convert(_response);
}