destroy method

Future<DynamiteResponse<TermsDestroyResponseApplicationJson, void>> destroy({
  1. required int id,
  2. bool? oCSAPIRequest,
})

Delete a given Term by id.

This endpoint requires admin access.

Returns a Future containing a DynamiteResponse with the status code, deserialized body and headers. Throws a DynamiteApiException if the API call does not return an expected status code.

Parameters:

  • id The terms which should be deleted.
  • oCSAPIRequest Required to be true for the API request to pass. Defaults to true.

Status codes:

  • 200: Deleted successfully

See:

Implementation

Future<_i1.DynamiteResponse<TermsDestroyResponseApplicationJson, void>> destroy({
  required int id,
  bool? oCSAPIRequest,
}) async {
  final _request = $destroy_Request(id: id, oCSAPIRequest: oCSAPIRequest);
  final _streamedResponse = await _rootClient.httpClient.send(_request);
  final _response = await _i3.Response.fromStream(_streamedResponse);

  final _serializer = $destroy_Serializer();
  return _i1.ResponseConverter<TermsDestroyResponseApplicationJson, void>(_serializer).convert(_response);
}