getAdminFormData method

Future<DynamiteResponse<TermsGetAdminFormDataResponseApplicationJson, void>> getAdminFormData({
  1. bool? oCSAPIRequest,
})

Get the form data for the admin interface.

This endpoint requires admin access.

Returns a Future containing a DynamiteResponse with the status code, deserialized body and headers. Throws a DynamiteApiException if the API call does not return an expected status code.

Parameters:

  • oCSAPIRequest Required to be true for the API request to pass. Defaults to true.

Status codes:

  • 200: Get form data successfully

See:

Implementation

Future<_i1.DynamiteResponse<TermsGetAdminFormDataResponseApplicationJson, void>> getAdminFormData({
  bool? oCSAPIRequest,
}) async {
  final _request = $getAdminFormData_Request(oCSAPIRequest: oCSAPIRequest);
  final _streamedResponse = await _rootClient.httpClient.send(_request);
  final _response = await _i3.Response.fromStream(_streamedResponse);

  final _serializer = $getAdminFormData_Serializer();
  return _i1.ResponseConverter<TermsGetAdminFormDataResponseApplicationJson, void>(_serializer).convert(_response);
}