body property
String
get
body
The actual terms and conditions text (can be markdown, using headers, basic text formating, lists and links).
Implementation
String get body;
The actual terms and conditions text (can be markdown, using headers, basic text formating, lists and links).
String get body;