rebuild abstract method

Rebuilds the instance.

The result is the same as this instance but with updates applied. updates is a function that takes a builder $TermsGetAdminFormDataResponseApplicationJson_OcsInterfaceBuilder.

Implementation

$TermsGetAdminFormDataResponseApplicationJson_OcsInterface rebuild(
  void Function($TermsGetAdminFormDataResponseApplicationJson_OcsInterfaceBuilder) updates,
);