rebuild abstract method
Rebuilds the instance.
The result is the same as this instance but with updates applied.
updates is a function that takes a builder $TermsIndexResponseApplicationJson_OcsInterfaceBuilder.
Implementation
$TermsIndexResponseApplicationJson_OcsInterface rebuild(
void Function($TermsIndexResponseApplicationJson_OcsInterfaceBuilder) updates,
);