$TermsInterface class sealed

Implementers
Annotations
  • @BuiltValue.new(instantiable: false)

Properties

body String
no setter
countryCode String
no setter
hashCode int
The hash code for this object.
no setterinherited
id int
no setter
languageCode String
no setter
renderedBody String
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(void updates($TermsInterfaceBuilder)) $TermsInterface
Rebuilds the instance.
toBuilder() $TermsInterfaceBuilder
Converts the instance to a builder $TermsInterfaceBuilder.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited