AdminFormData class abstract

Implemented types

Constructors

AdminFormData([void b(AdminFormDataBuilder)?])
Creates a new AdminFormData object using the builder pattern.
factory
AdminFormData.fromJson(Map<String, dynamic> json)
Creates a new object from the given json data.
factory

Properties

countries → BuiltMap<String, String>
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
languages → BuiltMap<String, String>
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
terms → BuiltMap<String, Terms>
no setterinherited
tosForUsers AdminFormData_TosForUsers
no setterinherited
tosOnPublicShares AdminFormData_TosOnPublicShares
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(AdminFormDataBuilder)) AdminFormData
Rebuilds the instance.
inherited
toBuilder() AdminFormDataBuilder
Converts the instance to a builder B.
inherited
toJson() Map<String, dynamic>
Parses this object into a json like map.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

serializer → Serializer<AdminFormData>
Serializer for AdminFormData.
no setter