PublicCapabilities_TermsOfServiceBuilder class

Implemented types

Properties

enabled PublicCapabilities_TermsOfService_Enabled?
covariantgetter/setter pairoverride
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
termUuid String?
covariantgetter/setter pairoverride

Methods

build() PublicCapabilities_TermsOfService
Builds.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
replace(covariant PublicCapabilities_TermsOfService other) → void
Replaces the value in the builder with a new one.
override
toString() String
A string representation of this object.
inherited
update(void updates(PublicCapabilities_TermsOfServiceBuilder)?) → void
Applies updates.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited