Terms class abstract

Implemented types

Constructors

Terms([void b(TermsBuilder)?])
Creates a new Terms object using the builder pattern.
factory
Terms.fromJson(Map<String, dynamic> json)
Creates a new object from the given json data.
factory

Properties

body String
no setterinherited
countryCode String
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
id int
no setterinherited
languageCode String
no setterinherited
renderedBody String
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(TermsBuilder)) Terms
Rebuilds the instance.
inherited
toBuilder() TermsBuilder
Converts the instance to a builder B.
inherited
toJson() Map<String, dynamic>
Parses this object into a json like map.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

serializer → Serializer<Terms>
Serializer for Terms.
no setter