TermsCreateRequestApplicationJson class abstract

Implemented types

Constructors

TermsCreateRequestApplicationJson([void b(TermsCreateRequestApplicationJsonBuilder)?])
Creates a new TermsCreateRequestApplicationJson object using the builder pattern.
factory
TermsCreateRequestApplicationJson.fromJson(Map<String, dynamic> json)
Creates a new object from the given json data.
factory

Properties

body String
The actual terms and conditions text (can be markdown, using headers, basic text formating, lists and links).
no setterinherited
countryCode String
One of the 2-letter region codes or -- for "global".
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
languageCode String
One of the 2-letter language codes.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(TermsCreateRequestApplicationJsonBuilder)) TermsCreateRequestApplicationJson
Rebuilds the instance.
inherited
toBuilder() TermsCreateRequestApplicationJsonBuilder
Converts the instance to a builder B.
inherited
toJson() Map<String, dynamic>
Parses this object into a json like map.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

serializer → Serializer<TermsCreateRequestApplicationJson>
Serializer for TermsCreateRequestApplicationJson.
no setter