TermsCreateResponseApplicationJson_Ocs class abstract

Implemented types

Constructors

TermsCreateResponseApplicationJson_Ocs([void b(TermsCreateResponseApplicationJson_OcsBuilder)?])
Creates a new TermsCreateResponseApplicationJson_Ocs object using the builder pattern.
factory
TermsCreateResponseApplicationJson_Ocs.fromJson(Map<String, dynamic> json)
Creates a new object from the given json data.
factory

Properties

data Terms
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
meta OCSMeta
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(TermsCreateResponseApplicationJson_OcsBuilder)) TermsCreateResponseApplicationJson_Ocs
Rebuilds the instance.
inherited
toBuilder() TermsCreateResponseApplicationJson_OcsBuilder
Converts the instance to a builder B.
inherited
toJson() Map<String, dynamic>
Parses this object into a json like map.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

serializer → Serializer<TermsCreateResponseApplicationJson_Ocs>
Serializer for TermsCreateResponseApplicationJson_Ocs.
no setter