$BackgroundInterface class sealed
- Implementers
- Annotations
-
- @BuiltValue.new(instantiable: false)
Properties
- backgroundColor → String
-
no setter
- backgroundImage → String?
-
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- primaryColor → String
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- version → int
-
no setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
rebuild(
void updates($BackgroundInterfaceBuilder)) → $BackgroundInterface - Rebuilds the instance.
-
toBuilder(
) → $BackgroundInterfaceBuilder - Converts the instance to a builder $BackgroundInterfaceBuilder.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited