$PublicCapabilities_ThemingInterfaceBuilder class abstract mixin

Implementers

Properties

background ↔ String?
getter/setter pair
backgroundDefault ↔ bool?
getter/setter pair
backgroundPlain ↔ bool?
getter/setter pair
backgroundText ↔ String?
getter/setter pair
color ↔ String?
getter/setter pair
colorElement ↔ String?
getter/setter pair
colorElementBright ↔ String?
getter/setter pair
colorElementDark ↔ String?
getter/setter pair
colorText ↔ String?
getter/setter pair
favicon ↔ String?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
getter/setter pair
logoheader ↔ String?
getter/setter pair
name ↔ String?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
slogan ↔ String?
getter/setter pair
url ↔ String?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
replace($PublicCapabilities_ThemingInterface other) → void
toString() → String
A string representation of this object.
inherited
update(void updates($PublicCapabilities_ThemingInterfaceBuilder)) → void

Operators

operator ==(Object other) → bool
The equality operator.
inherited