$ThemingGetManifestResponseApplicationJsonInterface class sealed

Implementers
Annotations
  • @BuiltValue.new(instantiable: false)

Properties

backgroundColor → String
no setter
description → String
no setter
display → String
no setter
hashCode → int
The hash code for this object.
no setterinherited
icons → BuiltList<ThemingGetManifestResponseApplicationJson_Icons>
no setter
name → String
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
shortName → String
no setter
startUrl → String
no setter
themeColor → String
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(void updates($ThemingGetManifestResponseApplicationJsonInterfaceBuilder)) → $ThemingGetManifestResponseApplicationJsonInterface
Rebuilds the instance.
toBuilder() → $ThemingGetManifestResponseApplicationJsonInterfaceBuilder
Converts the instance to a builder $ThemingGetManifestResponseApplicationJsonInterfaceBuilder.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited