$deleteBackground_Request method
Delete the background.
Returns a DynamiteRequest backing the deleteBackground operation.
Throws a DynamiteApiException if the API call does not return an expected status code.
Parameters:
oCSAPIRequestRequired to be true for the API request to pass. Defaults totrue.
Status codes:
- 200: Background deleted successfully
See:
- deleteBackground for a method executing this request and parsing the response.
- $deleteBackground_Serializer for a converter to parse the
Responsefrom an executed this request.
Implementation
@_i2.experimental
_i3.Request $deleteBackground_Request({bool? oCSAPIRequest}) {
const _path = '/index.php/apps/theming/background/custom';
final _uri = Uri.parse('${_rootClient.baseURL}$_path');
final _request = _i3.Request('delete', _uri);
_request.headers['Accept'] = 'application/json';
// coverage:ignore-start
final authentication = _i5.IterableExtension(_rootClient.authentications)?.firstWhereOrNull(
(auth) => switch (auth) {
_i1.DynamiteHttpBearerAuthentication() || _i1.DynamiteHttpBasicAuthentication() => true,
_ => false,
},
);
if (authentication != null) {
_request.headers.addAll(authentication.headers);
} else {
throw Exception('Missing authentication for bearer_auth or basic_auth');
}
// coverage:ignore-end
var __oCSAPIRequest = _$jsonSerializers.serialize(oCSAPIRequest, specifiedType: const FullType(bool));
__oCSAPIRequest ??= true;
_request.headers['OCS-APIRequest'] = const _i6.HeaderEncoder().convert(__oCSAPIRequest);
return _request;
}