$setBackground_Request method
- @experimental
- required String type,
- bool? oCSAPIRequest,
- UserThemeSetBackgroundRequestApplicationJson? $body,
Set the background.
Returns a DynamiteRequest backing the setBackground operation.
Throws a DynamiteApiException if the API call does not return an expected status code.
Parameters:
typeType of background.oCSAPIRequestRequired to be true for the API request to pass. Defaults totrue.
Status codes:
- 200: Background set successfully
- 400: Setting background is not possible
- 500
See:
- setBackground for a method executing this request and parsing the response.
- $setBackground_Serializer for a converter to parse the
Responsefrom an executed this request.
Implementation
@_i2.experimental
_i3.Request $setBackground_Request({
required String type,
bool? oCSAPIRequest,
UserThemeSetBackgroundRequestApplicationJson? $body,
}) {
final _parameters = <String, Object?>{};
final __type = _$jsonSerializers.serialize(type, specifiedType: const FullType(String));
_parameters['type'] = __type;
final _path = _i4.UriTemplate('/index.php/apps/theming/background/{type}').expand(_parameters);
final _uri = Uri.parse('${_rootClient.baseURL}$_path');
final _request = _i3.Request('post', _uri);
_request.headers['Accept'] = 'application/json';
// coverage:ignore-start
final authentication = _i5.IterableExtension(_rootClient.authentications)?.firstWhereOrNull(
(auth) => switch (auth) {
_i1.DynamiteHttpBearerAuthentication() || _i1.DynamiteHttpBasicAuthentication() => true,
_ => false,
},
);
if (authentication != null) {
_request.headers.addAll(authentication.headers);
} else {
throw Exception('Missing authentication for bearer_auth or basic_auth');
}
// coverage:ignore-end
var __oCSAPIRequest = _$jsonSerializers.serialize(oCSAPIRequest, specifiedType: const FullType(bool));
__oCSAPIRequest ??= true;
_request.headers['OCS-APIRequest'] = const _i6.HeaderEncoder().convert(__oCSAPIRequest);
_request.headers['Content-Type'] = 'application/json';
_request.body = $body != null
? json.encode(
_$jsonSerializers.serialize(
$body,
specifiedType: const FullType(UserThemeSetBackgroundRequestApplicationJson),
),
)
: json.encode(
_$jsonSerializers.serialize(
UserThemeSetBackgroundRequestApplicationJson(),
specifiedType: const FullType(UserThemeSetBackgroundRequestApplicationJson),
),
);
return _request;
}