deleteBackground method

Future<DynamiteResponse<Background, void>> deleteBackground({
  1. bool? oCSAPIRequest,
})

Delete the background.

Returns a Future containing a DynamiteResponse with the status code, deserialized body and headers. Throws a DynamiteApiException if the API call does not return an expected status code.

Parameters:

  • oCSAPIRequest Required to be true for the API request to pass. Defaults to true.

Status codes:

  • 200: Background deleted successfully

See:

Implementation

Future<_i1.DynamiteResponse<Background, void>> deleteBackground({bool? oCSAPIRequest}) async {
  final _request = $deleteBackground_Request(oCSAPIRequest: oCSAPIRequest);
  final _streamedResponse = await _rootClient.httpClient.send(_request);
  final _response = await _i3.Response.fromStream(_streamedResponse);

  final _serializer = $deleteBackground_Serializer();
  return _i1.ResponseConverter<Background, void>(_serializer).convert(_response);
}