setBackground method

Future<DynamiteResponse<Background, void>> setBackground({
  1. required String type,
  2. bool? oCSAPIRequest,
  3. UserThemeSetBackgroundRequestApplicationJson? $body,
})

Set the background.

Returns a Future containing a DynamiteResponse with the status code, deserialized body and headers. Throws a DynamiteApiException if the API call does not return an expected status code.

Parameters:

  • type Type of background.
  • oCSAPIRequest Required to be true for the API request to pass. Defaults to true.

Status codes:

  • 200: Background set successfully
  • 400: Setting background is not possible
  • 500

See:

Implementation

Future<_i1.DynamiteResponse<Background, void>> setBackground({
  required String type,
  bool? oCSAPIRequest,
  UserThemeSetBackgroundRequestApplicationJson? $body,
}) async {
  final _request = $setBackground_Request(type: type, oCSAPIRequest: oCSAPIRequest, $body: $body);
  final _streamedResponse = await _rootClient.httpClient.send(_request);
  final _response = await _i3.Response.fromStream(_streamedResponse);

  final _serializer = $setBackground_Serializer();
  return _i1.ResponseConverter<Background, void>(_serializer).convert(_response);
}