$UserThemeSetBackgroundRequestApplicationJsonInterface class sealed

Implementers
Annotations
  • @BuiltValue.new(instantiable: false)

Properties

color String?
Color for the background.
no setter
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
Path of the background image.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(void updates($UserThemeSetBackgroundRequestApplicationJsonInterfaceBuilder)) $UserThemeSetBackgroundRequestApplicationJsonInterface
Rebuilds the instance.
toBuilder() $UserThemeSetBackgroundRequestApplicationJsonInterfaceBuilder
Converts the instance to a builder $UserThemeSetBackgroundRequestApplicationJsonInterfaceBuilder.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited