Background constructor
Background([
- void b()?
Creates a new Background object using the builder pattern.
Implementation
factory Background([void Function(BackgroundBuilder)? b]) = _$Background;
Creates a new Background object using the builder pattern.
factory Background([void Function(BackgroundBuilder)? b]) = _$Background;