PublicCapabilities_Theming class abstract

Implemented types

Constructors

PublicCapabilities_Theming([void b(PublicCapabilities_ThemingBuilder)?])
Creates a new PublicCapabilities_Theming object using the builder pattern.
factory
PublicCapabilities_Theming.fromJson(Map<String, dynamic> json)
Creates a new object from the given json data.
factory

Properties

background → String
no setterinherited
backgroundDefault → bool
no setterinherited
backgroundPlain → bool
no setterinherited
backgroundText → String
no setterinherited
color → String
no setterinherited
colorElement → String
no setterinherited
colorElementBright → String
no setterinherited
colorElementDark → String
no setterinherited
colorText → String
no setterinherited
favicon → String
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
no setterinherited
logoheader → String
no setterinherited
name → String
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
slogan → String
no setterinherited
url → String
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(PublicCapabilities_ThemingBuilder)) → PublicCapabilities_Theming
Rebuilds the instance.
inherited
toBuilder() → PublicCapabilities_ThemingBuilder
Converts the instance to a builder B.
inherited
toJson() → Map<String, dynamic>
Parses this object into a json like map.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

serializer → Serializer<PublicCapabilities_Theming>
Serializer for PublicCapabilities_Theming.
no setter