UserThemeSetBackgroundRequestApplicationJson class abstract

Implemented types

Constructors

UserThemeSetBackgroundRequestApplicationJson([void b(UserThemeSetBackgroundRequestApplicationJsonBuilder)?])
Creates a new UserThemeSetBackgroundRequestApplicationJson object using the builder pattern.
factory
UserThemeSetBackgroundRequestApplicationJson.fromJson(Map<String, dynamic> json)
Creates a new object from the given json data.
factory

Properties

color String?
Color for the background.
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
Path of the background image.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(UserThemeSetBackgroundRequestApplicationJsonBuilder)) UserThemeSetBackgroundRequestApplicationJson
Rebuilds the instance.
inherited
toBuilder() UserThemeSetBackgroundRequestApplicationJsonBuilder
Converts the instance to a builder B.
inherited
toJson() Map<String, dynamic>
Parses this object into a json like map.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

serializer → Serializer<UserThemeSetBackgroundRequestApplicationJson>
Serializer for UserThemeSetBackgroundRequestApplicationJson.
no setter