$getAppChangelogEntry_Request method
- @experimental
- required String appId,
- ApiGetAppChangelogEntryApiVersion? apiVersion,
- String? version,
- bool? oCSAPIRequest,
Get changelog entry for an app.
This endpoint requires admin access.
Returns a DynamiteRequest backing the getAppChangelogEntry operation.
Throws a DynamiteApiException if the API call does not return an expected status code.
Parameters:
apiVersionDefaults to"v1".appIdApp to search changelog entry for.versionThe version to search the changelog entry for (defaults to the latest installed).oCSAPIRequestRequired to be true for the API request to pass. Defaults totrue.
Status codes:
- 200: Changelog entry returned
- 404: No changelog found
- 400: The
versionparameter is not a valid version format
See:
- getAppChangelogEntry for a method executing this request and parsing the response.
- $getAppChangelogEntry_Serializer for a converter to parse the
Responsefrom an executed this request.
Implementation
@_i2.experimental
_i3.Request $getAppChangelogEntry_Request({
required String appId,
ApiGetAppChangelogEntryApiVersion? apiVersion,
String? version,
bool? oCSAPIRequest,
}) {
final _parameters = <String, Object?>{};
final __appId = _$jsonSerializers.serialize(appId, specifiedType: const FullType(String));
_parameters['appId'] = __appId;
var __apiVersion = _$jsonSerializers.serialize(
apiVersion,
specifiedType: const FullType(ApiGetAppChangelogEntryApiVersion),
);
__apiVersion ??= 'v1';
_parameters['apiVersion'] = __apiVersion;
final __version = _$jsonSerializers.serialize(version, specifiedType: const FullType(String));
_parameters['version'] = __version;
final _path = _i4.UriTemplate(
'/ocs/v2.php/apps/updatenotification/api/{apiVersion}/changelog/{appId}{?version*}',
).expand(_parameters);
final _uri = Uri.parse('${_rootClient.baseURL}$_path');
final _request = _i3.Request('get', _uri);
_request.headers['Accept'] = 'application/json';
// coverage:ignore-start
final authentication = _i5.IterableExtension(_rootClient.authentications)?.firstWhereOrNull(
(auth) => switch (auth) {
_i1.DynamiteHttpBearerAuthentication() || _i1.DynamiteHttpBasicAuthentication() => true,
_ => false,
},
);
if (authentication != null) {
_request.headers.addAll(authentication.headers);
} else {
throw Exception('Missing authentication for bearer_auth or basic_auth');
}
// coverage:ignore-end
var __oCSAPIRequest = _$jsonSerializers.serialize(oCSAPIRequest, specifiedType: const FullType(bool));
__oCSAPIRequest ??= true;
_request.headers['OCS-APIRequest'] = const _i6.HeaderEncoder().convert(__oCSAPIRequest);
return _request;
}