getAppListRaw method
- @experimental
- required String newVersion,
- ApiGetAppListApiVersion? apiVersion,
- bool? oCSAPIRequest,
List available updates for apps.
This endpoint requires admin access.
This method and the response it returns is experimental. The API might change without a major version bump.
Returns a Future containing a DynamiteRawResponse with the raw HttpClientResponse and serialization helpers.
Throws a DynamiteApiException if the API call does not return an expected status code.
Parameters:
apiVersionDefaults tov1.newVersionServer version to check updates for.oCSAPIRequestRequired to be true for the API request to pass. Defaults totrue.
Status codes:
- 200: Apps returned
- 404: New versions not found
See:
- getAppList for an operation that returns a
DynamiteResponsewith a stable API.
Implementation
@_i4.experimental
_i1.DynamiteRawResponse<ApiGetAppListResponseApplicationJson, void> getAppListRaw({
required String newVersion,
ApiGetAppListApiVersion? apiVersion,
bool? oCSAPIRequest,
}) {
final _parameters = <String, dynamic>{};
final _headers = <String, String>{'Accept': 'application/json'};
// coverage:ignore-start
final authentication = _rootClient.authentications?.firstWhereOrNull(
(auth) => switch (auth) {
_i1.DynamiteHttpBearerAuthentication() || _i1.DynamiteHttpBasicAuthentication() => true,
_ => false,
},
);
if (authentication != null) {
_headers.addAll(
authentication.headers,
);
} else {
throw Exception('Missing authentication for bearer_auth or basic_auth');
}
// coverage:ignore-end
final $newVersion = _$jsonSerializers.serialize(newVersion, specifiedType: const FullType(String));
_parameters['newVersion'] = $newVersion;
var $apiVersion = _$jsonSerializers.serialize(apiVersion, specifiedType: const FullType(ApiGetAppListApiVersion));
$apiVersion ??= 'v1';
_parameters['apiVersion'] = $apiVersion;
var $oCSAPIRequest = _$jsonSerializers.serialize(oCSAPIRequest, specifiedType: const FullType(bool));
$oCSAPIRequest ??= true;
_headers['OCS-APIRequest'] = const _i2.HeaderEncoder().convert($oCSAPIRequest);
final _path = _i3.UriTemplate('/ocs/v2.php/apps/updatenotification/api/{apiVersion}/applist/{newVersion}')
.expand(_parameters);
return _i1.DynamiteRawResponse<ApiGetAppListResponseApplicationJson, void>(
response: _rootClient.executeRequest(
'get',
_path,
headers: _headers,
validStatuses: const {200},
),
bodyType: const FullType(ApiGetAppListResponseApplicationJson),
headersType: null,
serializers: _$jsonSerializers,
);
}