setLocationRaw method
- @experimental
Set address and resolve it to get coordinates or directly set coordinates and get address with reverse geocoding.
This method and the response it returns is experimental. The API might change without a major version bump.
Returns a Future containing a DynamiteRawResponse with the raw HttpClientResponse and serialization helpers.
Throws a DynamiteApiException if the API call does not return an expected status code.
Parameters:
addressAny approximative or exact address.latLatitude in decimal degree format.lonLongitude in decimal degree format.oCSAPIRequestRequired to be true for the API request to pass. Defaults totrue.
Status codes:
- 200: Location updated
See:
- setLocation for an operation that returns a
DynamiteResponsewith a stable API.
Implementation
@_i4.experimental
_i1.DynamiteRawResponse<WeatherStatusSetLocationResponseApplicationJson, void> setLocationRaw({
String? address,
double? lat,
double? lon,
bool? oCSAPIRequest,
}) {
final _parameters = <String, dynamic>{};
final _headers = <String, String>{'Accept': 'application/json'};
// coverage:ignore-start
final authentication = _rootClient.authentications?.firstWhereOrNull(
(auth) => switch (auth) {
_i1.DynamiteHttpBearerAuthentication() || _i1.DynamiteHttpBasicAuthentication() => true,
_ => false,
},
);
if (authentication != null) {
_headers.addAll(
authentication.headers,
);
} else {
throw Exception('Missing authentication for bearer_auth or basic_auth');
}
// coverage:ignore-end
final $address = _$jsonSerializers.serialize(address, specifiedType: const FullType(String));
_parameters['address'] = $address;
final $lat = _$jsonSerializers.serialize(lat, specifiedType: const FullType(double));
_parameters['lat'] = $lat;
final $lon = _$jsonSerializers.serialize(lon, specifiedType: const FullType(double));
_parameters['lon'] = $lon;
var $oCSAPIRequest = _$jsonSerializers.serialize(oCSAPIRequest, specifiedType: const FullType(bool));
$oCSAPIRequest ??= true;
_headers['OCS-APIRequest'] = const _i2.HeaderEncoder().convert($oCSAPIRequest);
final _path =
_i3.UriTemplate('/ocs/v2.php/apps/weather_status/api/v1/location{?address*,lat*,lon*}').expand(_parameters);
return _i1.DynamiteRawResponse<WeatherStatusSetLocationResponseApplicationJson, void>(
response: _rootClient.executeRequest(
'put',
_path,
headers: _headers,
validStatuses: const {200},
),
bodyType: const FullType(WeatherStatusSetLocationResponseApplicationJson),
headersType: null,
serializers: _$jsonSerializers,
);
}