LocationWithMode class abstract

Implemented types

Constructors

LocationWithMode([void b(LocationWithModeBuilder)?])
Creates a new LocationWithMode object using the builder pattern.
factory
LocationWithMode.fromJson(Map<String, dynamic> json)
Creates a new object from the given json data.
factory

Properties

address → String?
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
lat → String?
no setterinherited
lon → String?
no setterinherited
mode → int
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(LocationWithModeBuilder)) → LocationWithMode
Rebuilds the instance.
inherited
toBuilder() → LocationWithModeBuilder
Converts the instance to a builder B.
inherited
toJson() → Map<String, dynamic>
Parses this object into a json like map.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

serializer → Serializer<LocationWithMode>
Serializer for LocationWithMode.
no setter