WebDavDepth enum

Depth used for propfind requests.

See http://www.webdav.org/specs/rfc2518.html#HEADER_Depth for more information.

Inheritance
Available extensions

Values

zero → const WebDavDepth

Returns props of the resource.

const WebDavDepth('0')
one → const WebDavDepth

Returns props of the resource and its immediate children.

Only works on collections and returns the same as WebDavDepth.zero for other resources.

const WebDavDepth('1')
infinity → const WebDavDepth

Returns props of the resource and all its progeny.

Only works on collections and returns the same as WebDavDepth.zero for other resources.

const WebDavDepth('infinity')

Properties

binary → int

Available on Enum, provided by the EnumBinary extension

Gets the binary representation of the index.
no setter
hashCode → int
The hash code for this object.
no setterinherited
index → int
A numeric identifier for the enumerated value.
no setterinherited
name → String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
value → String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

values → const List<WebDavDepth>
A constant List of the values in this enum, in order of their declaration.