WebDavFile class

WebDavFile class

Constructors

WebDavFile({required WebDavResponse response})
Creates a new WebDavFile object with the given path

Properties

blurHash → String?
The compact representation of an image preview.
latefinal
createdDate → TZDateTime?
Creation date of the file as provided by uploader
latefinal
etag → String?
ETag of the file
latefinal
favorite → bool?
Whether this file is marked as favorite
latefinal
fileId → int?
The unique id for the file within the instance
latefinal
hashCode → int
The hash code for this object.
no setterinherited
hasPreview → bool?
Whether this file has a preview image
latefinal
id → String?
The fileid namespaced by the instance id, globally unique
latefinal
isCollection → bool?
Whether this is a collection resource type
latefinal
isDirectory → bool
Whether the file is a directory
latefinal
isHidden → bool
Whether the file is hidden.
latefinal
lastModified → TZDateTime?
Last modified date of the file.
latefinal
mimeType → String?
Mime-type of the file
latefinal
name → String
Returns the decoded name of the file / folder without the whole path
latefinal
note → String?
Share note
latefinal
ownerDisplay → String?
The display name of the owner of a shared file
latefinal
ownerId → String?
The user id of the owner of a shared file
latefinal
path → PathUri
The path of file
latefinal
props → WebDavProp
Get the props of the file
latefinal
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
size → int?
File content length or folder size
latefinal
uploadedDate → TZDateTime?
Upload date of the file
latefinal

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited