$WebhooksUpdateRequestApplicationJsonInterface class sealed

Implementers
Annotations
  • @BuiltValue.new(instantiable: false)

Properties

authData → BuiltMap<String, JsonObject>?
Array of data for authentication.
no setter
authMethod → WebhooksUpdateRequestApplicationJson_AuthMethod?
Authentication method to use.
no setter
event → String
Event class name to listen to.
no setter
eventFilter → BuiltMap<String, JsonObject>?
Mongo filter to apply to the serialized data to decide if firing.
no setter
hashCode → int
The hash code for this object.
no setterinherited
headers → BuiltMap<String, String>?
Array of headers to send.
no setter
httpMethod → String
HTTP method to use to contact the webhook.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
uri → String
Webhook URI endpoint.
no setter
userIdFilter → String?
User id to filter on. The webhook will only be called by requests from this user. Empty or null means no filtering.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(void updates($WebhooksUpdateRequestApplicationJsonInterfaceBuilder)) → $WebhooksUpdateRequestApplicationJsonInterface
Rebuilds the instance.
toBuilder() → $WebhooksUpdateRequestApplicationJsonInterfaceBuilder
Converts the instance to a builder $WebhooksUpdateRequestApplicationJsonInterfaceBuilder.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited