WebhooksUpdateRequestApplicationJson class abstract

Implemented types

Constructors

WebhooksUpdateRequestApplicationJson([void b(WebhooksUpdateRequestApplicationJsonBuilder)?])
Creates a new WebhooksUpdateRequestApplicationJson object using the builder pattern.
factory
WebhooksUpdateRequestApplicationJson.fromJson(Map<String, dynamic> json)
Creates a new object from the given json data.
factory

Properties

authData → BuiltMap<String, JsonObject>?
Array of data for authentication.
no setterinherited
authMethod → WebhooksUpdateRequestApplicationJson_AuthMethod?
Authentication method to use.
no setterinherited
event → String
Event class name to listen to.
no setterinherited
eventFilter → BuiltMap<String, JsonObject>?
Mongo filter to apply to the serialized data to decide if firing.
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
headers → BuiltMap<String, String>?
Array of headers to send.
no setterinherited
httpMethod → String
HTTP method to use to contact the webhook.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
uri → String
Webhook URI endpoint.
no setterinherited
userIdFilter → String?
User id to filter on. The webhook will only be called by requests from this user. Empty or null means no filtering.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(WebhooksUpdateRequestApplicationJsonBuilder)) → WebhooksUpdateRequestApplicationJson
Rebuilds the instance.
inherited
toBuilder() → WebhooksUpdateRequestApplicationJsonBuilder
Converts the instance to a builder B.
inherited
toJson() → Map<String, dynamic>
Parses this object into a json like map.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

serializer → Serializer<WebhooksUpdateRequestApplicationJson>
Serializer for WebhooksUpdateRequestApplicationJson.
no setter