getProfileFields method
Future<DynamiteResponse<ProfileApiGetProfileFieldsResponseApplicationJson, void> >
getProfileFields({})
Get profile fields for another user.
Returns a Future containing a DynamiteResponse with the status code, deserialized body and headers.
Throws a DynamiteApiException if the API call does not return an expected status code.
Parameters:
targetUserIdID of the user.oCSAPIRequestRequired to be true for the API request to pass. Defaults totrue.
Status codes:
- 200: Profile data returned successfully
- 400: Profile is disabled
- 404: Account not found or disabled
See:
- $getProfileFields_Request for the request send by this method.
- $getProfileFields_Serializer for a converter to parse the
Responsefrom an executed request.
Implementation
Future<_i1.DynamiteResponse<ProfileApiGetProfileFieldsResponseApplicationJson, void>> getProfileFields({
required String targetUserId,
bool? oCSAPIRequest,
}) async {
final _request = $getProfileFields_Request(targetUserId: targetUserId, oCSAPIRequest: oCSAPIRequest);
final _streamedResponse = await _rootClient.httpClient.send(_request);
final _response = await _i3.Response.fromStream(_streamedResponse);
final _serializer = $getProfileFields_Serializer();
return _i1.ResponseConverter<ProfileApiGetProfileFieldsResponseApplicationJson, void>(
_serializer,
).convert(_response);
}