rebuild abstract method
Rebuilds the instance.
The result is the same as this instance but with updates applied.
updates is a function that takes a builder $ProfileDataInterfaceBuilder.
Implementation
@override
$ProfileDataInterface rebuild(void Function($ProfileDataInterfaceBuilder) updates);