$ProfileFieldsInterfaceBuilder class abstract mixin

Implementers

Properties

actions ↔ ListBuilder<ProfileAction>
getter/setter pair
address String?
getter/setter pair
biography String?
getter/setter pair
displayname String?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
headline String?
getter/setter pair
isUserAvatarVisible bool?
getter/setter pair
organisation String?
getter/setter pair
pronouns String?
getter/setter pair
role String?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
userId String?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
replace($ProfileFieldsInterface other) → void
toString() String
A string representation of this object.
inherited
update(void updates($ProfileFieldsInterfaceBuilder)) → void

Operators

operator ==(Object other) bool
The equality operator.
inherited