extract method
Extract references from a text.
Returns a Future containing a DynamiteResponse with the status code, deserialized body and headers. Throws a DynamiteApiException if the API call does not return an expected status code.
Parameters:
textText to extract from.resolveResolve the references. Defaults to0.limitMaximum amount of references to extract. Defaults to1.oCSAPIRequestRequired to be true for the API request to pass. Defaults totrue.
Status codes:
- 200: References returned
See:
- extractRaw for an experimental operation that returns a DynamiteRawResponse that can be serialized.
Implementation
Future<DynamiteResponse<ReferenceApiExtractResponseApplicationJson, void>> extract({
required String text,
int? resolve,
int? limit,
bool? oCSAPIRequest,
}) async {
final rawResponse = extractRaw(
text: text,
resolve: resolve,
limit: limit,
oCSAPIRequest: oCSAPIRequest,
);
return rawResponse.future;
}