rebuild abstract method
Rebuilds the instance.
The result is the same as this instance but with updates applied.
updates is a function that takes a builder $TwoFactorApiStateResponseApplicationJson_OcsInterfaceBuilder.
Implementation
$TwoFactorApiStateResponseApplicationJson_OcsInterface rebuild(
void Function($TwoFactorApiStateResponseApplicationJson_OcsInterfaceBuilder) updates,
);