FilesCapabilities_Files_ChunkedUpload class abstract
- Implemented types
Constructors
- FilesCapabilities_Files_ChunkedUpload([void b(FilesCapabilities_Files_ChunkedUploadBuilder)?])
-
Creates a new FilesCapabilities_Files_ChunkedUpload object using the builder pattern.
factory
-
FilesCapabilities_Files_ChunkedUpload.fromJson(Map<
String, dynamic> json) -
Creates a new object from the given
jsondata.factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- maxParallelCount → int
-
no setterinherited
- maxSize → int
-
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
rebuild(
dynamic updates(FilesCapabilities_Files_ChunkedUploadBuilder)) → FilesCapabilities_Files_ChunkedUpload -
Rebuilds the instance.
inherited
-
toBuilder(
) → FilesCapabilities_Files_ChunkedUploadBuilder -
Converts the instance to a builder
B.inherited -
toJson(
) → Map< String, dynamic> - Parses this object into a json like map.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
-
serializer
→ Serializer<
FilesCapabilities_Files_ChunkedUpload> -
Serializer for FilesCapabilities_Files_ChunkedUpload.
no setter