ProfileData class abstract
- Implemented types
Constructors
- ProfileData([void b(ProfileDataBuilder)?])
-
Creates a new ProfileData object using the builder pattern.
factory
-
ProfileData.fromJson(Map<
String, dynamic> json) -
Creates a new object from the given
jsondata.factory
Properties
-
actions
→ BuiltList<
ProfileAction> -
no setterinherited
- address → String?
-
no setterinherited
- biography → String?
-
no setterinherited
- displayname → String?
-
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- headline → String?
-
no setterinherited
- isUserAvatarVisible → bool?
-
no setterinherited
- organisation → String?
-
no setterinherited
- pronouns → String?
-
no setterinherited
- role → String?
-
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- timezone → String
-
no setterinherited
- timezoneOffset → int
-
no setterinherited
- userId → String
-
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
rebuild(
dynamic updates(ProfileDataBuilder)) → ProfileData -
Rebuilds the instance.
inherited
-
toBuilder(
) → ProfileDataBuilder -
Converts the instance to a builder
B.inherited -
toJson(
) → Map< String, dynamic> - Parses this object into a json like map.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
-
serializer
→ Serializer<
ProfileData> -
Serializer for ProfileData.
no setter