$TemplateFileCreatorWithTemplatesInterface class sealed
- Implemented types
- Implementers
- Annotations
-
- @BuiltValue.new(instantiable: false)
Properties
- $extension → String
-
no setterinherited
- actionLabel → String
-
no setterinherited
- app → String
-
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- iconClass → String?
-
no setterinherited
- iconSvgInline → String?
-
no setterinherited
- label → String
-
no setterinherited
-
mimetypes
→ BuiltList<
String> -
no setterinherited
- ratio → double?
-
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
templates
→ BuiltList<
Template> -
no setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
rebuild(
void updates($TemplateFileCreatorWithTemplatesInterfaceBuilder)) → $TemplateFileCreatorWithTemplatesInterface -
Rebuilds the instance.
override
-
toBuilder(
) → $TemplateFileCreatorWithTemplatesInterfaceBuilder -
Converts the instance to a builder $TemplateFileCreatorWithTemplatesInterfaceBuilder.
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited