ConversionApiConvertRequestApplicationJson class abstract

Implemented types

Constructors

ConversionApiConvertRequestApplicationJson([void b(ConversionApiConvertRequestApplicationJsonBuilder)?])
Creates a new ConversionApiConvertRequestApplicationJson object using the builder pattern.
factory
ConversionApiConvertRequestApplicationJson.fromJson(Map<String, dynamic> json)
Creates a new object from the given json data.
factory

Properties

destination String?
The target path of the converted file. Written to a temporary file if left empty.
no setterinherited
fileId int
ID of the file to be converted.
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
targetMimeType String
The MIME type to which you want to convert the file.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(ConversionApiConvertRequestApplicationJsonBuilder)) ConversionApiConvertRequestApplicationJson
Rebuilds the instance.
inherited
toBuilder() ConversionApiConvertRequestApplicationJsonBuilder
Converts the instance to a builder B.
inherited
toJson() Map<String, dynamic>
Parses this object into a json like map.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

serializer → Serializer<ConversionApiConvertRequestApplicationJson>
Serializer for ConversionApiConvertRequestApplicationJson.
no setter