VersionCheck class
Holds the versions, minimumVersion of an app.
- Annotations
-
- @immutable
Constructors
-
VersionCheck({required BuiltList<
Version> ? versions, required Version minimumVersion, bool? isSupportedOverride}) -
Creates a new VersionCheck.
const
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- isSupported → bool
-
Whether the versions is allowed by the minimumVersion.
no setter
- minimumVersion → Version
-
Minimum version of the app.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
versions
→ BuiltList<
Version> ? -
Current version of the app.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override