$selfTestPush_Request method
Send a test notification to push registered mobile apps.
Required capability: ocs-endpoints > test-push.
Returns a DynamiteRequest backing the selfTestPush operation.
Throws a DynamiteApiException if the API call does not return an expected status code.
Parameters:
apiVersion3oCSAPIRequestRequired to be true for the API request to pass. Defaults totrue.
Status codes:
- 200: Test notification generated successfully, but the device should still show the message to the user
- 400: Test notification could not be generated, show the message to the user
See:
- selfTestPush for a method executing this request and parsing the response.
- $selfTestPush_Serializer for a converter to parse the
Responsefrom an executed this request.
Implementation
@_i2.experimental
_i3.Request $selfTestPush_Request({required String apiVersion3, bool? oCSAPIRequest}) {
final _parameters = <String, Object?>{};
final __apiVersion3 = _$jsonSerializers.serialize(apiVersion3, specifiedType: const FullType(String));
_i6.checkString(__apiVersion3, 'apiVersion3', pattern: RegExp(r'^(v3)$'));
_parameters['apiVersion3'] = __apiVersion3;
final _path = _i4.UriTemplate('/ocs/v2.php/apps/notifications/api/{apiVersion3}/test/self').expand(_parameters);
final _uri = Uri.parse('${_rootClient.baseURL}$_path');
final _request = _i3.Request('post', _uri);
_request.headers['Accept'] = 'application/json';
// coverage:ignore-start
final authentication = _i5.IterableExtension(_rootClient.authentications)?.firstWhereOrNull(
(auth) => switch (auth) {
_i1.DynamiteHttpBearerAuthentication() || _i1.DynamiteHttpBasicAuthentication() => true,
_ => false,
},
);
if (authentication != null) {
_request.headers.addAll(authentication.headers);
} else {
throw Exception('Missing authentication for bearer_auth or basic_auth');
}
// coverage:ignore-end
var __oCSAPIRequest = _$jsonSerializers.serialize(oCSAPIRequest, specifiedType: const FullType(bool));
__oCSAPIRequest ??= true;
_request.headers['OCS-APIRequest'] = const _i6.HeaderEncoder().convert(__oCSAPIRequest);
return _request;
}