rebuild abstract method
Rebuilds the instance.
The result is the same as this instance but with updates applied.
updates is a function that takes a builder $ApiSelfTestPushResponseApplicationJson_OcsInterfaceBuilder.
Implementation
$ApiSelfTestPushResponseApplicationJson_OcsInterface rebuild(
void Function($ApiSelfTestPushResponseApplicationJson_OcsInterfaceBuilder) updates,
);