rebuild abstract method
Rebuilds the instance.
The result is the same as this instance but with updates applied.
updates is a function that takes a builder $ApiSelfTestPushResponseApplicationJson_Ocs_DataInterfaceBuilder.
Implementation
$ApiSelfTestPushResponseApplicationJson_Ocs_DataInterface rebuild(
void Function($ApiSelfTestPushResponseApplicationJson_Ocs_DataInterfaceBuilder) updates,
);