validate method
Future<DynamiteResponse<ApiValidateResponseApplicationJson, void> >
validate({
- required ApiValidateRequestApplicationJson $body,
- bool? oCSAPIRequest,
Validate a password against the enabled password policy rules.
Returns a Future containing a DynamiteResponse with the status code, deserialized body and headers.
Throws a DynamiteApiException if the API call does not return an expected status code.
Parameters:
oCSAPIRequestRequired to be true for the API request to pass. Defaults totrue.
Status codes:
- 200: Always
See:
- $validate_Request for the request send by this method.
- $validate_Serializer for a converter to parse the
Responsefrom an executed request.
Implementation
Future<_i1.DynamiteResponse<ApiValidateResponseApplicationJson, void>> validate({
required ApiValidateRequestApplicationJson $body,
bool? oCSAPIRequest,
}) async {
final _request = $validate_Request(oCSAPIRequest: oCSAPIRequest, $body: $body);
final _streamedResponse = await _rootClient.httpClient.send(_request);
final _response = await _i3.Response.fromStream(_streamedResponse);
final _serializer = $validate_Serializer();
return _i1.ResponseConverter<ApiValidateResponseApplicationJson, void>(_serializer).convert(_response);
}