rebuild abstract method
Rebuilds the instance.
The result is the same as this instance but with updates applied.
updates is a function that takes a builder $UsersGetEnabledAppsResponseApplicationJson_OcsInterfaceBuilder.
Implementation
$UsersGetEnabledAppsResponseApplicationJson_OcsInterface rebuild(
void Function($UsersGetEnabledAppsResponseApplicationJson_OcsInterfaceBuilder) updates,
);