$getMutualEvents_Request method
- @experimental
- required String token,
- CalendarIntegrationGetMutualEventsApiVersion? apiVersion,
- bool? oCSAPIRequest,
Get up to 3 events in the next 7 days sorted by their start timestamp ascending.
Required capability: mutual-calendar-events.
Returns a DynamiteRequest backing the getMutualEvents operation.
Throws a DynamiteApiException if the API call does not return an expected status code.
Parameters:
apiVersionDefaults to"v4".tokenoCSAPIRequestRequired to be true for the API request to pass. Defaults totrue.
Status codes:
- 200: A list of dashboard entries or an empty array
- 403: Room is not a 1 to 1 room, room is invalid, or user is not participant
See:
- getMutualEvents for a method executing this request and parsing the response.
- $getMutualEvents_Serializer for a converter to parse the
Responsefrom an executed this request.
Implementation
@_i2.experimental
_i3.Request $getMutualEvents_Request({
required String token,
CalendarIntegrationGetMutualEventsApiVersion? apiVersion,
bool? oCSAPIRequest,
}) {
final _parameters = <String, Object?>{};
final __token = _$jsonSerializers.serialize(token, specifiedType: const FullType(String));
_i4.checkString(__token, 'token', pattern: RegExp(r'^[a-z0-9]{4,30}$'));
_parameters['token'] = __token;
var __apiVersion = _$jsonSerializers.serialize(
apiVersion,
specifiedType: const FullType(CalendarIntegrationGetMutualEventsApiVersion),
);
__apiVersion ??= 'v4';
_parameters['apiVersion'] = __apiVersion;
final _path = _i5.UriTemplate(
'/ocs/v2.php/apps/spreed/api/{apiVersion}/room/{token}/mutual-events',
).expand(_parameters);
final _uri = Uri.parse('${_rootClient.baseURL}$_path');
final _request = _i3.Request('get', _uri);
_request.headers['Accept'] = 'application/json';
// coverage:ignore-start
final authentication = _i6.IterableExtension(_rootClient.authentications)?.firstWhereOrNull(
(auth) => switch (auth) {
_i1.DynamiteHttpBearerAuthentication() || _i1.DynamiteHttpBasicAuthentication() => true,
_ => false,
},
);
if (authentication != null) {
_request.headers.addAll(authentication.headers);
} else {
throw Exception('Missing authentication for bearer_auth or basic_auth');
}
// coverage:ignore-end
var __oCSAPIRequest = _$jsonSerializers.serialize(oCSAPIRequest, specifiedType: const FullType(bool));
__oCSAPIRequest ??= true;
_request.headers['OCS-APIRequest'] = const _i4.HeaderEncoder().convert(__oCSAPIRequest);
return _request;
}