getMutualEvents method
Future<DynamiteResponse<CalendarIntegrationGetMutualEventsResponseApplicationJson, void> >
getMutualEvents({
- required String token,
- CalendarIntegrationGetMutualEventsApiVersion? apiVersion,
- bool? oCSAPIRequest,
Get up to 3 events in the next 7 days sorted by their start timestamp ascending.
Required capability: mutual-calendar-events.
Returns a Future containing a DynamiteResponse with the status code, deserialized body and headers.
Throws a DynamiteApiException if the API call does not return an expected status code.
Parameters:
apiVersionDefaults to"v4".tokenoCSAPIRequestRequired to be true for the API request to pass. Defaults totrue.
Status codes:
- 200: A list of dashboard entries or an empty array
- 403: Room is not a 1 to 1 room, room is invalid, or user is not participant
See:
- $getMutualEvents_Request for the request send by this method.
- $getMutualEvents_Serializer for a converter to parse the
Responsefrom an executed request.
Implementation
Future<_i1.DynamiteResponse<CalendarIntegrationGetMutualEventsResponseApplicationJson, void>> getMutualEvents({
required String token,
CalendarIntegrationGetMutualEventsApiVersion? apiVersion,
bool? oCSAPIRequest,
}) async {
final _request = $getMutualEvents_Request(token: token, apiVersion: apiVersion, oCSAPIRequest: oCSAPIRequest);
final _streamedResponse = await _rootClient.httpClient.send(_request);
final _response = await _i3.Response.fromStream(_streamedResponse);
final _serializer = $getMutualEvents_Serializer();
return _i1.ResponseConverter<CalendarIntegrationGetMutualEventsResponseApplicationJson, void>(
_serializer,
).convert(_response);
}