getUpcomingReminders method
Future<DynamiteResponse<ChatGetUpcomingRemindersResponseApplicationJson, void> >
getUpcomingReminders({
- ChatGetUpcomingRemindersApiVersion? apiVersion,
- bool? oCSAPIRequest,
Get all upcoming reminders.
Required capability: upcoming-reminders.
Returns a Future containing a DynamiteResponse with the status code, deserialized body and headers.
Throws a DynamiteApiException if the API call does not return an expected status code.
Parameters:
apiVersionDefaults to"v1".oCSAPIRequestRequired to be true for the API request to pass. Defaults totrue.
Status codes:
- 200: Reminders returned
See:
- $getUpcomingReminders_Request for the request send by this method.
- $getUpcomingReminders_Serializer for a converter to parse the
Responsefrom an executed request.
Implementation
Future<_i1.DynamiteResponse<ChatGetUpcomingRemindersResponseApplicationJson, void>> getUpcomingReminders({
ChatGetUpcomingRemindersApiVersion? apiVersion,
bool? oCSAPIRequest,
}) async {
final _request = $getUpcomingReminders_Request(apiVersion: apiVersion, oCSAPIRequest: oCSAPIRequest);
final _streamedResponse = await _rootClient.httpClient.send(_request);
final _response = await _i3.Response.fromStream(_streamedResponse);
final _serializer = $getUpcomingReminders_Serializer();
return _i1.ResponseConverter<ChatGetUpcomingRemindersResponseApplicationJson, void>(_serializer).convert(_response);
}