$ChatReminderUpcomingInterface class sealed
- Implementers
- Annotations
-
- @BuiltValue.new(instantiable: false)
Properties
- actorDisplayName → String
-
no setter
- actorId → String
-
no setter
- actorType → String
-
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- message → String
-
no setter
- messageId → int
-
no setter
-
messageParameters
→ BuiltMap<
String, BuiltMap< String, JsonObject> > -
no setter
- reminderTimestamp → int
-
no setter
- roomToken → String
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
rebuild(
void updates($ChatReminderUpcomingInterfaceBuilder)) → $ChatReminderUpcomingInterface - Rebuilds the instance.
-
toBuilder(
) → $ChatReminderUpcomingInterfaceBuilder - Converts the instance to a builder $ChatReminderUpcomingInterfaceBuilder.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited