- Implementers
Constructors
Properties
- actorDisplayName ↔ String?
-
getter/setter pair
- actorId ↔ String?
-
getter/setter pair
- actorType ↔ String?
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- message ↔ String?
-
getter/setter pair
- messageId ↔ int?
-
getter/setter pair
-
messageParameters
↔ MapBuilder<
String, BuiltMap< String, JsonObject> > -
getter/setter pair
- reminderTimestamp ↔ int?
-
getter/setter pair
- roomToken ↔ String?
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
replace(
$ChatReminderUpcomingInterface other) → void -
toString(
) → String -
A string representation of this object.
inherited
-
update(
void updates($ChatReminderUpcomingInterfaceBuilder)) → void
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited