$RoomCreateRoomRequestApplicationJsonInterface class
sealed
Implementers
Annotations
@BuiltValue.new(instantiable: false)
Properties
avatarColor
→ String ?
Background color of the avatar (Only considered when an emoji was provided) (only available with conversation-creation-all capability).
no setter
description
→ String
Description for the conversation (limited to 2.000 characters) (only available with conversation-creation-all capability).
no setter
emoji
→ String ?
Emoji for the avatar of the conversation (only available with conversation-creation-all capability).
no setter
hashCode
→ int
The hash code for this object.
no setter inherited
invite
→ String
User, group, … ID to invite Deprecated Use the $participants array instead.
no setter
listable
→ RoomCreateRoomRequestApplicationJson_Listable ?
Scope where the conversation is listable (Default not listable for anyone) (only available with conversation-creation-all capability).
no setter
lobbyState
→ RoomCreateRoomRequestApplicationJson_LobbyState ?
Lobby state of the conversation (Default lobby is disabled) (only available with conversation-creation-all capability).
no setter
lobbyTimer
→ int ?
Timer when the lobby will be removed (Default null, will not be disabled automatically) (only available with conversation-creation-all capability).
no setter
mentionPermissions
→ RoomCreateRoomRequestApplicationJson_MentionPermissions ?
Who can mention at-all in the chat (only available with conversation-creation-all capability).
no setter
messageExpiration
→ int
Seconds after which messages will disappear, 0 disables expiration (Default 0) (only available with conversation-creation-all capability).
no setter
objectId
→ String
ID of the object (Ignored if $roomType is {@see Room::TYPE_ONE_TO_ONE}).
no setter
objectType
→ String
Type of the object (Ignored if $roomType is {@see Room::TYPE_ONE_TO_ONE}).
no setter
participants
→ InvitationList
List of participants to add grouped by type (only available with conversation-creation-all capability).
no setter
password
→ String
The room password (only available with conversation-creation-password capability) (Ignored if $roomType is not {@see Room::TYPE_PUBLIC}).
no setter
permissions
→ int ?
Default permissions for participants (only available with conversation-creation-all capability).
no setter
readOnly
→ RoomCreateRoomRequestApplicationJson_ReadOnly ?
Read only state of the conversation (Default writable) (only available with conversation-creation-all capability).
no setter
recordingConsent
→ RoomCreateRoomRequestApplicationJson_RecordingConsent ?
Whether participants need to agree to a recording before joining a call (only available with conversation-creation-all capability).
no setter
roomName
→ String
Name of the room, unless the legacy mode providing $invite and $source is used, the name must no longer be empty with the conversation-creation-all capability (Ignored if $roomType is {@see Room::TYPE_ONE_TO_ONE}).
no setter
roomType
→ int
Type of the room.
no setter
runtimeType
→ Type
A representation of the runtime type of the object.
no setter inherited
sipEnabled
→ RoomCreateRoomRequestApplicationJson_SipEnabled ?
Whether SIP dial-in shall be enabled (only available with conversation-creation-all capability).
no setter
source
→ String
Source of the invite ID ('circles' to create a room with a circle, etc.) Deprecated Use the $participants array instead.
no setter