$RoomImportEmailsAsParticipantsResponseApplicationJson_Ocs_DataInterfaceBuilder class abstract mixin
Properties
- duplicates ↔ int?
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- invalid ↔ int?
-
getter/setter pair
-
invalidLines
↔ ListBuilder<
int> -
getter/setter pair
- invites ↔ int?
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- type ↔ int?
-
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
replace(
$RoomImportEmailsAsParticipantsResponseApplicationJson_Ocs_DataInterface other) → void -
toString(
) → String -
A string representation of this object.
inherited
-
update(
void updates($RoomImportEmailsAsParticipantsResponseApplicationJson_Ocs_DataInterfaceBuilder)) → void
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited