callPermissions property
int
get
callPermissions
Call permissions, if not Custom this are not the resulting permissions, if set they will reset after the end of the call (see constants list).
Implementation
int get callPermissions;