canEnableSIP property
bool
get
canEnableSIP
Whether the given user can enable SIP for this conversation. Note that when the token is not-numeric only, SIP can not be enabled even if the user is permitted and a moderator of the conversation.
Implementation
bool get canEnableSIP;