canLeaveConversation property
bool
get
canLeaveConversation
Flag if the user can leave the conversation (not possible for the last user with moderator permissions).
Implementation
bool get canLeaveConversation;