attendeeIds property
BuiltList<int> ?
get
attendeeIds
List of attendee ids to invite, if null everyone will be invited, if empty array only the actor will receive the event.
Implementation
BuiltList<int>? get attendeeIds;