ChatSummarizeChatResponseApplicationJson class abstract
- Implemented types
Constructors
- ChatSummarizeChatResponseApplicationJson([void b(ChatSummarizeChatResponseApplicationJsonBuilder)?])
-
Creates a new ChatSummarizeChatResponseApplicationJson object using the builder pattern.
factory
-
ChatSummarizeChatResponseApplicationJson.fromJson(Map<
String, dynamic> json) -
Creates a new object from the given
jsondata.factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- ocs → ChatSummarizeChatResponseApplicationJson_Ocs
-
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
rebuild(
dynamic updates(ChatSummarizeChatResponseApplicationJsonBuilder)) → ChatSummarizeChatResponseApplicationJson -
Rebuilds the instance.
inherited
-
toBuilder(
) → ChatSummarizeChatResponseApplicationJsonBuilder -
Converts the instance to a builder
B.inherited -
toJson(
) → Map< String, dynamic> - Parses this object into a json like map.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
-
serializer
→ Serializer<
ChatSummarizeChatResponseApplicationJson> -
Serializer for ChatSummarizeChatResponseApplicationJson.
no setter