- Implementers
Constructors
Properties
-
countries
↔ MapBuilder<
String, String> -
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
-
languages
↔ MapBuilder<
String, String> -
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
terms
↔ MapBuilder<
String, Terms> -
getter/setter pair
- tosForUsers ↔ AdminFormData_TosForUsers?
-
getter/setter pair
-
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
replace(
$AdminFormDataInterface other) → void -
toString(
) → String -
A string representation of this object.
inherited
-
update(
void updates($AdminFormDataInterfaceBuilder)) → void
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited