$SigningClient class
Properties
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
$resetAllSignatories_Request({bool? oCSAPIRequest})
→ Request
-
Reset the signatories of all accounts.
-
$resetAllSignatories_Serializer()
→ DynamiteSerializer<SigningResetAllSignatoriesResponseApplicationJson, void>
-
Builds a serializer to parse the response of $resetAllSignatories_Request.
-
$signTerms_Request({required SigningSignTermsRequestApplicationJson $body, bool? oCSAPIRequest})
→ Request
-
As a logged in user sign the terms.
-
$signTerms_Serializer()
→ DynamiteSerializer<SigningSignTermsResponseApplicationJson, void>
-
Builds a serializer to parse the response of $signTerms_Request.
-
$signTermsPublic_Request({required SigningSignTermsPublicRequestApplicationJson $body, bool? oCSAPIRequest})
→ Request
-
As a guest sign the terms.
-
$signTermsPublic_Serializer()
→ DynamiteSerializer<SigningSignTermsPublicResponseApplicationJson, void>
-
Builds a serializer to parse the response of $signTermsPublic_Request.
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
resetAllSignatories({bool? oCSAPIRequest})
→ Future<DynamiteResponse<SigningResetAllSignatoriesResponseApplicationJson, void>>
-
Reset the signatories of all accounts.
-
signTerms({required SigningSignTermsRequestApplicationJson $body, bool? oCSAPIRequest})
→ Future<DynamiteResponse<SigningSignTermsResponseApplicationJson, void>>
-
As a logged in user sign the terms.
-
signTermsPublic({required SigningSignTermsPublicRequestApplicationJson $body, bool? oCSAPIRequest})
→ Future<DynamiteResponse<SigningSignTermsPublicResponseApplicationJson, void>>
-
As a guest sign the terms.
-
toString()
→ String
-
A string representation of this object.
inherited