signTerms method
Future<DynamiteResponse<SigningSignTermsResponseApplicationJson, void> >
signTerms({
- required SigningSignTermsRequestApplicationJson $body,
- bool? oCSAPIRequest,
As a logged in user sign the terms.
Returns a Future containing a DynamiteResponse with the status code, deserialized body and headers.
Throws a DynamiteApiException if the API call does not return an expected status code.
Parameters:
oCSAPIRequestRequired to be true for the API request to pass. Defaults totrue.
Status codes:
- 200: Signed successfully
See:
- $signTerms_Request for the request send by this method.
- $signTerms_Serializer for a converter to parse the
Responsefrom an executed request.
Implementation
Future<_i1.DynamiteResponse<SigningSignTermsResponseApplicationJson, void>> signTerms({
required SigningSignTermsRequestApplicationJson $body,
bool? oCSAPIRequest,
}) async {
final _request = $signTerms_Request(oCSAPIRequest: oCSAPIRequest, $body: $body);
final _streamedResponse = await _rootClient.httpClient.send(_request);
final _response = await _i3.Response.fromStream(_streamedResponse);
final _serializer = $signTerms_Serializer();
return _i1.ResponseConverter<SigningSignTermsResponseApplicationJson, void>(_serializer).convert(_response);
}