$TermsCreateRequestApplicationJsonInterface class sealed
- Implementers
- Annotations
-
- @BuiltValue.new(instantiable: false)
Properties
- body → String
-
The actual terms and conditions text (can be markdown, using headers, basic text formating, lists and links).
no setter
- countryCode → String
-
One of the 2-letter region codes or
--for "global".no setter - hashCode → int
-
The hash code for this object.
no setterinherited
- languageCode → String
-
One of the 2-letter language codes.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
rebuild(
void updates($TermsCreateRequestApplicationJsonInterfaceBuilder)) → $TermsCreateRequestApplicationJsonInterface - Rebuilds the instance.
-
toBuilder(
) → $TermsCreateRequestApplicationJsonInterfaceBuilder - Converts the instance to a builder $TermsCreateRequestApplicationJsonInterfaceBuilder.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited