rebuild abstract method
Rebuilds the instance.
The result is the same as this instance but with updates applied.
updates is a function that takes a builder $TermsDestroyResponseApplicationJson_OcsInterfaceBuilder.
Implementation
$TermsDestroyResponseApplicationJson_OcsInterface rebuild(
void Function($TermsDestroyResponseApplicationJson_OcsInterfaceBuilder) updates,
);