AdminFormDataBuilder class
- Implemented types
Constructors
Properties
-
countries
↔ MapBuilder<
String, String> -
covariantgetter/setter pairoverride
- hashCode → int
-
The hash code for this object.
no setterinherited
-
languages
↔ MapBuilder<
String, String> -
covariantgetter/setter pairoverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
terms
↔ MapBuilder<
String, Terms> -
covariantgetter/setter pairoverride
- tosForUsers ↔ AdminFormData_TosForUsers?
-
covariantgetter/setter pairoverride
-
covariantgetter/setter pairoverride
Methods
-
build(
) → AdminFormData -
Builds.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
replace(
covariant AdminFormData other) → void -
Replaces the value in the builder with a new one.
override
-
toString(
) → String -
A string representation of this object.
inherited
-
update(
void updates(AdminFormDataBuilder)?) → void -
Applies updates.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited