PublicCapabilities_TermsOfService class abstract
- Implemented types
Constructors
- PublicCapabilities_TermsOfService([void b(PublicCapabilities_TermsOfServiceBuilder)?])
-
Creates a new PublicCapabilities_TermsOfService object using the builder pattern.
factory
-
PublicCapabilities_TermsOfService.fromJson(Map<
String, dynamic> json) -
Creates a new object from the given
jsondata.factory
Properties
- enabled → PublicCapabilities_TermsOfService_Enabled
-
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- termUuid → String
-
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
rebuild(
dynamic updates(PublicCapabilities_TermsOfServiceBuilder)) → PublicCapabilities_TermsOfService -
Rebuilds the instance.
inherited
-
toBuilder(
) → PublicCapabilities_TermsOfServiceBuilder -
Converts the instance to a builder
B.inherited -
toJson(
) → Map< String, dynamic> - Parses this object into a json like map.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
-
serializer
→ Serializer<
PublicCapabilities_TermsOfService> -
Serializer for PublicCapabilities_TermsOfService.
no setter