$UserThemeClient class
Properties
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
$deleteBackground_Request({bool? oCSAPIRequest})
→ Request
-
Delete the background.
-
$deleteBackground_Serializer()
→ DynamiteSerializer<Background, void>
-
Builds a serializer to parse the response of $deleteBackground_Request.
-
$disableTheme_Request({required String themeId, bool? oCSAPIRequest})
→ Request
-
Disable theme.
-
$disableTheme_Serializer()
→ DynamiteSerializer<UserThemeDisableThemeResponseApplicationJson, void>
-
Builds a serializer to parse the response of $disableTheme_Request.
-
$enableTheme_Request({required String themeId, bool? oCSAPIRequest})
→ Request
-
Enable theme.
-
$enableTheme_Serializer()
→ DynamiteSerializer<UserThemeEnableThemeResponseApplicationJson, void>
-
Builds a serializer to parse the response of $enableTheme_Request.
-
$getBackground_Request({bool? oCSAPIRequest})
→ Request
-
Get the background image.
-
$getBackground_Serializer()
→ DynamiteSerializer<Uint8List, void>
-
Builds a serializer to parse the response of $getBackground_Request.
-
$setBackground_Request({required String type, bool? oCSAPIRequest, UserThemeSetBackgroundRequestApplicationJson? $body})
→ Request
-
Set the background.
-
$setBackground_Serializer()
→ DynamiteSerializer<Background, void>
-
Builds a serializer to parse the response of $setBackground_Request.
-
deleteBackground({bool? oCSAPIRequest})
→ Future<DynamiteResponse<Background, void>>
-
Delete the background.
-
disableTheme({required String themeId, bool? oCSAPIRequest})
→ Future<DynamiteResponse<UserThemeDisableThemeResponseApplicationJson, void>>
-
Disable theme.
-
enableTheme({required String themeId, bool? oCSAPIRequest})
→ Future<DynamiteResponse<UserThemeEnableThemeResponseApplicationJson, void>>
-
Enable theme.
-
getBackground({bool? oCSAPIRequest})
→ Future<DynamiteResponse<Uint8List, void>>
-
Get the background image.
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
setBackground({required String type, bool? oCSAPIRequest, UserThemeSetBackgroundRequestApplicationJson? $body})
→ Future<DynamiteResponse<Background, void>>
-
Set the background.
-
toString()
→ String
-
A string representation of this object.
inherited