setBackground method
Future<DynamiteResponse<Background, void> >
setBackground({
- required String type,
- bool? oCSAPIRequest,
- UserThemeSetBackgroundRequestApplicationJson? $body,
Set the background.
Returns a Future containing a DynamiteResponse with the status code, deserialized body and headers.
Throws a DynamiteApiException if the API call does not return an expected status code.
Parameters:
typeType of background.oCSAPIRequestRequired to be true for the API request to pass. Defaults totrue.
Status codes:
- 200: Background set successfully
- 400: Setting background is not possible
- 500
See:
- $setBackground_Request for the request send by this method.
- $setBackground_Serializer for a converter to parse the
Responsefrom an executed request.
Implementation
Future<_i1.DynamiteResponse<Background, void>> setBackground({
required String type,
bool? oCSAPIRequest,
UserThemeSetBackgroundRequestApplicationJson? $body,
}) async {
final _request = $setBackground_Request(type: type, oCSAPIRequest: oCSAPIRequest, $body: $body);
final _streamedResponse = await _rootClient.httpClient.send(_request);
final _response = await _i3.Response.fromStream(_streamedResponse);
final _serializer = $setBackground_Serializer();
return _i1.ResponseConverter<Background, void>(_serializer).convert(_response);
}