Background class abstract

Implemented types

Constructors

Background([void b(BackgroundBuilder)?])
Creates a new Background object using the builder pattern.
factory
Background.fromJson(Map<String, dynamic> json)
Creates a new object from the given json data.
factory

Properties

backgroundColor String
no setterinherited
backgroundImage String?
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
primaryColor String
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
version int
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(BackgroundBuilder)) Background
Rebuilds the instance.
inherited
toBuilder() BackgroundBuilder
Converts the instance to a builder B.
inherited
toJson() Map<String, dynamic>
Parses this object into a json like map.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

serializer → Serializer<Background>
Serializer for Background.
no setter